type token =
  | QUESTION
  | COLON
  | ACTION_IF
  | ADD_KIT
  | ADD_MUSIC
  | ADD_PROJECTILE
  | ADD_STATE_TRIGGER
  | ADD_TRANS_TRIGGER
  | ADD_STORE_ITEM
  | ALLOW_MISSING
  | ALWAYS
  | AND
  | OR
  | NOT
  | ELSE
  | LPAREN
  | RPAREN
  | APPEND
  | APPENDI
  | APPEND_COL
  | ASK_EVERY_COMPONENT
  | AT_EXIT
  | AT_INTERACTIVE_EXIT
  | AT_INTERACTIVE_UNINSTALL
  | SET_2DA_ENTRY
  | READ_2DA_ENTRY
  | AT_UNINSTALL
  | AUTHOR
  | AUTO_TRA
  | BACKUP
  | BEGIN
  | BUT_ONLY_IF_IT_CHANGES
  | CHAIN2
  | CHAIN3
  | COMPILE
  | COPY
  | GLOB
  | COPY_EXISTING
  | COPY_EXISTING_REGEXP
  | COPY_RANDOM
  | COPY_TRANS
  | DELETE_BYTES
  | DEPRECATED
  | DO
  | END
  | EQUALS
  | EQUALSEQUALS
  | EXIT
  | EXTEND_BOTTOM
  | EXTEND_BOTTOM_REGEXP
  | EXTEND_TOP
  | EXTEND_TOP_REGEXP
  | EXTERN
  | FAIL
  | FILE_CONTAINS
  | FILE_MD5
  | FILE_EXISTS
  | FILE_EXISTS_IN_GAME
  | FILE_SIZE
  | FLAGS
  | FORBID_FILE
  | GOTO
  | GT
  | GTE
  | LT
  | LTE
  | BAND
  | BOR
  | BXOR
  | BLSL
  | BASR
  | BLSR
  | BNOT
  | IF
  | SET
  | IF_EVAL
  | IF_SIZE_IS
  | INSERT_BYTES
  | INTERJECT
  | INTERJECT_COPY_TRANS
  | JOURNAL
  | SOLVED_JOURNAL
  | UNSOLVED_JOURNAL
  | LANGUAGE
  | MENU_STYLE
  | MKDIR
  | PATCH_GAM
  | PLUS
  | MINUS
  | TIMES
  | DIVIDE
  | PRINT
  | RANDOM_SEED
  | READ_ASCII
  | READ_BYTE
  | READ_LONG
  | READ_SHORT
  | REPLACE
  | REPLACE_ACTION_TEXT
  | REPLACE_ACTION_TEXT_PROCESS
  | REPLACE_BCS_BLOCK
  | REPLACE_BCS_BLOCK_REGEXP
  | APPLY_BCS_PATCH
  | APPLY_BCS_PATCH_OR_COPY
  | REPLACE_SAY
  | REPLACE_STATE_TRIGGER
  | REPLACE_TEXTUALLY
  | REPLACE_TRIGGER_TEXT
  | REPLACE_TRIGGER_TEXT_REGEXP
  | REPLY
  | REQUIRE_FILE
  | REQUIRE_COMPONENT
  | FORBID_COMPONENT
  | SAY
  | SET_WEIGHT
  | STRING of (string)
  | STRING_SET
  | THEN
  | UNINSTALL
  | UNLESS
  | USING
  | WEIGHT
  | WRITE_ASCII
  | WRITE_EVALUATED_ASCII
  | WRITE_BYTE
  | WRITE_LONG
  | WRITE_SHORT
  | WHILE
  | EOF
  | SOUND of (string)
  | STRING_REF of (int)
  | TRANS_REF of (int)
  | FORCED_STRING_REF of (int)

open Parsing;;
# 2 "src/dparser.mly"
open Util
open Load

(*** input handle ***)

let current_unit = ref None

(*** Error handling ***)
let parse_error = Util.parse_error 

let get_current_unit () = match !current_unit with
  Some(s) -> s
| None -> parse_error "No current unit (use BEGIN)" 

type trans_opt_type =
    Trans_Reply of Dlg.tlk_string option
  | Trans_Do of string option
  | Trans_Journal of (Dlg.journal_type * Dlg.tlk_string) option
  | Trans_Flags of int

let extra_actions = ref [] 

let verify_trigger_list s =
  let con = the_context () in 
  let filename = (Printf.sprintf "trigger list near line %d, column %d of %s"
    con.line con.col con.filename) in 
  let lexbuf = lex_init_from_internal_string filename s in 
  let result = try 
    let res = Bafparser.trigger_list Baflexer.initial lexbuf in 
    let buff = Buffer.create (String.length s) in 
    Bcs.print_script_text (the_game()) (Bcs.Save_BCS_Buffer(buff))
        (Bcs.BCS_Print_TriggerList(res)) false None ;
    Buffer.contents buff 
  with e -> 
    log_only "WARNING: cannot verify trigger ~%s~: %s\n" s 
      (Printexc.to_string e) ;
    s 
  in 
  pop_context () ;
  result 

let verify_action_list s =
  let con = the_context () in 
  let filename = (Printf.sprintf "action list near line %d, column %d of %s"
    con.line con.col con.filename) in 
  let lexbuf = lex_init_from_internal_string filename s in 
  let result = try 
    let res = Bafparser.action_list Baflexer.initial lexbuf in 
    let buff = Buffer.create (String.length s) in 
    Bcs.print_script_text (the_game()) (Bcs.Save_BCS_Buffer(buff))
        (Bcs.BCS_Print_ActionList(res)) false None ;
    Buffer.contents buff 
  with e -> 
    log_only "WARNING: cannot verify action ~%s~: %s\n" s 
      (Printexc.to_string e) ;
    s 
  in
  pop_context () ; 
  (if result = "" then begin
    let warn = con.warn_only in
    con.warn_only <- true ;
    (try parse_error "Empty Action (may confuse some utilities, like NI)"
    with _ -> () ) ;
    con.warn_only <- warn 
  end) ; 
  result 

# 206 "src/dparser.ml"
let yytransl_const = [|
  257 (* QUESTION *);
  258 (* COLON *);
  259 (* ACTION_IF *);
  260 (* ADD_KIT *);
  261 (* ADD_MUSIC *);
  262 (* ADD_PROJECTILE *);
  263 (* ADD_STATE_TRIGGER *);
  264 (* ADD_TRANS_TRIGGER *);
  265 (* ADD_STORE_ITEM *);
  266 (* ALLOW_MISSING *);
  267 (* ALWAYS *);
  268 (* AND *);
  269 (* OR *);
  270 (* NOT *);
  271 (* ELSE *);
  272 (* LPAREN *);
  273 (* RPAREN *);
  274 (* APPEND *);
  275 (* APPENDI *);
  276 (* APPEND_COL *);
  277 (* ASK_EVERY_COMPONENT *);
  278 (* AT_EXIT *);
  279 (* AT_INTERACTIVE_EXIT *);
  280 (* AT_INTERACTIVE_UNINSTALL *);
  281 (* SET_2DA_ENTRY *);
  282 (* READ_2DA_ENTRY *);
  283 (* AT_UNINSTALL *);
  284 (* AUTHOR *);
  285 (* AUTO_TRA *);
  286 (* BACKUP *);
  287 (* BEGIN *);
  288 (* BUT_ONLY_IF_IT_CHANGES *);
  289 (* CHAIN2 *);
  290 (* CHAIN3 *);
  291 (* COMPILE *);
  292 (* COPY *);
  293 (* GLOB *);
  294 (* COPY_EXISTING *);
  295 (* COPY_EXISTING_REGEXP *);
  296 (* COPY_RANDOM *);
  297 (* COPY_TRANS *);
  298 (* DELETE_BYTES *);
  299 (* DEPRECATED *);
  300 (* DO *);
  301 (* END *);
  302 (* EQUALS *);
  303 (* EQUALSEQUALS *);
  304 (* EXIT *);
  305 (* EXTEND_BOTTOM *);
  306 (* EXTEND_BOTTOM_REGEXP *);
  307 (* EXTEND_TOP *);
  308 (* EXTEND_TOP_REGEXP *);
  309 (* EXTERN *);
  310 (* FAIL *);
  311 (* FILE_CONTAINS *);
  312 (* FILE_MD5 *);
  313 (* FILE_EXISTS *);
  314 (* FILE_EXISTS_IN_GAME *);
  315 (* FILE_SIZE *);
  316 (* FLAGS *);
  317 (* FORBID_FILE *);
  318 (* GOTO *);
  319 (* GT *);
  320 (* GTE *);
  321 (* LT *);
  322 (* LTE *);
  323 (* BAND *);
  324 (* BOR *);
  325 (* BXOR *);
  326 (* BLSL *);
  327 (* BASR *);
  328 (* BLSR *);
  329 (* BNOT *);
  330 (* IF *);
  331 (* SET *);
  332 (* IF_EVAL *);
  333 (* IF_SIZE_IS *);
  334 (* INSERT_BYTES *);
  335 (* INTERJECT *);
  336 (* INTERJECT_COPY_TRANS *);
  337 (* JOURNAL *);
  338 (* SOLVED_JOURNAL *);
  339 (* UNSOLVED_JOURNAL *);
  340 (* LANGUAGE *);
  341 (* MENU_STYLE *);
  342 (* MKDIR *);
  343 (* PATCH_GAM *);
  344 (* PLUS *);
  345 (* MINUS *);
  346 (* TIMES *);
  347 (* DIVIDE *);
  348 (* PRINT *);
  349 (* RANDOM_SEED *);
  350 (* READ_ASCII *);
  351 (* READ_BYTE *);
  352 (* READ_LONG *);
  353 (* READ_SHORT *);
  354 (* REPLACE *);
  355 (* REPLACE_ACTION_TEXT *);
  356 (* REPLACE_ACTION_TEXT_PROCESS *);
  357 (* REPLACE_BCS_BLOCK *);
  358 (* REPLACE_BCS_BLOCK_REGEXP *);
  359 (* APPLY_BCS_PATCH *);
  360 (* APPLY_BCS_PATCH_OR_COPY *);
  361 (* REPLACE_SAY *);
  362 (* REPLACE_STATE_TRIGGER *);
  363 (* REPLACE_TEXTUALLY *);
  364 (* REPLACE_TRIGGER_TEXT *);
  365 (* REPLACE_TRIGGER_TEXT_REGEXP *);
  366 (* REPLY *);
  367 (* REQUIRE_FILE *);
  368 (* REQUIRE_COMPONENT *);
  369 (* FORBID_COMPONENT *);
  370 (* SAY *);
  371 (* SET_WEIGHT *);
  373 (* STRING_SET *);
  374 (* THEN *);
  375 (* UNINSTALL *);
  376 (* UNLESS *);
  377 (* USING *);
  378 (* WEIGHT *);
  379 (* WRITE_ASCII *);
  380 (* WRITE_EVALUATED_ASCII *);
  381 (* WRITE_BYTE *);
  382 (* WRITE_LONG *);
  383 (* WRITE_SHORT *);
  384 (* WHILE *);
    0 (* EOF *);
    0|]

let yytransl_block = [|
  372 (* STRING *);
  385 (* SOUND *);
  386 (* STRING_REF *);
  387 (* TRANS_REF *);
  388 (* FORCED_STRING_REF *);
    0|]

let yylhs = "\255\255\
\001\000\012\000\012\000\006\000\006\000\007\000\009\000\009\000\
\038\000\038\000\008\000\040\000\041\000\041\000\042\000\043\000\
\044\000\010\000\011\000\013\000\013\000\013\000\013\000\013\000\
\013\000\013\000\013\000\013\000\013\000\013\000\013\000\013\000\
\013\000\013\000\013\000\020\000\020\000\048\000\048\000\047\000\
\047\000\047\000\047\000\047\000\045\000\045\000\021\000\021\000\
\046\000\046\000\014\000\014\000\018\000\018\000\049\000\049\000\
\050\000\050\000\051\000\015\000\015\000\015\000\039\000\019\000\
\019\000\019\000\023\000\023\000\016\000\016\000\026\000\026\000\
\026\000\026\000\026\000\026\000\027\000\027\000\052\000\053\000\
\053\000\017\000\017\000\017\000\025\000\025\000\025\000\025\000\
\022\000\022\000\022\000\022\000\022\000\024\000\024\000\002\000\
\002\000\003\000\029\000\029\000\029\000\029\000\029\000\029\000\
\037\000\037\000\028\000\028\000\030\000\030\000\054\000\054\000\
\054\000\054\000\031\000\031\000\055\000\055\000\056\000\056\000\
\057\000\057\000\032\000\032\000\032\000\032\000\032\000\032\000\
\032\000\032\000\032\000\032\000\032\000\032\000\032\000\032\000\
\032\000\032\000\032\000\032\000\032\000\032\000\032\000\032\000\
\032\000\032\000\032\000\032\000\032\000\032\000\058\000\058\000\
\058\000\058\000\058\000\058\000\058\000\058\000\058\000\036\000\
\036\000\033\000\033\000\033\000\033\000\033\000\033\000\034\000\
\034\000\059\000\059\000\059\000\059\000\059\000\059\000\059\000\
\059\000\059\000\059\000\059\000\059\000\059\000\059\000\059\000\
\059\000\059\000\059\000\059\000\059\000\059\000\059\000\035\000\
\035\000\060\000\060\000\060\000\060\000\060\000\060\000\060\000\
\060\000\060\000\060\000\060\000\060\000\060\000\060\000\060\000\
\060\000\060\000\060\000\060\000\060\000\060\000\060\000\060\000\
\060\000\004\000\005\000\005\000\005\000\000\000\000\000\000\000\
\000\000"

let yylen = "\002\000\
\001\000\000\000\002\000\002\000\003\000\002\000\004\000\004\000\
\000\000\001\000\002\000\005\000\000\000\002\000\006\000\005\000\
\004\000\004\000\004\000\002\000\003\000\003\000\003\000\004\000\
\001\000\001\000\001\000\004\000\004\000\003\000\003\000\004\000\
\004\000\005\000\005\000\003\000\005\000\000\000\002\000\003\000\
\003\000\003\000\001\000\002\000\000\000\004\000\000\000\003\000\
\000\000\004\000\000\000\002\000\000\000\002\000\000\000\001\000\
\000\000\001\000\001\000\010\000\003\000\007\000\002\000\001\000\
\003\000\003\000\001\000\003\000\000\000\002\000\002\000\002\000\
\002\000\002\000\002\000\002\000\000\000\002\000\001\000\001\000\
\000\000\005\000\006\000\003\000\002\000\002\000\003\000\001\000\
\002\000\004\000\001\000\001\000\002\000\000\000\001\000\000\000\
\004\000\007\000\000\000\003\000\003\000\002\000\004\000\003\000\
\000\000\002\000\000\000\005\000\000\000\005\000\000\000\003\000\
\005\000\005\000\000\000\002\000\000\000\002\000\000\000\001\000\
\000\000\001\000\006\000\005\000\006\000\003\000\002\000\003\000\
\002\000\003\000\003\000\004\000\004\000\005\000\005\000\005\000\
\005\000\002\000\002\000\002\000\002\000\003\000\002\000\003\000\
\003\000\021\000\002\000\002\000\006\000\010\000\003\000\003\000\
\003\000\002\000\002\000\003\000\002\000\003\000\003\000\000\000\
\002\000\000\000\003\000\003\000\003\000\003\000\002\000\000\000\
\003\000\001\000\003\000\003\000\003\000\003\000\003\000\003\000\
\002\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
\003\000\002\000\003\000\003\000\003\000\003\000\005\000\000\000\
\002\000\003\000\003\000\003\000\003\000\003\000\002\000\003\000\
\003\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
\003\000\003\000\003\000\004\000\005\000\005\000\005\000\005\000\
\008\000\001\000\000\000\004\000\005\000\002\000\002\000\002\000\
\002\000"

let yydefred = "\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\222\000\000\000\
\000\000\000\000\000\000\000\000\000\000\001\000\000\000\025\000\
\027\000\026\000\000\000\000\000\223\000\000\000\224\000\000\000\
\225\000\218\000\000\000\000\000\006\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\011\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\020\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\003\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\005\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\063\000\000\000\000\000\
\052\000\000\000\021\000\023\000\000\000\079\000\000\000\080\000\
\000\000\022\000\070\000\000\000\000\000\000\000\043\000\000\000\
\030\000\031\000\000\000\000\000\000\000\091\000\092\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\054\000\000\000\
\017\000\161\000\010\000\008\000\007\000\018\000\019\000\000\000\
\000\000\024\000\000\000\032\000\033\000\028\000\000\000\059\000\
\000\000\061\000\084\000\056\000\000\000\000\000\000\000\000\000\
\000\000\044\000\000\000\048\000\029\000\095\000\000\000\093\000\
\000\000\000\000\097\000\000\000\000\000\220\000\016\000\000\000\
\046\000\000\000\034\000\035\000\012\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\050\000\042\000\040\000\041\000\000\000\039\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\221\000\000\000\
\015\000\106\000\000\000\000\000\000\000\058\000\000\000\072\000\
\076\000\073\000\074\000\075\000\071\000\078\000\088\000\000\000\
\000\000\000\000\082\000\000\000\090\000\037\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\102\000\000\000\000\000\000\000\
\000\000\014\000\000\000\065\000\066\000\000\000\000\000\085\000\
\086\000\083\000\104\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\143\000\000\000\000\000\
\138\000\139\000\140\000\141\000\000\000\120\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\147\000\000\000\
\129\000\148\000\127\000\000\000\000\000\000\000\000\000\116\000\
\100\000\101\000\000\000\000\000\098\000\062\000\000\000\087\000\
\154\000\000\000\000\000\000\000\155\000\157\000\000\000\000\000\
\000\000\000\000\000\000\142\000\000\000\000\000\000\000\128\000\
\122\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\126\000\000\000\000\000\
\000\000\000\000\000\000\131\000\130\000\144\000\145\000\103\000\
\000\000\000\000\000\000\000\000\151\000\159\000\156\000\158\000\
\000\000\153\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\132\000\133\000\118\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\170\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\199\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\193\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\167\000\000\000\000\000\000\000\000\000\000\000\
\169\000\124\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\201\000\
\202\000\204\000\203\000\195\000\197\000\198\000\200\000\196\000\
\194\000\208\000\209\000\000\000\000\000\000\000\000\000\135\000\
\137\000\134\000\136\000\108\000\000\000\000\000\000\000\000\000\
\068\000\060\000\000\000\000\000\163\000\166\000\165\000\164\000\
\123\000\125\000\000\000\171\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\112\000\000\000\000\000\110\000\000\000\
\000\000\000\000\000\000\000\000\215\000\216\000\213\000\000\000\
\000\000\000\000\000\000\000\000\000\000\113\000\114\000\000\000\
\000\000\000\000\150\000\000\000\217\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\146\000"

let yydgoto = "\005\000\
\023\000\037\000\039\000\041\000\042\000\024\000\025\000\026\000\
\027\000\028\000\029\000\030\000\031\000\064\000\065\000\072\000\
\073\000\088\000\182\000\079\000\080\000\183\000\124\001\167\000\
\227\000\191\000\192\000\009\001\206\000\061\001\003\001\004\001\
\138\001\084\001\110\001\091\000\179\000\140\000\066\000\032\000\
\209\000\033\000\034\000\035\000\048\000\075\000\121\000\170\000\
\157\000\215\000\153\000\111\000\113\000\182\001\080\001\039\001\
\082\001\027\001\150\001\111\001"

let yysindex = "\173\001\
\121\020\128\254\005\255\185\254\000\000\200\254\213\254\233\254\
\240\254\239\254\244\254\022\255\037\255\050\255\053\255\056\255\
\059\255\060\255\062\255\064\255\068\255\069\255\000\000\130\255\
\130\255\130\255\017\255\139\255\139\255\000\000\121\020\000\000\
\000\000\000\000\118\255\152\255\000\000\077\255\000\000\072\255\
\000\000\000\000\087\255\092\255\000\000\094\255\090\255\103\255\
\109\255\109\255\116\255\121\255\000\000\122\255\125\255\132\255\
\133\255\140\255\151\255\153\255\156\255\157\255\090\255\000\000\
\130\255\130\255\182\255\189\255\165\255\166\255\179\255\190\255\
\017\255\201\255\069\001\223\255\000\000\206\255\139\255\202\255\
\202\255\227\255\144\255\211\255\214\255\000\000\224\255\225\255\
\237\255\109\255\243\255\243\255\241\255\002\000\007\000\008\000\
\202\255\010\000\011\000\012\000\001\000\000\000\014\000\017\000\
\000\000\095\000\000\000\000\000\035\000\000\000\034\000\000\000\
\075\000\000\000\000\000\118\255\068\000\229\254\000\000\069\000\
\000\000\000\000\034\000\069\001\059\000\000\000\000\000\202\255\
\148\000\128\254\080\000\082\000\109\255\109\255\000\000\089\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\094\000\
\094\000\000\000\109\255\000\000\000\000\000\000\202\255\000\000\
\034\000\000\000\000\000\000\000\108\255\202\255\139\255\098\000\
\104\000\000\000\105\000\000\000\000\000\000\000\108\000\000\000\
\109\000\165\000\000\000\061\255\206\254\000\000\000\000\186\000\
\000\000\094\000\000\000\000\000\000\000\191\000\101\255\217\000\
\133\000\146\000\202\255\202\255\202\255\202\255\108\255\111\255\
\108\255\000\000\000\000\000\000\000\000\059\000\000\000\118\255\
\094\000\109\024\061\255\160\000\161\000\198\000\000\000\109\255\
\000\000\000\000\169\000\202\255\202\255\000\000\170\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\176\000\
\183\000\190\000\000\000\111\255\000\000\000\000\061\255\195\255\
\194\000\195\000\202\000\206\000\210\000\214\000\216\000\223\000\
\224\000\109\255\233\000\233\000\233\000\109\255\225\000\228\000\
\229\000\232\000\202\255\236\000\109\255\202\255\238\000\239\000\
\243\000\248\000\057\001\109\024\000\000\061\255\061\255\251\000\
\081\001\000\000\253\000\000\000\000\000\001\001\007\001\000\000\
\000\000\000\000\000\000\195\255\195\255\008\001\009\001\010\001\
\011\001\018\001\025\255\019\001\020\001\000\000\021\001\022\001\
\000\000\000\000\000\000\000\000\033\001\000\000\102\001\024\001\
\102\001\119\255\039\001\044\001\047\001\048\001\000\000\202\255\
\000\000\000\000\000\000\202\255\202\255\051\001\061\255\000\000\
\000\000\000\000\054\001\202\255\000\000\000\000\202\255\000\000\
\000\000\143\255\061\001\068\001\000\000\000\000\078\001\195\255\
\195\255\166\001\082\001\000\000\247\254\247\254\109\255\000\000\
\000\000\024\001\086\001\119\255\024\001\233\000\008\255\008\255\
\008\255\090\001\008\255\092\001\008\255\008\255\008\255\008\255\
\099\001\100\001\101\001\104\001\105\001\108\001\008\255\008\255\
\008\255\008\255\008\255\008\255\008\255\000\000\119\255\119\255\
\119\255\119\255\119\255\000\000\000\000\000\000\000\000\000\000\
\109\255\238\254\182\001\017\255\000\000\000\000\000\000\000\000\
\217\001\000\000\109\024\115\001\247\254\118\001\008\255\119\001\
\124\001\000\000\000\000\000\000\119\255\024\001\247\254\119\255\
\126\001\008\255\008\255\008\255\000\000\166\024\166\024\166\024\
\197\001\166\024\128\001\195\024\205\024\021\025\031\025\202\255\
\129\001\130\001\000\000\131\001\133\001\051\255\060\025\132\025\
\166\024\166\024\166\024\214\025\000\000\033\001\033\001\033\001\
\033\001\198\000\202\255\138\001\139\001\109\024\202\255\211\001\
\212\001\142\001\000\000\247\254\034\024\247\254\247\254\247\254\
\000\000\000\000\247\254\136\001\189\000\241\023\006\026\008\255\
\008\255\008\255\008\255\008\255\008\255\008\255\008\255\008\255\
\008\255\008\255\008\255\008\255\008\255\008\255\008\255\008\255\
\008\255\166\024\166\024\006\026\008\255\006\026\137\001\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\006\026\006\026\006\026\119\255\000\000\
\000\000\000\000\000\000\000\000\238\254\143\001\152\001\081\001\
\000\000\000\000\254\001\154\001\000\000\000\000\000\000\000\000\
\000\000\000\000\141\001\000\000\227\025\019\026\247\020\189\000\
\189\000\189\000\189\000\189\000\006\026\006\026\006\026\006\026\
\006\026\006\026\194\255\194\255\101\000\101\000\166\024\142\025\
\006\026\156\001\227\001\000\000\202\255\202\255\000\000\000\002\
\176\001\163\001\008\255\006\026\000\000\000\000\000\000\238\254\
\238\254\109\024\179\001\180\001\090\000\000\000\000\000\252\001\
\183\001\170\001\000\000\186\001\000\000\189\001\193\001\200\001\
\210\001\215\001\202\255\216\001\202\255\220\001\202\255\000\000"

let yyrindex = "\000\000\
\082\003\084\003\000\000\091\003\000\000\000\000\000\000\000\000\
\000\000\233\254\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\148\022\
\047\002\047\002\048\002\120\001\051\002\000\000\082\003\000\000\
\000\000\000\000\213\255\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\116\022\053\255\000\000\
\224\254\224\254\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\053\255\000\000\
\230\018\047\002\000\000\000\000\000\000\000\000\009\002\000\000\
\174\019\000\000\000\000\000\000\000\000\000\000\120\001\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\005\012\038\255\038\255\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\037\019\000\000\
\000\000\000\000\000\000\213\255\000\000\201\022\000\000\000\000\
\000\000\000\000\102\000\000\000\120\010\000\000\000\000\000\000\
\083\003\084\003\000\000\091\003\233\022\204\021\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\030\023\
\030\023\000\000\233\022\000\000\000\000\000\000\000\000\000\000\
\236\254\000\000\000\000\000\000\117\255\000\000\120\001\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\251\010\000\000\
\000\000\242\000\000\000\006\000\091\003\000\000\000\000\083\023\
\000\000\031\022\000\000\000\000\000\000\000\000\055\002\062\255\
\000\000\000\000\000\000\000\000\000\000\000\000\117\255\000\000\
\117\255\000\000\000\000\000\000\000\000\130\011\000\000\213\255\
\151\006\059\002\006\000\000\000\000\000\015\000\000\000\233\022\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\006\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\010\019\140\012\015\013\140\012\030\018\000\000\000\000\
\000\000\000\000\000\000\000\000\057\020\000\000\000\000\000\000\
\000\000\000\000\000\000\020\000\000\000\006\000\006\000\000\000\
\106\003\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\142\020\000\000\141\013\150\017\
\141\013\240\020\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\006\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\069\021\069\021\057\020\000\000\
\000\000\150\017\000\000\210\019\150\017\247\001\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\157\018\110\019\
\110\019\110\019\110\019\000\000\000\000\000\000\000\000\000\000\
\016\000\239\021\113\255\048\002\000\000\000\000\000\000\000\000\
\251\254\000\000\059\002\000\000\069\021\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\210\019\150\017\069\021\210\019\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\142\020\142\020\142\020\
\142\020\015\000\000\000\000\000\000\000\021\000\000\000\000\000\
\000\000\000\000\000\000\069\021\069\021\069\021\069\021\069\021\
\000\000\000\000\069\021\000\000\018\000\000\000\223\006\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\013\014\000\000\148\014\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\020\015\146\015\021\016\065\002\000\000\
\000\000\000\000\000\000\000\000\239\021\000\000\000\000\106\003\
\000\000\000\000\154\021\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\092\006\216\005\177\000\
\055\001\187\001\063\002\195\002\099\007\230\007\106\008\237\008\
\113\009\244\009\209\004\085\005\202\003\078\004\000\000\000\000\
\153\016\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\023\017\000\000\000\000\000\000\239\021\
\239\021\059\002\000\000\000\000\071\003\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"

let yygindex = "\000\000\
\000\000\237\002\000\000\000\000\158\255\000\000\000\000\000\000\
\000\000\000\000\000\000\085\003\000\000\205\000\000\000\191\255\
\000\000\055\003\120\255\183\255\000\000\176\255\192\001\178\002\
\149\002\000\000\104\255\201\001\079\255\140\001\006\255\000\000\
\197\254\220\254\174\254\210\255\147\255\030\003\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\232\255\001\003\000\000\
\173\255\000\000\000\000\000\000\000\000\110\254\070\000\039\255\
\089\002\030\255\061\023\000\000"

let yytablesize = 7022
let yytable = "\129\000\
\130\000\143\001\036\000\092\000\076\000\099\000\152\000\115\000\
\160\000\056\001\055\000\152\000\160\000\069\000\107\000\160\000\
\146\000\177\000\139\001\115\000\115\000\146\001\133\001\147\001\
\179\001\005\001\040\001\041\001\173\001\174\001\175\001\176\001\
\177\001\174\000\038\000\180\000\072\001\073\001\222\000\164\000\
\228\000\160\000\159\000\138\000\040\000\141\001\070\000\168\000\
\144\001\065\001\066\001\200\001\162\000\019\001\124\000\160\000\
\047\000\069\000\192\001\043\000\071\000\195\001\201\001\202\001\
\134\001\040\000\135\001\136\001\210\000\184\000\201\000\202\000\
\044\000\187\001\207\000\012\001\013\001\193\000\009\000\083\000\
\148\001\203\000\009\000\194\001\057\001\058\001\175\000\176\000\
\161\000\204\000\070\000\231\000\045\000\180\001\181\001\055\000\
\203\001\160\000\028\002\046\000\181\000\129\001\130\001\049\000\
\071\000\193\001\218\000\219\000\220\000\221\000\137\001\009\000\
\152\000\204\001\205\001\206\001\207\001\208\001\209\001\210\001\
\211\001\212\001\213\001\149\001\145\001\009\000\230\000\086\001\
\253\001\254\001\255\001\000\002\001\002\120\001\194\000\002\002\
\185\001\050\000\214\001\215\001\216\001\217\001\074\001\087\001\
\088\001\205\000\212\000\213\000\061\000\046\002\047\002\185\000\
\051\000\067\000\072\001\073\001\027\002\067\000\223\000\125\001\
\089\001\010\001\062\000\224\000\077\000\052\000\125\000\186\000\
\053\000\077\000\047\001\054\000\225\000\050\001\055\000\056\000\
\176\000\057\000\077\000\058\000\126\000\127\000\128\000\059\000\
\060\000\074\000\067\000\248\001\187\000\188\000\189\000\078\000\
\082\000\090\001\200\001\037\001\091\001\081\000\226\000\042\001\
\067\000\083\000\084\000\063\000\077\000\092\001\049\001\085\000\
\020\001\086\000\021\001\087\000\093\001\094\001\095\001\096\001\
\097\001\190\000\089\000\098\001\099\001\100\001\101\001\116\001\
\090\000\102\001\107\000\117\001\118\001\067\000\068\000\093\000\
\103\001\108\000\114\000\122\001\094\000\095\000\123\001\203\001\
\096\000\104\001\105\001\106\001\107\001\108\001\109\001\097\000\
\098\000\022\001\023\001\024\001\025\001\026\001\131\000\099\000\
\204\001\205\001\206\001\207\001\208\001\209\001\210\001\211\001\
\212\001\213\001\100\000\122\000\101\000\105\000\106\000\102\000\
\103\000\132\000\177\000\177\000\177\000\177\000\177\000\177\000\
\109\000\110\000\177\000\216\001\217\001\177\000\177\000\177\000\
\140\001\177\000\177\000\177\000\099\000\177\000\112\000\177\000\
\177\000\177\000\177\000\177\000\177\000\107\000\160\000\048\002\
\177\000\177\000\115\000\115\000\177\000\177\000\180\000\177\000\
\177\000\177\000\184\001\177\000\116\000\125\000\177\000\177\000\
\115\000\123\000\177\000\177\000\177\000\177\000\133\000\177\000\
\047\000\134\000\178\001\126\000\127\000\128\000\177\000\228\001\
\177\000\177\000\177\000\177\000\136\000\233\001\047\000\047\000\
\047\000\099\000\177\000\177\000\177\000\177\000\177\000\177\000\
\137\000\135\000\245\001\160\000\142\000\200\001\123\001\177\000\
\177\000\177\000\177\000\177\000\177\000\177\000\177\000\177\000\
\177\000\177\000\177\000\177\000\139\000\143\000\177\000\177\000\
\177\000\177\000\144\000\145\000\177\000\147\000\148\000\149\000\
\177\000\151\000\150\000\177\000\152\000\177\000\177\000\203\001\
\177\000\177\000\177\000\154\000\177\000\177\000\177\000\177\000\
\177\000\177\000\203\001\177\000\177\000\177\000\155\000\156\000\
\204\001\205\001\206\001\207\001\208\001\209\001\210\001\211\001\
\212\001\213\001\158\000\204\001\205\001\206\001\207\001\208\001\
\209\001\210\001\211\001\212\001\213\001\001\000\002\000\003\000\
\004\000\176\000\176\000\176\000\176\000\176\000\176\000\160\000\
\163\000\176\000\181\000\166\000\176\000\176\000\176\000\169\000\
\176\000\176\000\176\000\172\000\176\000\173\000\176\000\176\000\
\176\000\176\000\176\000\176\000\040\002\041\002\177\000\176\000\
\176\000\178\000\200\000\176\000\176\000\195\000\176\000\176\000\
\176\000\055\000\176\000\196\000\197\000\176\000\176\000\198\000\
\199\000\176\000\176\000\176\000\176\000\208\000\176\000\055\000\
\055\000\055\000\060\002\211\000\062\002\176\000\064\002\176\000\
\176\000\176\000\176\000\240\001\241\001\242\001\243\001\214\000\
\216\000\176\000\176\000\176\000\176\000\176\000\176\000\208\001\
\209\001\210\001\211\001\212\001\213\001\217\000\176\000\176\000\
\176\000\176\000\176\000\176\000\176\000\176\000\176\000\176\000\
\176\000\176\000\176\000\006\001\007\001\176\000\176\000\176\000\
\176\000\008\001\036\000\176\000\011\001\014\001\036\000\176\000\
\036\000\036\000\176\000\015\001\176\000\176\000\036\000\176\000\
\176\000\176\000\016\001\176\000\176\000\176\000\176\000\176\000\
\176\000\017\001\176\000\176\000\176\000\028\001\029\001\180\000\
\180\000\180\000\180\000\180\000\180\000\030\001\182\000\180\000\
\038\001\031\001\180\000\180\000\180\000\032\001\180\000\180\000\
\180\000\033\001\180\000\034\001\180\000\180\000\180\000\180\000\
\180\000\180\000\035\001\036\001\043\001\180\000\180\000\044\001\
\045\001\180\000\180\000\046\001\180\000\180\000\180\000\048\001\
\180\000\051\001\052\001\180\000\180\000\055\001\053\001\180\000\
\180\000\180\000\180\000\054\001\180\000\117\000\059\001\060\001\
\062\001\118\000\063\001\180\000\119\000\180\000\180\000\180\000\
\180\000\120\000\064\001\067\001\068\001\069\001\070\001\180\000\
\180\000\180\000\180\000\180\000\180\000\071\001\075\001\076\001\
\077\001\078\001\081\001\083\001\180\000\180\000\180\000\180\000\
\180\000\180\000\180\000\180\000\180\000\180\000\180\000\180\000\
\180\000\079\001\112\001\180\000\180\000\180\000\180\000\113\001\
\049\000\180\000\114\001\115\001\049\000\180\000\119\001\049\000\
\180\000\121\001\180\000\180\000\049\000\180\000\180\000\180\000\
\126\001\180\000\180\000\180\000\180\000\180\000\180\000\127\001\
\180\000\180\000\180\000\181\000\181\000\181\000\181\000\181\000\
\181\000\128\001\183\000\181\000\131\001\132\001\181\000\181\000\
\181\000\142\001\181\000\181\000\181\000\153\001\181\000\155\001\
\181\000\181\000\181\000\181\000\181\000\181\000\160\001\161\001\
\162\001\181\000\181\000\163\001\164\001\181\000\181\000\165\001\
\181\000\181\000\181\000\183\001\181\000\073\001\186\001\181\000\
\181\000\188\001\190\001\181\000\181\000\181\000\181\000\191\001\
\181\000\196\001\221\001\223\001\229\001\230\001\231\001\181\000\
\232\001\181\000\181\000\181\000\181\000\246\001\247\001\250\001\
\251\001\252\001\029\002\181\000\181\000\181\000\181\000\181\000\
\181\000\003\002\026\002\030\002\032\002\033\002\034\002\039\002\
\181\000\181\000\181\000\181\000\181\000\181\000\181\000\181\000\
\181\000\181\000\181\000\181\000\181\000\038\002\042\002\181\000\
\181\000\181\000\181\000\043\002\044\002\181\000\049\002\050\002\
\051\002\181\000\052\002\053\002\181\000\054\002\181\000\181\000\
\055\002\181\000\181\000\181\000\056\002\181\000\181\000\181\000\
\181\000\181\000\181\000\057\002\181\000\181\000\181\000\182\000\
\182\000\182\000\182\000\182\000\182\000\058\002\191\000\182\000\
\059\002\061\002\182\000\182\000\182\000\063\002\182\000\182\000\
\182\000\002\000\182\000\096\000\182\000\182\000\182\000\182\000\
\182\000\182\000\219\000\051\000\069\000\182\000\182\000\049\000\
\081\000\182\000\182\000\064\000\182\000\182\000\182\000\115\000\
\182\000\109\000\119\000\182\000\182\000\192\000\171\000\182\000\
\182\000\182\000\182\000\077\000\182\000\104\000\249\001\229\000\
\018\001\141\000\244\001\182\000\165\000\182\000\182\000\182\000\
\182\000\085\001\000\000\031\002\000\000\000\000\000\000\182\000\
\182\000\182\000\182\000\182\000\182\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\182\000\182\000\182\000\182\000\
\182\000\182\000\182\000\182\000\182\000\182\000\182\000\182\000\
\182\000\000\000\000\000\182\000\182\000\182\000\182\000\000\000\
\000\000\182\000\000\000\000\000\000\000\182\000\000\000\000\000\
\182\000\000\000\182\000\182\000\000\000\182\000\182\000\182\000\
\000\000\182\000\182\000\182\000\182\000\182\000\182\000\000\000\
\182\000\182\000\182\000\183\000\183\000\183\000\183\000\183\000\
\183\000\174\000\000\000\183\000\000\000\000\000\183\000\183\000\
\183\000\000\000\183\000\183\000\183\000\000\000\183\000\000\000\
\183\000\183\000\183\000\183\000\183\000\183\000\000\000\000\000\
\000\000\183\000\183\000\000\000\000\000\183\000\183\000\000\000\
\183\000\183\000\183\000\000\000\183\000\000\000\000\000\183\000\
\183\000\000\000\000\000\183\000\183\000\183\000\183\000\000\000\
\183\000\000\000\000\000\000\000\000\000\000\000\000\000\183\000\
\000\000\183\000\183\000\183\000\183\000\000\000\000\000\000\000\
\000\000\000\000\000\000\183\000\183\000\183\000\183\000\183\000\
\183\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\183\000\183\000\183\000\183\000\183\000\183\000\183\000\183\000\
\183\000\183\000\183\000\183\000\183\000\000\000\000\000\183\000\
\183\000\183\000\183\000\000\000\000\000\183\000\000\000\000\000\
\000\000\183\000\000\000\000\000\183\000\000\000\183\000\183\000\
\000\000\183\000\183\000\183\000\000\000\183\000\183\000\183\000\
\183\000\183\000\183\000\000\000\183\000\183\000\183\000\191\000\
\191\000\191\000\191\000\191\000\191\000\175\000\000\000\191\000\
\000\000\000\000\191\000\191\000\191\000\000\000\191\000\191\000\
\191\000\000\000\191\000\000\000\191\000\191\000\191\000\191\000\
\191\000\191\000\000\000\000\000\000\000\191\000\191\000\000\000\
\000\000\191\000\191\000\000\000\191\000\191\000\191\000\000\000\
\191\000\000\000\000\000\191\000\000\000\000\000\000\000\191\000\
\191\000\191\000\191\000\038\000\191\000\000\000\000\000\038\000\
\038\000\038\000\038\000\191\000\000\000\000\000\000\000\038\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\191\000\
\191\000\191\000\191\000\191\000\191\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\191\000\191\000\191\000\191\000\
\191\000\191\000\191\000\191\000\191\000\191\000\191\000\191\000\
\191\000\000\000\000\000\191\000\191\000\191\000\191\000\000\000\
\000\000\191\000\000\000\000\000\000\000\191\000\000\000\000\000\
\191\000\000\000\191\000\191\000\000\000\191\000\191\000\191\000\
\000\000\191\000\191\000\191\000\191\000\191\000\191\000\000\000\
\191\000\191\000\191\000\174\000\174\000\174\000\174\000\174\000\
\172\000\000\000\174\000\000\000\000\000\174\000\174\000\174\000\
\000\000\174\000\174\000\174\000\000\000\174\000\000\000\174\000\
\174\000\174\000\174\000\174\000\174\000\000\000\000\000\000\000\
\174\000\174\000\000\000\000\000\174\000\174\000\000\000\174\000\
\174\000\174\000\000\000\174\000\000\000\000\000\174\000\000\000\
\000\000\000\000\174\000\174\000\174\000\174\000\000\000\174\000\
\000\000\000\000\000\000\000\000\000\000\000\000\174\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\174\000\174\000\174\000\174\000\174\000\174\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\174\000\
\174\000\174\000\174\000\174\000\174\000\174\000\174\000\174\000\
\174\000\174\000\174\000\174\000\000\000\000\000\174\000\174\000\
\174\000\174\000\000\000\000\000\174\000\000\000\000\000\000\000\
\174\000\000\000\000\000\174\000\000\000\174\000\174\000\000\000\
\174\000\174\000\174\000\000\000\174\000\174\000\174\000\174\000\
\174\000\174\000\000\000\174\000\174\000\174\000\000\000\175\000\
\175\000\175\000\175\000\175\000\173\000\000\000\175\000\000\000\
\000\000\175\000\175\000\175\000\000\000\175\000\175\000\175\000\
\000\000\175\000\000\000\175\000\175\000\175\000\175\000\175\000\
\175\000\000\000\000\000\000\000\175\000\175\000\000\000\000\000\
\175\000\175\000\000\000\175\000\175\000\175\000\000\000\175\000\
\000\000\000\000\175\000\000\000\000\000\000\000\175\000\175\000\
\175\000\175\000\000\000\175\000\000\000\000\000\000\000\000\000\
\000\000\000\000\175\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\175\000\175\000\
\175\000\175\000\175\000\175\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\175\000\175\000\175\000\175\000\175\000\
\175\000\175\000\175\000\175\000\175\000\175\000\175\000\175\000\
\000\000\000\000\175\000\175\000\175\000\175\000\000\000\000\000\
\175\000\000\000\000\000\000\000\175\000\000\000\000\000\175\000\
\000\000\175\000\175\000\000\000\175\000\175\000\175\000\000\000\
\175\000\175\000\175\000\175\000\175\000\175\000\000\000\175\000\
\175\000\175\000\172\000\172\000\172\000\172\000\172\000\179\000\
\000\000\172\000\000\000\000\000\172\000\172\000\172\000\000\000\
\172\000\172\000\172\000\000\000\172\000\000\000\172\000\172\000\
\172\000\172\000\172\000\172\000\000\000\000\000\000\000\172\000\
\172\000\000\000\000\000\172\000\172\000\000\000\172\000\172\000\
\172\000\000\000\172\000\000\000\000\000\172\000\000\000\000\000\
\000\000\172\000\172\000\172\000\172\000\000\000\172\000\000\000\
\000\000\000\000\000\000\000\000\000\000\172\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\172\000\172\000\172\000\172\000\172\000\172\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\172\000\172\000\
\172\000\172\000\000\000\000\000\172\000\172\000\172\000\172\000\
\172\000\172\000\172\000\000\000\000\000\172\000\172\000\172\000\
\172\000\000\000\000\000\172\000\000\000\000\000\000\000\172\000\
\000\000\000\000\172\000\000\000\172\000\172\000\000\000\172\000\
\172\000\172\000\000\000\172\000\172\000\172\000\172\000\172\000\
\172\000\000\000\172\000\172\000\172\000\000\000\173\000\173\000\
\173\000\173\000\173\000\178\000\000\000\173\000\000\000\000\000\
\173\000\173\000\173\000\000\000\173\000\173\000\173\000\000\000\
\173\000\000\000\173\000\173\000\173\000\173\000\173\000\173\000\
\000\000\000\000\000\000\173\000\173\000\000\000\000\000\173\000\
\173\000\000\000\173\000\173\000\173\000\000\000\173\000\000\000\
\000\000\173\000\000\000\000\000\000\000\173\000\173\000\173\000\
\173\000\000\000\173\000\000\000\000\000\000\000\000\000\000\000\
\000\000\173\000\000\000\000\000\000\000\000\000\105\000\000\000\
\000\000\000\000\000\000\000\000\000\000\173\000\173\000\173\000\
\173\000\173\000\173\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\173\000\173\000\173\000\173\000\000\000\000\000\
\173\000\173\000\173\000\173\000\173\000\173\000\173\000\000\000\
\000\000\173\000\173\000\173\000\173\000\000\000\000\000\173\000\
\000\000\000\000\000\000\173\000\000\000\000\000\173\000\000\000\
\173\000\173\000\000\000\173\000\173\000\173\000\000\000\173\000\
\173\000\173\000\173\000\173\000\173\000\000\000\173\000\173\000\
\173\000\179\000\179\000\179\000\179\000\179\000\186\000\000\000\
\179\000\000\000\000\000\179\000\179\000\179\000\000\000\179\000\
\179\000\179\000\000\000\179\000\000\000\179\000\179\000\179\000\
\179\000\179\000\179\000\000\000\000\000\000\000\179\000\179\000\
\000\000\000\000\179\000\179\000\000\000\179\000\179\000\179\000\
\000\000\179\000\000\000\000\000\179\000\000\000\000\000\000\000\
\179\000\179\000\179\000\179\000\000\000\179\000\000\000\000\000\
\000\000\000\000\000\000\000\000\179\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\179\000\179\000\179\000\179\000\179\000\179\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\179\000\179\000\000\000\
\000\000\000\000\000\000\179\000\179\000\179\000\179\000\179\000\
\179\000\179\000\000\000\000\000\179\000\179\000\179\000\179\000\
\000\000\000\000\179\000\000\000\000\000\000\000\179\000\000\000\
\000\000\179\000\000\000\179\000\179\000\000\000\179\000\179\000\
\179\000\000\000\179\000\179\000\179\000\179\000\179\000\179\000\
\000\000\179\000\179\000\179\000\000\000\178\000\178\000\178\000\
\178\000\178\000\184\000\000\000\178\000\000\000\000\000\178\000\
\000\000\178\000\000\000\178\000\178\000\178\000\000\000\178\000\
\000\000\178\000\178\000\178\000\178\000\178\000\178\000\000\000\
\000\000\000\000\178\000\178\000\000\000\000\000\178\000\178\000\
\000\000\178\000\178\000\178\000\000\000\178\000\000\000\000\000\
\178\000\000\000\000\000\000\000\178\000\178\000\178\000\178\000\
\000\000\178\000\000\000\000\000\000\000\000\000\000\000\000\000\
\178\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\105\000\105\000\000\000\000\000\178\000\178\000\178\000\178\000\
\178\000\178\000\000\000\105\000\000\000\000\000\000\000\000\000\
\000\000\178\000\178\000\105\000\000\000\105\000\000\000\178\000\
\178\000\178\000\178\000\178\000\178\000\178\000\000\000\000\000\
\178\000\178\000\178\000\178\000\000\000\000\000\178\000\000\000\
\000\000\000\000\178\000\000\000\000\000\178\000\000\000\178\000\
\178\000\000\000\178\000\178\000\178\000\000\000\178\000\178\000\
\178\000\178\000\178\000\178\000\000\000\178\000\178\000\178\000\
\186\000\186\000\186\000\186\000\186\000\185\000\000\000\186\000\
\000\000\000\000\105\000\105\000\186\000\000\000\186\000\186\000\
\186\000\000\000\186\000\000\000\186\000\186\000\186\000\186\000\
\186\000\186\000\000\000\000\000\000\000\186\000\186\000\000\000\
\000\000\186\000\186\000\000\000\186\000\186\000\186\000\000\000\
\186\000\000\000\000\000\186\000\000\000\000\000\000\000\186\000\
\186\000\186\000\186\000\000\000\186\000\000\000\000\000\000\000\
\000\000\000\000\000\000\186\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\186\000\
\186\000\186\000\186\000\186\000\186\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\186\000\186\000\000\000\000\000\
\000\000\000\000\186\000\186\000\186\000\186\000\186\000\186\000\
\186\000\000\000\000\000\186\000\186\000\186\000\186\000\000\000\
\000\000\186\000\000\000\000\000\000\000\186\000\000\000\000\000\
\186\000\000\000\186\000\186\000\000\000\186\000\186\000\186\000\
\000\000\186\000\186\000\186\000\186\000\186\000\186\000\000\000\
\186\000\186\000\186\000\000\000\184\000\184\000\184\000\184\000\
\184\000\187\000\000\000\184\000\000\000\000\000\000\000\000\000\
\184\000\000\000\184\000\184\000\184\000\000\000\184\000\000\000\
\184\000\184\000\184\000\184\000\184\000\184\000\000\000\000\000\
\000\000\184\000\184\000\000\000\000\000\184\000\184\000\000\000\
\184\000\184\000\184\000\000\000\184\000\000\000\000\000\184\000\
\000\000\000\000\000\000\184\000\184\000\184\000\184\000\000\000\
\184\000\000\000\000\000\000\000\000\000\000\000\000\000\184\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\184\000\184\000\184\000\184\000\184\000\
\184\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\184\000\184\000\000\000\000\000\000\000\000\000\184\000\184\000\
\184\000\184\000\184\000\184\000\184\000\000\000\000\000\184\000\
\184\000\184\000\184\000\000\000\000\000\184\000\000\000\000\000\
\000\000\184\000\000\000\000\000\184\000\000\000\184\000\184\000\
\000\000\184\000\184\000\184\000\000\000\184\000\184\000\184\000\
\184\000\184\000\184\000\000\000\184\000\184\000\184\000\185\000\
\185\000\185\000\185\000\185\000\188\000\000\000\185\000\000\000\
\000\000\000\000\000\000\185\000\000\000\185\000\185\000\185\000\
\000\000\185\000\000\000\185\000\185\000\185\000\185\000\185\000\
\185\000\000\000\000\000\000\000\185\000\185\000\000\000\000\000\
\185\000\185\000\000\000\185\000\185\000\185\000\000\000\185\000\
\000\000\000\000\185\000\000\000\000\000\000\000\185\000\185\000\
\185\000\185\000\000\000\185\000\000\000\000\000\000\000\000\000\
\000\000\000\000\185\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\185\000\185\000\
\185\000\185\000\185\000\185\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\185\000\185\000\000\000\000\000\000\000\
\000\000\185\000\185\000\185\000\185\000\185\000\185\000\185\000\
\000\000\000\000\185\000\185\000\185\000\185\000\000\000\000\000\
\185\000\000\000\000\000\000\000\185\000\000\000\000\000\185\000\
\000\000\185\000\185\000\000\000\185\000\185\000\185\000\000\000\
\185\000\185\000\185\000\185\000\185\000\185\000\000\000\185\000\
\185\000\185\000\000\000\187\000\187\000\187\000\187\000\187\000\
\190\000\000\000\187\000\000\000\000\000\000\000\000\000\187\000\
\000\000\187\000\187\000\187\000\000\000\187\000\000\000\187\000\
\187\000\187\000\187\000\187\000\187\000\000\000\000\000\000\000\
\187\000\187\000\000\000\000\000\187\000\187\000\000\000\187\000\
\187\000\187\000\000\000\187\000\000\000\000\000\187\000\000\000\
\000\000\000\000\187\000\187\000\187\000\187\000\000\000\187\000\
\000\000\000\000\000\000\000\000\000\000\000\000\187\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\187\000\187\000\187\000\187\000\187\000\187\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\187\000\
\187\000\000\000\000\000\000\000\000\000\187\000\187\000\187\000\
\187\000\187\000\187\000\187\000\000\000\000\000\187\000\187\000\
\187\000\187\000\000\000\000\000\187\000\000\000\000\000\000\000\
\187\000\000\000\000\000\187\000\000\000\187\000\187\000\000\000\
\187\000\187\000\187\000\000\000\187\000\187\000\187\000\187\000\
\187\000\187\000\000\000\187\000\187\000\187\000\188\000\188\000\
\188\000\188\000\188\000\189\000\000\000\188\000\000\000\000\000\
\000\000\000\000\188\000\000\000\188\000\188\000\188\000\000\000\
\188\000\000\000\188\000\188\000\188\000\188\000\188\000\188\000\
\000\000\000\000\000\000\188\000\188\000\000\000\000\000\188\000\
\188\000\000\000\188\000\188\000\188\000\000\000\188\000\000\000\
\000\000\188\000\000\000\000\000\000\000\188\000\188\000\188\000\
\188\000\000\000\188\000\000\000\000\000\000\000\000\000\000\000\
\000\000\188\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\188\000\188\000\188\000\
\188\000\188\000\188\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\188\000\188\000\000\000\000\000\000\000\000\000\
\188\000\188\000\188\000\188\000\188\000\188\000\188\000\000\000\
\000\000\188\000\188\000\188\000\188\000\000\000\000\000\188\000\
\000\000\000\000\000\000\188\000\000\000\000\000\188\000\000\000\
\188\000\188\000\000\000\188\000\188\000\188\000\000\000\188\000\
\188\000\188\000\188\000\188\000\188\000\000\000\188\000\188\000\
\188\000\000\000\190\000\190\000\190\000\190\000\190\000\094\000\
\000\000\190\000\000\000\000\000\000\000\000\000\190\000\000\000\
\190\000\190\000\190\000\000\000\190\000\000\000\190\000\190\000\
\190\000\190\000\190\000\190\000\000\000\000\000\000\000\190\000\
\190\000\000\000\000\000\190\000\190\000\000\000\190\000\190\000\
\190\000\000\000\190\000\000\000\000\000\190\000\000\000\000\000\
\000\000\190\000\190\000\190\000\190\000\000\000\190\000\000\000\
\000\000\000\000\000\000\000\000\000\000\190\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\190\000\190\000\190\000\190\000\190\000\190\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\190\000\190\000\
\000\000\000\000\000\000\000\000\190\000\190\000\190\000\190\000\
\190\000\190\000\190\000\000\000\000\000\190\000\190\000\190\000\
\190\000\000\000\000\000\190\000\000\000\000\000\000\000\190\000\
\000\000\000\000\190\000\000\000\190\000\190\000\000\000\190\000\
\190\000\190\000\000\000\190\000\190\000\190\000\190\000\190\000\
\190\000\000\000\190\000\190\000\190\000\189\000\189\000\189\000\
\189\000\189\000\089\000\000\000\189\000\000\000\000\000\000\000\
\000\000\189\000\000\000\189\000\189\000\189\000\000\000\189\000\
\000\000\189\000\189\000\189\000\189\000\189\000\189\000\000\000\
\000\000\000\000\189\000\189\000\000\000\000\000\189\000\189\000\
\000\000\189\000\189\000\189\000\000\000\189\000\000\000\000\000\
\189\000\000\000\000\000\000\000\189\000\189\000\189\000\189\000\
\000\000\189\000\000\000\000\000\000\000\000\000\000\000\000\000\
\189\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\189\000\189\000\189\000\189\000\
\189\000\189\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\189\000\189\000\000\000\000\000\000\000\000\000\189\000\
\189\000\189\000\189\000\189\000\189\000\189\000\000\000\000\000\
\189\000\189\000\189\000\189\000\000\000\000\000\189\000\000\000\
\000\000\000\000\189\000\000\000\000\000\189\000\000\000\189\000\
\189\000\000\000\189\000\189\000\189\000\000\000\189\000\189\000\
\189\000\189\000\189\000\189\000\000\000\189\000\189\000\189\000\
\000\000\000\000\094\000\094\000\094\000\094\000\094\000\094\000\
\094\000\094\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\094\000\000\000\094\000\000\000\094\000\094\000\094\000\
\094\000\094\000\094\000\000\000\000\000\000\000\094\000\094\000\
\000\000\094\000\094\000\094\000\000\000\094\000\094\000\094\000\
\094\000\094\000\094\000\094\000\094\000\094\000\094\000\094\000\
\094\000\094\000\094\000\094\000\094\000\094\000\000\000\000\000\
\000\000\000\000\000\000\094\000\094\000\094\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\094\000\094\000\094\000\094\000\094\000\094\000\094\000\
\094\000\094\000\094\000\000\000\000\000\094\000\094\000\094\000\
\000\000\000\000\000\000\094\000\094\000\094\000\094\000\094\000\
\094\000\094\000\094\000\094\000\094\000\094\000\094\000\094\000\
\094\000\094\000\094\000\094\000\094\000\094\000\094\000\094\000\
\094\000\094\000\094\000\094\000\094\000\000\000\094\000\094\000\
\094\000\000\000\094\000\094\000\094\000\094\000\094\000\094\000\
\000\000\000\000\094\000\000\000\000\000\089\000\089\000\089\000\
\089\000\089\000\089\000\089\000\160\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\089\000\000\000\089\000\000\000\
\089\000\089\000\089\000\089\000\089\000\089\000\000\000\000\000\
\000\000\089\000\089\000\000\000\089\000\089\000\089\000\000\000\
\089\000\089\000\089\000\089\000\089\000\089\000\089\000\089\000\
\089\000\089\000\089\000\089\000\089\000\089\000\089\000\089\000\
\089\000\000\000\000\000\000\000\000\000\000\000\089\000\089\000\
\089\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\089\000\089\000\089\000\089\000\
\089\000\089\000\089\000\089\000\089\000\089\000\000\000\000\000\
\089\000\089\000\089\000\000\000\000\000\000\000\089\000\089\000\
\089\000\089\000\089\000\089\000\089\000\089\000\089\000\089\000\
\089\000\089\000\089\000\089\000\089\000\089\000\089\000\089\000\
\089\000\089\000\089\000\089\000\089\000\089\000\000\000\089\000\
\000\000\089\000\089\000\089\000\000\000\089\000\089\000\089\000\
\089\000\089\000\089\000\000\000\000\000\089\000\000\000\000\000\
\000\000\000\000\000\000\000\000\094\000\094\000\094\000\094\000\
\094\000\094\000\094\000\119\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\094\000\000\000\094\000\000\000\094\000\
\094\000\094\000\094\000\094\000\094\000\000\000\000\000\000\000\
\094\000\094\000\000\000\094\000\094\000\094\000\000\000\094\000\
\094\000\094\000\094\000\094\000\094\000\094\000\094\000\094\000\
\094\000\094\000\094\000\094\000\094\000\094\000\094\000\094\000\
\000\000\000\000\000\000\000\000\000\000\094\000\094\000\094\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\094\000\094\000\094\000\094\000\094\000\
\094\000\094\000\094\000\094\000\094\000\000\000\000\000\094\000\
\094\000\094\000\000\000\000\000\000\000\094\000\094\000\094\000\
\094\000\094\000\094\000\094\000\094\000\094\000\094\000\094\000\
\094\000\094\000\094\000\094\000\094\000\094\000\094\000\094\000\
\094\000\094\000\094\000\094\000\094\000\000\000\094\000\000\000\
\094\000\094\000\094\000\000\000\094\000\094\000\094\000\094\000\
\094\000\094\000\000\000\000\000\094\000\000\000\000\000\160\000\
\160\000\160\000\160\000\160\000\160\000\160\000\119\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\160\000\000\000\
\160\000\000\000\160\000\160\000\160\000\160\000\160\000\160\000\
\000\000\000\000\000\000\160\000\000\000\000\000\160\000\160\000\
\160\000\000\000\160\000\160\000\160\000\160\000\160\000\000\000\
\160\000\160\000\000\000\000\000\000\000\160\000\160\000\160\000\
\160\000\000\000\160\000\000\000\000\000\000\000\000\000\000\000\
\000\000\160\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\160\000\160\000\
\000\000\000\000\160\000\160\000\160\000\000\000\000\000\000\000\
\160\000\000\000\160\000\160\000\160\000\000\000\000\000\000\000\
\160\000\160\000\160\000\160\000\160\000\160\000\160\000\160\000\
\160\000\160\000\160\000\160\000\160\000\160\000\160\000\160\000\
\160\000\160\000\000\000\160\000\000\000\000\000\160\000\160\000\
\000\000\160\000\000\000\160\000\000\000\160\000\000\000\160\000\
\160\000\160\000\160\000\160\000\160\000\000\000\160\000\000\000\
\000\000\000\000\000\000\000\000\121\000\000\000\119\000\119\000\
\119\000\119\000\000\000\000\000\119\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\119\000\000\000\119\000\
\000\000\119\000\119\000\119\000\119\000\119\000\119\000\000\000\
\000\000\000\000\119\000\119\000\000\000\000\000\119\000\119\000\
\119\000\119\000\119\000\119\000\000\000\119\000\000\000\000\000\
\119\000\000\000\000\000\000\000\119\000\119\000\119\000\119\000\
\000\000\119\000\000\000\000\000\000\000\000\000\000\000\000\000\
\119\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\119\000\119\000\119\000\
\119\000\119\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\119\000\119\000\000\000\000\000\000\000\000\000\119\000\
\119\000\119\000\119\000\119\000\119\000\119\000\000\000\000\000\
\119\000\119\000\119\000\119\000\000\000\000\000\119\000\000\000\
\000\000\000\000\119\000\000\000\000\000\119\000\000\000\119\000\
\119\000\000\000\119\000\119\000\000\000\000\000\119\000\119\000\
\119\000\119\000\119\000\119\000\211\000\000\000\000\000\000\000\
\000\000\119\000\119\000\119\000\119\000\000\000\000\000\119\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\119\000\000\000\119\000\000\000\119\000\119\000\119\000\119\000\
\119\000\119\000\000\000\000\000\000\000\119\000\119\000\000\000\
\000\000\119\000\119\000\000\000\119\000\119\000\119\000\000\000\
\119\000\000\000\000\000\119\000\000\000\000\000\000\000\119\000\
\119\000\119\000\119\000\000\000\119\000\000\000\000\000\000\000\
\000\000\000\000\000\000\119\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\119\000\119\000\119\000\119\000\119\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\119\000\119\000\000\000\000\000\
\000\000\000\000\119\000\119\000\119\000\119\000\119\000\119\000\
\119\000\000\000\000\000\119\000\119\000\119\000\119\000\000\000\
\000\000\119\000\000\000\000\000\000\000\119\000\000\000\000\000\
\119\000\000\000\119\000\119\000\000\000\119\000\119\000\000\000\
\000\000\119\000\119\000\119\000\119\000\119\000\119\000\121\000\
\121\000\121\000\121\000\210\000\000\000\121\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\121\000\000\000\
\121\000\000\000\121\000\121\000\121\000\121\000\121\000\121\000\
\000\000\000\000\000\000\121\000\121\000\000\000\000\000\121\000\
\121\000\000\000\121\000\121\000\121\000\000\000\121\000\000\000\
\000\000\121\000\000\000\000\000\000\000\121\000\121\000\121\000\
\121\000\000\000\121\000\000\000\000\000\000\000\000\000\000\000\
\000\000\121\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\121\000\121\000\
\121\000\121\000\121\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\121\000\121\000\000\000\000\000\000\000\000\000\
\121\000\121\000\121\000\121\000\121\000\121\000\121\000\000\000\
\000\000\121\000\121\000\121\000\121\000\000\000\000\000\121\000\
\000\000\000\000\000\000\121\000\000\000\000\000\121\000\000\000\
\121\000\121\000\000\000\121\000\121\000\000\000\000\000\121\000\
\121\000\121\000\121\000\121\000\121\000\000\000\000\000\211\000\
\211\000\211\000\211\000\205\000\000\000\211\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\211\000\000\000\
\211\000\000\000\211\000\211\000\211\000\211\000\211\000\211\000\
\000\000\000\000\000\000\211\000\211\000\000\000\000\000\211\000\
\211\000\000\000\211\000\211\000\211\000\000\000\211\000\000\000\
\000\000\211\000\000\000\000\000\000\000\211\000\211\000\211\000\
\211\000\000\000\211\000\000\000\000\000\000\000\000\000\000\000\
\000\000\211\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\211\000\211\000\
\211\000\211\000\211\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\211\000\211\000\000\000\000\000\000\000\000\000\
\211\000\211\000\211\000\211\000\211\000\211\000\211\000\000\000\
\000\000\211\000\211\000\211\000\211\000\000\000\000\000\211\000\
\000\000\000\000\000\000\211\000\000\000\000\000\211\000\000\000\
\000\000\211\000\000\000\211\000\211\000\211\000\000\000\211\000\
\211\000\211\000\211\000\211\000\211\000\000\000\000\000\000\000\
\000\000\207\000\000\000\000\000\000\000\000\000\210\000\210\000\
\210\000\210\000\000\000\000\000\210\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\210\000\000\000\210\000\
\000\000\210\000\210\000\210\000\210\000\210\000\210\000\000\000\
\000\000\000\000\210\000\210\000\000\000\000\000\210\000\210\000\
\000\000\210\000\210\000\210\000\000\000\210\000\000\000\000\000\
\210\000\000\000\000\000\000\000\210\000\210\000\210\000\210\000\
\000\000\210\000\000\000\000\000\000\000\000\000\000\000\000\000\
\210\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\210\000\210\000\210\000\
\210\000\210\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\210\000\210\000\000\000\000\000\000\000\000\000\210\000\
\210\000\210\000\210\000\210\000\210\000\210\000\000\000\000\000\
\210\000\210\000\210\000\210\000\000\000\000\000\210\000\000\000\
\000\000\000\000\210\000\000\000\000\000\210\000\000\000\000\000\
\210\000\000\000\210\000\210\000\210\000\000\000\210\000\210\000\
\210\000\210\000\210\000\210\000\206\000\000\000\205\000\205\000\
\205\000\205\000\000\000\000\000\205\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\205\000\000\000\205\000\
\000\000\205\000\205\000\205\000\205\000\205\000\205\000\000\000\
\000\000\000\000\205\000\205\000\000\000\000\000\205\000\205\000\
\000\000\205\000\205\000\205\000\000\000\205\000\000\000\000\000\
\205\000\000\000\000\000\000\000\205\000\205\000\205\000\205\000\
\000\000\205\000\000\000\000\000\000\000\000\000\000\000\000\000\
\205\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\205\000\205\000\205\000\
\205\000\205\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\205\000\205\000\000\000\000\000\000\000\000\000\205\000\
\205\000\205\000\205\000\205\000\205\000\205\000\000\000\000\000\
\205\000\205\000\205\000\205\000\000\000\000\000\205\000\000\000\
\000\000\000\000\205\000\000\000\000\000\205\000\000\000\000\000\
\205\000\000\000\205\000\205\000\205\000\000\000\205\000\205\000\
\205\000\205\000\205\000\205\000\207\000\207\000\207\000\207\000\
\212\000\000\000\207\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\207\000\000\000\207\000\000\000\207\000\
\207\000\207\000\207\000\207\000\207\000\000\000\000\000\000\000\
\207\000\207\000\000\000\000\000\207\000\207\000\000\000\207\000\
\207\000\207\000\000\000\207\000\000\000\000\000\207\000\000\000\
\000\000\000\000\207\000\207\000\207\000\207\000\000\000\207\000\
\000\000\000\000\000\000\000\000\000\000\000\000\207\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\207\000\207\000\207\000\207\000\207\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\207\000\
\207\000\000\000\000\000\000\000\000\000\207\000\207\000\207\000\
\207\000\207\000\207\000\207\000\000\000\000\000\207\000\207\000\
\207\000\207\000\000\000\000\000\207\000\000\000\000\000\000\000\
\207\000\000\000\000\000\207\000\000\000\000\000\207\000\000\000\
\207\000\207\000\207\000\000\000\207\000\207\000\207\000\207\000\
\207\000\207\000\000\000\000\000\000\000\000\000\214\000\206\000\
\206\000\206\000\206\000\000\000\000\000\206\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\206\000\000\000\
\206\000\000\000\206\000\206\000\206\000\206\000\206\000\206\000\
\000\000\000\000\000\000\206\000\206\000\000\000\000\000\206\000\
\206\000\000\000\206\000\206\000\206\000\000\000\206\000\000\000\
\000\000\206\000\000\000\000\000\000\000\206\000\206\000\206\000\
\206\000\000\000\206\000\000\000\000\000\000\000\000\000\000\000\
\000\000\206\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\206\000\206\000\
\206\000\206\000\206\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\206\000\206\000\000\000\000\000\000\000\000\000\
\206\000\206\000\206\000\206\000\206\000\206\000\206\000\000\000\
\000\000\206\000\206\000\206\000\206\000\000\000\000\000\206\000\
\000\000\000\000\000\000\206\000\000\000\000\000\206\000\000\000\
\000\000\206\000\000\000\206\000\206\000\206\000\000\000\206\000\
\206\000\206\000\206\000\206\000\206\000\168\000\000\000\000\000\
\000\000\000\000\000\000\212\000\212\000\212\000\212\000\000\000\
\000\000\212\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\212\000\000\000\212\000\000\000\212\000\212\000\
\212\000\212\000\212\000\212\000\000\000\000\000\000\000\212\000\
\212\000\000\000\000\000\212\000\212\000\000\000\212\000\212\000\
\212\000\000\000\212\000\000\000\000\000\212\000\000\000\000\000\
\000\000\212\000\212\000\212\000\212\000\000\000\212\000\000\000\
\000\000\000\000\000\000\000\000\000\000\212\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\212\000\212\000\212\000\212\000\212\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\212\000\212\000\
\000\000\000\000\000\000\000\000\212\000\212\000\212\000\212\000\
\212\000\212\000\212\000\000\000\000\000\212\000\212\000\212\000\
\212\000\000\000\000\000\212\000\000\000\000\000\000\000\212\000\
\000\000\000\000\212\000\000\000\000\000\212\000\000\000\212\000\
\212\000\212\000\000\000\212\000\212\000\212\000\212\000\212\000\
\212\000\214\000\214\000\214\000\214\000\160\000\000\000\214\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\214\000\000\000\214\000\000\000\214\000\214\000\214\000\214\000\
\214\000\214\000\000\000\000\000\000\000\214\000\214\000\000\000\
\000\000\214\000\214\000\000\000\214\000\214\000\214\000\000\000\
\214\000\000\000\000\000\214\000\000\000\000\000\000\000\214\000\
\214\000\214\000\214\000\000\000\214\000\000\000\000\000\000\000\
\000\000\000\000\000\000\214\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\214\000\214\000\214\000\214\000\214\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\214\000\214\000\000\000\000\000\
\000\000\000\000\214\000\214\000\214\000\214\000\214\000\214\000\
\214\000\000\000\000\000\214\000\214\000\214\000\214\000\000\000\
\000\000\214\000\000\000\000\000\000\000\214\000\000\000\000\000\
\214\000\000\000\000\000\214\000\000\000\214\000\214\000\214\000\
\000\000\214\000\214\000\214\000\214\000\214\000\214\000\000\000\
\168\000\168\000\168\000\168\000\192\000\000\000\168\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\168\000\
\000\000\168\000\000\000\168\000\168\000\168\000\168\000\168\000\
\168\000\000\000\000\000\000\000\168\000\168\000\000\000\000\000\
\168\000\168\000\000\000\168\000\168\000\168\000\000\000\168\000\
\000\000\000\000\168\000\000\000\000\000\000\000\168\000\168\000\
\168\000\168\000\000\000\168\000\000\000\000\000\000\000\000\000\
\000\000\000\000\168\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\168\000\
\168\000\168\000\168\000\168\000\000\000\051\000\000\000\000\000\
\000\000\000\000\000\000\168\000\168\000\000\000\000\000\000\000\
\000\000\168\000\168\000\168\000\168\000\168\000\168\000\168\000\
\000\000\000\000\168\000\168\000\168\000\168\000\000\000\000\000\
\168\000\000\000\000\000\000\000\168\000\000\000\000\000\168\000\
\000\000\160\000\168\000\000\000\168\000\168\000\000\000\000\000\
\168\000\168\000\168\000\168\000\168\000\168\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\160\000\160\000\160\000\160\000\000\000\000\000\160\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\160\000\
\000\000\160\000\000\000\160\000\160\000\160\000\160\000\160\000\
\160\000\000\000\000\000\000\000\160\000\000\000\000\000\000\000\
\160\000\160\000\000\000\160\000\160\000\160\000\000\000\160\000\
\000\000\000\000\160\000\000\000\000\000\000\000\160\000\160\000\
\160\000\160\000\000\000\160\000\000\000\000\000\000\000\000\000\
\000\000\000\000\160\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\160\000\000\000\000\000\160\000\000\000\192\000\000\000\000\000\
\000\000\000\000\000\000\160\000\160\000\000\000\000\000\000\000\
\000\000\160\000\160\000\160\000\160\000\160\000\160\000\160\000\
\000\000\000\000\160\000\160\000\160\000\160\000\000\000\000\000\
\160\000\000\000\000\000\000\000\160\000\000\000\000\000\160\000\
\000\000\000\000\160\000\000\000\160\000\000\000\000\000\000\000\
\160\000\160\000\160\000\160\000\160\000\160\000\000\000\192\000\
\192\000\192\000\192\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\069\000\192\000\000\000\
\192\000\000\000\192\000\192\000\192\000\000\000\000\000\192\000\
\000\000\000\000\000\000\192\000\192\000\000\000\000\000\192\000\
\192\000\000\000\192\000\192\000\192\000\000\000\000\000\000\000\
\000\000\192\000\000\000\000\000\000\000\192\000\192\000\192\000\
\192\000\192\000\192\000\000\000\000\000\000\000\000\000\000\000\
\000\000\192\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\192\000\000\000\
\192\000\192\000\000\000\000\000\051\000\051\000\000\000\000\000\
\000\000\000\000\192\000\000\000\000\000\000\000\000\000\051\000\
\192\000\192\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\051\000\000\000\000\000\051\000\
\000\000\000\000\000\000\192\000\160\000\160\000\160\000\160\000\
\000\000\192\000\051\000\192\000\192\000\192\000\051\000\000\000\
\051\000\000\000\000\000\160\000\000\000\160\000\000\000\160\000\
\160\000\160\000\000\000\000\000\160\000\000\000\000\000\000\000\
\160\000\000\000\000\000\000\000\160\000\160\000\000\000\160\000\
\160\000\160\000\000\000\000\000\051\000\051\000\160\000\000\000\
\160\000\000\000\160\000\160\000\160\000\160\000\000\000\160\000\
\000\000\000\000\000\000\000\000\000\000\000\000\160\000\051\000\
\051\000\051\000\000\000\000\000\000\000\000\000\051\000\051\000\
\055\000\051\000\051\000\000\000\055\000\000\000\000\000\000\000\
\051\000\055\000\000\000\000\000\000\000\000\000\000\000\160\000\
\055\000\000\000\055\000\000\000\000\000\160\000\160\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\192\000\192\000\192\000\192\000\000\000\055\000\055\000\055\000\
\160\000\000\000\000\000\000\000\055\000\000\000\160\000\192\000\
\160\000\192\000\160\000\192\000\192\000\192\000\000\000\000\000\
\192\000\000\000\000\000\000\000\192\000\117\000\000\000\000\000\
\192\000\192\000\055\000\192\000\192\000\192\000\000\000\000\000\
\000\000\000\000\192\000\000\000\000\000\000\000\192\000\192\000\
\192\000\192\000\000\000\192\000\000\000\000\000\000\000\000\000\
\000\000\000\000\192\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\069\000\069\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\069\000\
\000\000\000\000\000\000\192\000\000\000\000\000\000\000\000\000\
\000\000\192\000\192\000\000\000\069\000\000\000\000\000\069\000\
\000\000\000\000\000\000\000\000\192\000\192\000\192\000\192\000\
\000\000\000\000\069\000\000\000\192\000\000\000\069\000\000\000\
\069\000\000\000\192\000\192\000\192\000\192\000\192\000\192\000\
\192\000\192\000\000\000\000\000\192\000\000\000\000\000\192\000\
\192\000\192\000\000\000\000\000\192\000\192\000\000\000\192\000\
\192\000\192\000\000\000\000\000\069\000\069\000\192\000\000\000\
\000\000\000\000\192\000\192\000\192\000\192\000\000\000\192\000\
\000\000\000\000\000\000\000\000\000\000\000\000\192\000\069\000\
\069\000\069\000\000\000\000\000\000\000\000\000\069\000\069\000\
\000\000\069\000\069\000\192\000\000\000\192\000\192\000\000\000\
\069\000\000\000\000\000\000\000\000\000\000\000\000\000\192\000\
\000\000\000\000\000\000\000\000\000\000\192\000\192\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\160\000\160\000\160\000\160\000\000\000\
\192\000\000\000\000\000\000\000\162\000\000\000\192\000\000\000\
\192\000\192\000\160\000\000\000\160\000\000\000\160\000\160\000\
\160\000\000\000\000\000\160\000\000\000\000\000\000\000\160\000\
\000\000\000\000\000\000\160\000\160\000\000\000\160\000\160\000\
\160\000\000\000\000\000\000\000\000\000\160\000\000\000\000\000\
\000\000\160\000\160\000\160\000\160\000\000\000\160\000\000\000\
\000\000\000\000\000\000\000\000\000\000\160\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\006\000\
\007\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\008\000\000\000\000\000\000\000\160\000\000\000\
\117\000\117\000\117\000\117\000\160\000\160\000\000\000\009\000\
\000\000\149\000\010\000\000\000\000\000\000\000\000\000\117\000\
\000\000\117\000\000\000\117\000\117\000\117\000\000\000\160\000\
\117\000\011\000\000\000\012\000\117\000\160\000\000\000\160\000\
\117\000\117\000\000\000\117\000\117\000\117\000\000\000\000\000\
\000\000\000\000\117\000\000\000\000\000\000\000\117\000\117\000\
\117\000\117\000\000\000\117\000\000\000\000\000\000\000\013\000\
\014\000\000\000\117\000\160\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\015\000\016\000\017\000\000\000\000\000\000\000\
\000\000\018\000\019\000\117\000\020\000\021\000\000\000\000\000\
\000\000\117\000\117\000\022\000\000\000\000\000\111\000\000\000\
\000\000\000\000\192\000\192\000\192\000\192\000\000\000\200\001\
\000\000\000\000\000\000\000\000\117\000\000\000\000\000\000\000\
\000\000\192\000\117\000\192\000\117\000\192\000\192\000\192\000\
\000\000\000\000\192\000\000\000\000\000\000\000\192\000\000\000\
\000\000\000\000\192\000\192\000\000\000\192\000\192\000\192\000\
\000\000\000\000\000\000\000\000\192\000\000\000\105\000\000\000\
\192\000\192\000\192\000\192\000\203\001\192\000\000\000\000\000\
\000\000\000\000\000\000\000\000\192\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\204\001\205\001\206\001\
\207\001\208\001\209\001\210\001\211\001\212\001\213\001\000\000\
\000\000\000\000\000\000\000\000\000\000\192\000\000\000\162\000\
\162\000\162\000\162\000\192\000\192\000\000\000\214\001\215\001\
\216\001\217\001\000\000\000\000\000\000\000\000\162\000\000\000\
\162\000\000\000\162\000\162\000\162\000\000\000\192\000\162\000\
\000\000\000\000\000\000\162\000\192\000\000\000\192\000\162\000\
\162\000\000\000\162\000\162\000\162\000\000\000\000\000\000\000\
\000\000\162\000\000\000\004\000\000\000\162\000\162\000\162\000\
\162\000\000\000\162\000\000\000\000\000\000\000\000\000\000\000\
\000\000\162\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\051\000\000\000\000\000\000\000\000\000\
\000\000\000\000\162\000\000\000\149\000\149\000\149\000\149\000\
\162\000\162\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\149\000\000\000\149\000\000\000\149\000\
\149\000\149\000\000\000\162\000\149\000\000\000\000\000\000\000\
\149\000\162\000\000\000\162\000\149\000\149\000\000\000\149\000\
\149\000\149\000\000\000\000\000\000\000\000\000\149\000\000\000\
\069\000\000\000\149\000\149\000\149\000\149\000\000\000\149\000\
\000\000\000\000\160\000\160\000\000\000\000\000\149\000\000\000\
\000\000\000\000\000\000\000\000\000\000\160\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\160\000\000\000\160\000\000\000\000\000\160\000\000\000\149\000\
\000\000\111\000\111\000\111\000\111\000\149\000\149\000\160\000\
\000\000\000\000\000\000\000\000\160\000\000\000\160\000\000\000\
\111\000\000\000\111\000\000\000\111\000\111\000\111\000\000\000\
\149\000\111\000\000\000\000\000\000\000\111\000\149\000\000\000\
\149\000\111\000\111\000\000\000\111\000\111\000\111\000\000\000\
\000\000\000\000\160\000\160\000\000\000\105\000\000\000\111\000\
\111\000\111\000\111\000\000\000\111\000\105\000\105\000\000\000\
\105\000\105\000\000\000\111\000\000\000\160\000\160\000\160\000\
\105\000\000\000\000\000\105\000\160\000\160\000\000\000\160\000\
\160\000\000\000\000\000\105\000\000\000\105\000\160\000\000\000\
\105\000\000\000\000\000\000\000\111\000\000\000\000\000\000\000\
\000\000\000\000\111\000\111\000\000\000\000\000\000\000\105\000\
\000\000\105\000\013\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\111\000\000\000\000\000\
\000\000\000\000\000\000\111\000\000\000\111\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\105\000\105\000\000\000\
\000\000\000\000\105\000\105\000\000\000\000\000\000\000\000\000\
\000\000\000\000\004\000\004\000\000\000\000\000\000\000\000\000\
\105\000\105\000\105\000\000\000\000\000\004\000\004\000\105\000\
\105\000\000\000\105\000\105\000\000\000\000\000\000\000\000\000\
\000\000\105\000\004\000\000\000\004\000\004\000\000\000\000\000\
\000\000\000\000\051\000\051\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\004\000\051\000\004\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\051\000\000\000\000\000\051\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\004\000\000\000\000\000\
\000\000\000\000\004\000\004\000\051\000\000\000\051\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\069\000\
\069\000\000\000\000\000\000\000\000\000\004\000\004\000\004\000\
\000\000\000\000\069\000\000\000\004\000\004\000\000\000\004\000\
\004\000\000\000\051\000\051\000\000\000\000\000\004\000\069\000\
\000\000\000\000\069\000\000\000\000\000\000\000\000\000\160\000\
\160\000\000\000\000\000\000\000\000\000\051\000\051\000\051\000\
\000\000\069\000\160\000\069\000\051\000\051\000\000\000\051\000\
\051\000\000\000\000\000\000\000\000\000\000\000\051\000\160\000\
\000\000\000\000\160\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\069\000\
\069\000\160\000\000\000\160\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\105\000\105\000\000\000\000\000\
\000\000\000\000\069\000\069\000\069\000\000\000\000\000\105\000\
\000\000\069\000\069\000\000\000\069\000\069\000\000\000\160\000\
\160\000\000\000\000\000\069\000\105\000\000\000\000\000\105\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\160\000\160\000\160\000\000\000\105\000\000\000\
\105\000\160\000\160\000\000\000\160\000\160\000\000\000\000\000\
\000\000\013\000\013\000\160\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\013\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\105\000\105\000\000\000\000\000\
\000\000\013\000\000\000\000\000\013\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\105\000\
\105\000\105\000\000\000\013\000\000\000\013\000\105\000\105\000\
\000\000\105\000\105\000\000\000\000\000\000\000\000\000\000\000\
\105\000\000\000\000\000\000\000\151\001\152\001\000\000\154\001\
\000\000\156\001\157\001\158\001\159\001\000\000\000\000\000\000\
\000\000\013\000\013\000\166\001\167\001\168\001\169\001\170\001\
\171\001\172\001\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\013\000\013\000\013\000\000\000\
\000\000\000\000\000\000\013\000\013\000\000\000\013\000\013\000\
\000\000\000\000\000\000\189\001\000\000\013\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\197\001\198\001\
\199\001\000\000\218\001\219\001\220\001\000\000\222\001\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\236\001\237\001\238\001\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\200\001\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\201\001\202\001\000\000\000\000\
\000\000\004\002\000\000\000\000\005\002\006\002\007\002\008\002\
\009\002\010\002\011\002\012\002\013\002\014\002\015\002\016\002\
\017\002\018\002\019\002\020\002\021\002\022\002\023\002\024\002\
\000\000\025\002\000\000\000\000\000\000\000\000\203\001\000\000\
\000\000\000\000\200\001\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\201\001\202\001\204\001\
\205\001\206\001\207\001\208\001\209\001\210\001\211\001\212\001\
\213\001\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\133\001\000\000\000\000\000\000\000\000\000\000\000\000\
\214\001\215\001\216\001\217\001\000\000\000\000\000\000\203\001\
\000\000\000\000\000\000\036\002\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\045\002\
\204\001\205\001\206\001\207\001\208\001\209\001\210\001\211\001\
\212\001\213\001\000\000\134\001\000\000\135\001\136\001\232\000\
\233\000\234\000\235\000\000\000\000\000\000\000\000\000\000\000\
\000\000\214\001\215\001\216\001\217\001\000\000\236\000\000\000\
\237\000\000\000\238\000\239\000\240\000\000\000\000\000\241\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\242\000\
\243\000\000\000\244\000\245\000\246\000\000\000\000\000\000\000\
\000\000\137\001\000\000\000\000\000\000\247\000\248\000\249\000\
\250\000\000\000\251\000\000\000\000\000\000\000\200\001\000\000\
\000\000\252\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\201\001\202\001\146\001\000\000\147\001\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\253\000\200\001\000\000\000\000\000\000\000\000\
\254\000\255\000\000\000\000\000\000\000\200\001\201\001\202\001\
\000\000\000\000\000\000\203\001\000\000\000\000\000\000\000\000\
\201\001\202\001\000\000\000\001\000\000\000\000\000\000\000\000\
\000\000\001\001\000\000\002\001\204\001\205\001\206\001\207\001\
\208\001\209\001\210\001\211\001\212\001\213\001\148\001\000\000\
\203\001\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\203\001\000\000\000\000\214\001\215\001\216\001\
\217\001\204\001\205\001\206\001\207\001\208\001\209\001\210\001\
\211\001\212\001\213\001\204\001\205\001\206\001\207\001\208\001\
\209\001\210\001\211\001\212\001\213\001\200\001\000\000\000\000\
\000\000\149\001\214\001\215\001\216\001\217\001\000\000\200\001\
\201\001\202\001\000\000\000\000\214\001\215\001\216\001\217\001\
\000\000\000\000\201\001\202\001\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\224\001\000\000\
\000\000\000\000\000\000\000\000\200\001\000\000\000\000\000\000\
\225\001\000\000\203\001\000\000\000\000\000\000\000\000\201\001\
\202\001\000\000\000\000\000\000\203\001\000\000\000\000\000\000\
\000\000\000\000\000\000\204\001\205\001\206\001\207\001\208\001\
\209\001\210\001\211\001\212\001\213\001\204\001\205\001\206\001\
\207\001\208\001\209\001\210\001\211\001\212\001\213\001\000\000\
\000\000\203\001\000\000\000\000\214\001\215\001\216\001\217\001\
\000\000\000\000\000\000\000\000\000\000\000\000\214\001\215\001\
\216\001\217\001\204\001\205\001\206\001\207\001\208\001\209\001\
\210\001\211\001\212\001\213\001\200\001\000\000\000\000\000\000\
\226\001\000\000\000\000\000\000\000\000\000\000\200\001\201\001\
\202\001\000\000\227\001\214\001\215\001\216\001\217\001\000\000\
\000\000\201\001\202\001\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\234\001\
\000\000\203\001\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\203\001\000\000\000\000\000\000\000\000\
\000\000\000\000\204\001\205\001\206\001\207\001\208\001\209\001\
\210\001\211\001\212\001\213\001\204\001\205\001\206\001\207\001\
\208\001\209\001\210\001\211\001\212\001\213\001\200\001\000\000\
\000\000\000\000\000\000\214\001\215\001\216\001\217\001\000\000\
\000\000\201\001\202\001\200\001\035\002\214\001\215\001\216\001\
\217\001\000\000\000\000\000\000\000\000\000\000\201\001\202\001\
\000\000\000\000\000\000\000\000\239\001\000\000\000\000\235\001\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\037\002\000\000\203\001\000\000\000\000\200\001\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\203\001\201\001\202\001\200\001\204\001\205\001\206\001\207\001\
\208\001\209\001\210\001\211\001\212\001\213\001\000\000\202\001\
\000\000\204\001\205\001\206\001\207\001\208\001\209\001\210\001\
\211\001\212\001\213\001\000\000\000\000\214\001\215\001\216\001\
\217\001\000\000\000\000\203\001\000\000\000\000\000\000\000\000\
\000\000\000\000\214\001\215\001\216\001\217\001\000\000\000\000\
\203\001\000\000\000\000\000\000\204\001\205\001\206\001\207\001\
\208\001\209\001\210\001\211\001\212\001\213\001\000\000\000\000\
\000\000\204\001\205\001\206\001\207\001\208\001\209\001\210\001\
\211\001\212\001\213\001\000\000\000\000\214\001\215\001\216\001\
\217\001\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\214\001\215\001\216\001\217\001"

let yycheck = "\080\000\
\081\000\084\001\131\001\050\000\029\000\000\000\012\001\073\000\
\041\001\004\001\031\001\017\001\045\001\041\001\000\000\000\000\
\097\000\000\000\078\001\000\000\000\000\014\001\032\001\016\001\
\043\001\203\000\244\000\245\000\111\001\112\001\113\001\114\001\
\115\001\132\000\030\001\145\000\012\001\013\001\191\000\123\000\
\193\000\074\001\116\000\090\000\116\001\082\001\074\001\128\000\
\085\001\020\001\021\001\001\001\118\000\231\000\079\000\088\001\
\074\001\041\001\141\001\116\001\088\001\144\001\012\001\013\001\
\074\001\116\001\076\001\077\001\178\000\153\000\010\001\011\001\
\116\001\133\001\173\000\212\000\213\000\158\000\041\001\130\001\
\073\001\021\001\045\001\143\001\006\001\007\001\133\000\134\000\
\116\001\029\001\074\001\201\000\116\001\112\001\113\001\116\001\
\046\001\130\001\245\001\116\001\147\000\072\001\073\001\116\001\
\088\001\142\001\187\000\188\000\189\000\190\000\120\001\074\001\
\118\001\063\001\064\001\065\001\066\001\067\001\068\001\069\001\
\070\001\071\001\072\001\116\001\086\001\088\001\200\000\009\001\
\188\001\189\001\190\001\191\001\192\001\055\001\159\000\195\001\
\131\001\116\001\088\001\089\001\090\001\091\001\118\001\025\001\
\026\001\085\001\046\001\047\001\019\001\040\002\041\002\044\001\
\116\001\041\001\012\001\013\001\239\001\045\001\048\001\017\001\
\042\001\208\000\033\001\053\001\048\001\116\001\116\001\060\001\
\116\001\053\001\251\000\116\001\062\001\254\000\116\001\116\001\
\000\000\116\001\062\001\116\001\130\001\131\001\132\001\116\001\
\116\001\047\001\074\001\182\001\081\001\082\001\083\001\074\001\
\116\001\075\001\001\001\242\000\078\001\046\001\088\001\246\000\
\088\001\130\001\116\001\074\001\088\001\087\001\253\000\116\001\
\014\001\116\001\016\001\122\001\094\001\095\001\096\001\097\001\
\098\001\110\001\116\001\101\001\102\001\103\001\104\001\048\001\
\116\001\107\001\045\001\052\001\053\001\025\000\026\000\116\001\
\114\001\045\001\045\001\060\001\116\001\116\001\063\001\046\001\
\116\001\123\001\124\001\125\001\126\001\127\001\128\001\116\001\
\116\001\055\001\056\001\057\001\058\001\059\001\028\001\116\001\
\063\001\064\001\065\001\066\001\067\001\068\001\069\001\070\001\
\071\001\072\001\116\001\045\001\116\001\065\000\066\000\116\001\
\116\001\130\001\001\001\002\001\003\001\004\001\005\001\006\001\
\116\001\116\001\009\001\090\001\091\001\012\001\013\001\014\001\
\079\001\016\001\017\001\018\001\031\001\020\001\116\001\022\001\
\023\001\024\001\025\001\026\001\027\001\031\001\031\001\042\002\
\031\001\032\001\031\001\031\001\035\001\036\001\000\000\038\001\
\039\001\040\001\124\001\042\001\116\001\116\001\045\001\046\001\
\045\001\116\001\049\001\050\001\051\001\052\001\116\001\054\001\
\116\001\116\001\121\001\130\001\131\001\132\001\061\001\160\001\
\063\001\064\001\065\001\066\001\116\001\166\001\130\001\131\001\
\132\001\084\001\073\001\074\001\075\001\076\001\077\001\078\001\
\116\001\130\001\179\001\084\001\116\001\001\001\183\001\086\001\
\087\001\088\001\089\001\090\001\091\001\092\001\093\001\094\001\
\095\001\096\001\097\001\098\001\130\001\116\001\101\001\102\001\
\103\001\104\001\116\001\116\001\107\001\116\001\116\001\116\001\
\111\001\116\001\130\001\114\001\116\001\116\001\117\001\046\001\
\119\001\120\001\121\001\045\001\123\001\124\001\125\001\126\001\
\127\001\128\001\046\001\130\001\131\001\132\001\116\001\118\001\
\063\001\064\001\065\001\066\001\067\001\068\001\069\001\070\001\
\071\001\072\001\088\001\063\001\064\001\065\001\066\001\067\001\
\068\001\069\001\070\001\071\001\072\001\001\000\002\000\003\000\
\004\000\001\001\002\001\003\001\004\001\005\001\006\001\116\001\
\116\001\009\001\000\000\129\001\012\001\013\001\014\001\044\001\
\016\001\017\001\018\001\116\001\020\001\116\001\022\001\023\001\
\024\001\025\001\026\001\027\001\029\002\030\002\118\001\031\001\
\032\001\116\001\046\001\035\001\036\001\116\001\038\001\039\001\
\040\001\116\001\042\001\116\001\116\001\045\001\046\001\116\001\
\116\001\049\001\050\001\051\001\052\001\044\001\054\001\130\001\
\131\001\132\001\059\002\045\001\061\002\061\001\063\002\063\001\
\064\001\065\001\066\001\174\001\175\001\176\001\177\001\031\001\
\116\001\073\001\074\001\075\001\076\001\077\001\078\001\067\001\
\068\001\069\001\070\001\071\001\072\001\116\001\086\001\087\001\
\088\001\089\001\090\001\091\001\092\001\093\001\094\001\095\001\
\096\001\097\001\098\001\116\001\116\001\101\001\102\001\103\001\
\104\001\084\001\041\001\107\001\116\001\116\001\045\001\111\001\
\047\001\048\001\114\001\116\001\116\001\117\001\053\001\119\001\
\120\001\121\001\116\001\123\001\124\001\125\001\126\001\127\001\
\128\001\116\001\130\001\131\001\132\001\116\001\116\001\001\001\
\002\001\003\001\004\001\005\001\006\001\116\001\000\000\009\001\
\088\001\116\001\012\001\013\001\014\001\116\001\016\001\017\001\
\018\001\116\001\020\001\116\001\022\001\023\001\024\001\025\001\
\026\001\027\001\116\001\116\001\116\001\031\001\032\001\116\001\
\116\001\035\001\036\001\116\001\038\001\039\001\040\001\116\001\
\042\001\116\001\116\001\045\001\046\001\045\001\116\001\049\001\
\050\001\051\001\052\001\116\001\054\001\041\001\116\001\031\001\
\116\001\045\001\114\001\061\001\048\001\063\001\064\001\065\001\
\066\001\053\001\116\001\116\001\116\001\116\001\116\001\073\001\
\074\001\075\001\076\001\077\001\078\001\116\001\116\001\116\001\
\116\001\116\001\037\001\116\001\086\001\087\001\088\001\089\001\
\090\001\091\001\092\001\093\001\094\001\095\001\096\001\097\001\
\098\001\121\001\116\001\101\001\102\001\103\001\104\001\116\001\
\041\001\107\001\116\001\116\001\045\001\111\001\116\001\048\001\
\114\001\116\001\116\001\117\001\053\001\119\001\120\001\121\001\
\116\001\123\001\124\001\125\001\126\001\127\001\128\001\116\001\
\130\001\131\001\132\001\001\001\002\001\003\001\004\001\005\001\
\006\001\116\001\000\000\009\001\031\001\116\001\012\001\013\001\
\014\001\116\001\016\001\017\001\018\001\116\001\020\001\116\001\
\022\001\023\001\024\001\025\001\026\001\027\001\116\001\116\001\
\116\001\031\001\032\001\116\001\116\001\035\001\036\001\116\001\
\038\001\039\001\040\001\046\001\042\001\013\001\116\001\045\001\
\046\001\116\001\116\001\049\001\050\001\051\001\052\001\116\001\
\054\001\116\001\046\001\116\001\116\001\116\001\116\001\061\001\
\116\001\063\001\064\001\065\001\066\001\116\001\116\001\045\001\
\045\001\116\001\116\001\073\001\074\001\075\001\076\001\077\001\
\078\001\130\001\130\001\116\001\015\001\116\001\130\001\045\001\
\086\001\087\001\088\001\089\001\090\001\091\001\092\001\093\001\
\094\001\095\001\096\001\097\001\098\001\130\001\031\001\101\001\
\102\001\103\001\104\001\116\001\130\001\107\001\116\001\116\001\
\045\001\111\001\116\001\130\001\114\001\116\001\116\001\117\001\
\116\001\119\001\120\001\121\001\116\001\123\001\124\001\125\001\
\126\001\127\001\128\001\116\001\130\001\131\001\132\001\001\001\
\002\001\003\001\004\001\005\001\006\001\116\001\000\000\009\001\
\114\001\114\001\012\001\013\001\014\001\114\001\016\001\017\001\
\018\001\000\000\020\001\000\000\022\001\023\001\024\001\025\001\
\026\001\027\001\000\000\045\001\045\001\031\001\032\001\045\001\
\088\001\035\001\036\001\045\001\038\001\039\001\040\001\045\001\
\042\001\000\000\116\001\045\001\046\001\045\001\130\000\049\001\
\050\001\051\001\052\001\031\000\054\001\063\000\183\001\198\000\
\228\000\092\000\178\001\061\001\124\000\063\001\064\001\065\001\
\066\001\041\001\255\255\248\001\255\255\255\255\255\255\073\001\
\074\001\075\001\076\001\077\001\078\001\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\086\001\087\001\088\001\089\001\
\090\001\091\001\092\001\093\001\094\001\095\001\096\001\097\001\
\098\001\255\255\255\255\101\001\102\001\103\001\104\001\255\255\
\255\255\107\001\255\255\255\255\255\255\111\001\255\255\255\255\
\114\001\255\255\116\001\117\001\255\255\119\001\120\001\121\001\
\255\255\123\001\124\001\125\001\126\001\127\001\128\001\255\255\
\130\001\131\001\132\001\001\001\002\001\003\001\004\001\005\001\
\006\001\000\000\255\255\009\001\255\255\255\255\012\001\013\001\
\014\001\255\255\016\001\017\001\018\001\255\255\020\001\255\255\
\022\001\023\001\024\001\025\001\026\001\027\001\255\255\255\255\
\255\255\031\001\032\001\255\255\255\255\035\001\036\001\255\255\
\038\001\039\001\040\001\255\255\042\001\255\255\255\255\045\001\
\046\001\255\255\255\255\049\001\050\001\051\001\052\001\255\255\
\054\001\255\255\255\255\255\255\255\255\255\255\255\255\061\001\
\255\255\063\001\064\001\065\001\066\001\255\255\255\255\255\255\
\255\255\255\255\255\255\073\001\074\001\075\001\076\001\077\001\
\078\001\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\086\001\087\001\088\001\089\001\090\001\091\001\092\001\093\001\
\094\001\095\001\096\001\097\001\098\001\255\255\255\255\101\001\
\102\001\103\001\104\001\255\255\255\255\107\001\255\255\255\255\
\255\255\111\001\255\255\255\255\114\001\255\255\116\001\117\001\
\255\255\119\001\120\001\121\001\255\255\123\001\124\001\125\001\
\126\001\127\001\128\001\255\255\130\001\131\001\132\001\001\001\
\002\001\003\001\004\001\005\001\006\001\000\000\255\255\009\001\
\255\255\255\255\012\001\013\001\014\001\255\255\016\001\017\001\
\018\001\255\255\020\001\255\255\022\001\023\001\024\001\025\001\
\026\001\027\001\255\255\255\255\255\255\031\001\032\001\255\255\
\255\255\035\001\036\001\255\255\038\001\039\001\040\001\255\255\
\042\001\255\255\255\255\045\001\255\255\255\255\255\255\049\001\
\050\001\051\001\052\001\041\001\054\001\255\255\255\255\045\001\
\046\001\047\001\048\001\061\001\255\255\255\255\255\255\053\001\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\073\001\
\074\001\075\001\076\001\077\001\078\001\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\086\001\087\001\088\001\089\001\
\090\001\091\001\092\001\093\001\094\001\095\001\096\001\097\001\
\098\001\255\255\255\255\101\001\102\001\103\001\104\001\255\255\
\255\255\107\001\255\255\255\255\255\255\111\001\255\255\255\255\
\114\001\255\255\116\001\117\001\255\255\119\001\120\001\121\001\
\255\255\123\001\124\001\125\001\126\001\127\001\128\001\255\255\
\130\001\131\001\132\001\002\001\003\001\004\001\005\001\006\001\
\000\000\255\255\009\001\255\255\255\255\012\001\013\001\014\001\
\255\255\016\001\017\001\018\001\255\255\020\001\255\255\022\001\
\023\001\024\001\025\001\026\001\027\001\255\255\255\255\255\255\
\031\001\032\001\255\255\255\255\035\001\036\001\255\255\038\001\
\039\001\040\001\255\255\042\001\255\255\255\255\045\001\255\255\
\255\255\255\255\049\001\050\001\051\001\052\001\255\255\054\001\
\255\255\255\255\255\255\255\255\255\255\255\255\061\001\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\073\001\074\001\075\001\076\001\077\001\078\001\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\086\001\
\087\001\088\001\089\001\090\001\091\001\092\001\093\001\094\001\
\095\001\096\001\097\001\098\001\255\255\255\255\101\001\102\001\
\103\001\104\001\255\255\255\255\107\001\255\255\255\255\255\255\
\111\001\255\255\255\255\114\001\255\255\116\001\117\001\255\255\
\119\001\120\001\121\001\255\255\123\001\124\001\125\001\126\001\
\127\001\128\001\255\255\130\001\131\001\132\001\255\255\002\001\
\003\001\004\001\005\001\006\001\000\000\255\255\009\001\255\255\
\255\255\012\001\013\001\014\001\255\255\016\001\017\001\018\001\
\255\255\020\001\255\255\022\001\023\001\024\001\025\001\026\001\
\027\001\255\255\255\255\255\255\031\001\032\001\255\255\255\255\
\035\001\036\001\255\255\038\001\039\001\040\001\255\255\042\001\
\255\255\255\255\045\001\255\255\255\255\255\255\049\001\050\001\
\051\001\052\001\255\255\054\001\255\255\255\255\255\255\255\255\
\255\255\255\255\061\001\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\073\001\074\001\
\075\001\076\001\077\001\078\001\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\086\001\087\001\088\001\089\001\090\001\
\091\001\092\001\093\001\094\001\095\001\096\001\097\001\098\001\
\255\255\255\255\101\001\102\001\103\001\104\001\255\255\255\255\
\107\001\255\255\255\255\255\255\111\001\255\255\255\255\114\001\
\255\255\116\001\117\001\255\255\119\001\120\001\121\001\255\255\
\123\001\124\001\125\001\126\001\127\001\128\001\255\255\130\001\
\131\001\132\001\002\001\003\001\004\001\005\001\006\001\000\000\
\255\255\009\001\255\255\255\255\012\001\013\001\014\001\255\255\
\016\001\017\001\018\001\255\255\020\001\255\255\022\001\023\001\
\024\001\025\001\026\001\027\001\255\255\255\255\255\255\031\001\
\032\001\255\255\255\255\035\001\036\001\255\255\038\001\039\001\
\040\001\255\255\042\001\255\255\255\255\045\001\255\255\255\255\
\255\255\049\001\050\001\051\001\052\001\255\255\054\001\255\255\
\255\255\255\255\255\255\255\255\255\255\061\001\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\073\001\074\001\075\001\076\001\077\001\078\001\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\086\001\087\001\
\088\001\089\001\255\255\255\255\092\001\093\001\094\001\095\001\
\096\001\097\001\098\001\255\255\255\255\101\001\102\001\103\001\
\104\001\255\255\255\255\107\001\255\255\255\255\255\255\111\001\
\255\255\255\255\114\001\255\255\116\001\117\001\255\255\119\001\
\120\001\121\001\255\255\123\001\124\001\125\001\126\001\127\001\
\128\001\255\255\130\001\131\001\132\001\255\255\002\001\003\001\
\004\001\005\001\006\001\000\000\255\255\009\001\255\255\255\255\
\012\001\013\001\014\001\255\255\016\001\017\001\018\001\255\255\
\020\001\255\255\022\001\023\001\024\001\025\001\026\001\027\001\
\255\255\255\255\255\255\031\001\032\001\255\255\255\255\035\001\
\036\001\255\255\038\001\039\001\040\001\255\255\042\001\255\255\
\255\255\045\001\255\255\255\255\255\255\049\001\050\001\051\001\
\052\001\255\255\054\001\255\255\255\255\255\255\255\255\255\255\
\255\255\061\001\255\255\255\255\255\255\255\255\000\000\255\255\
\255\255\255\255\255\255\255\255\255\255\073\001\074\001\075\001\
\076\001\077\001\078\001\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\086\001\087\001\088\001\089\001\255\255\255\255\
\092\001\093\001\094\001\095\001\096\001\097\001\098\001\255\255\
\255\255\101\001\102\001\103\001\104\001\255\255\255\255\107\001\
\255\255\255\255\255\255\111\001\255\255\255\255\114\001\255\255\
\116\001\117\001\255\255\119\001\120\001\121\001\255\255\123\001\
\124\001\125\001\126\001\127\001\128\001\255\255\130\001\131\001\
\132\001\002\001\003\001\004\001\005\001\006\001\000\000\255\255\
\009\001\255\255\255\255\012\001\013\001\014\001\255\255\016\001\
\017\001\018\001\255\255\020\001\255\255\022\001\023\001\024\001\
\025\001\026\001\027\001\255\255\255\255\255\255\031\001\032\001\
\255\255\255\255\035\001\036\001\255\255\038\001\039\001\040\001\
\255\255\042\001\255\255\255\255\045\001\255\255\255\255\255\255\
\049\001\050\001\051\001\052\001\255\255\054\001\255\255\255\255\
\255\255\255\255\255\255\255\255\061\001\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\073\001\074\001\075\001\076\001\077\001\078\001\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\086\001\087\001\255\255\
\255\255\255\255\255\255\092\001\093\001\094\001\095\001\096\001\
\097\001\098\001\255\255\255\255\101\001\102\001\103\001\104\001\
\255\255\255\255\107\001\255\255\255\255\255\255\111\001\255\255\
\255\255\114\001\255\255\116\001\117\001\255\255\119\001\120\001\
\121\001\255\255\123\001\124\001\125\001\126\001\127\001\128\001\
\255\255\130\001\131\001\132\001\255\255\002\001\003\001\004\001\
\005\001\006\001\000\000\255\255\009\001\255\255\255\255\012\001\
\255\255\014\001\255\255\016\001\017\001\018\001\255\255\020\001\
\255\255\022\001\023\001\024\001\025\001\026\001\027\001\255\255\
\255\255\255\255\031\001\032\001\255\255\255\255\035\001\036\001\
\255\255\038\001\039\001\040\001\255\255\042\001\255\255\255\255\
\045\001\255\255\255\255\255\255\049\001\050\001\051\001\052\001\
\255\255\054\001\255\255\255\255\255\255\255\255\255\255\255\255\
\061\001\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\010\001\011\001\255\255\255\255\073\001\074\001\075\001\076\001\
\077\001\078\001\255\255\021\001\255\255\255\255\255\255\255\255\
\255\255\086\001\087\001\029\001\255\255\031\001\255\255\092\001\
\093\001\094\001\095\001\096\001\097\001\098\001\255\255\255\255\
\101\001\102\001\103\001\104\001\255\255\255\255\107\001\255\255\
\255\255\255\255\111\001\255\255\255\255\114\001\255\255\116\001\
\117\001\255\255\119\001\120\001\121\001\255\255\123\001\124\001\
\125\001\126\001\127\001\128\001\255\255\130\001\131\001\132\001\
\002\001\003\001\004\001\005\001\006\001\000\000\255\255\009\001\
\255\255\255\255\084\001\085\001\014\001\255\255\016\001\017\001\
\018\001\255\255\020\001\255\255\022\001\023\001\024\001\025\001\
\026\001\027\001\255\255\255\255\255\255\031\001\032\001\255\255\
\255\255\035\001\036\001\255\255\038\001\039\001\040\001\255\255\
\042\001\255\255\255\255\045\001\255\255\255\255\255\255\049\001\
\050\001\051\001\052\001\255\255\054\001\255\255\255\255\255\255\
\255\255\255\255\255\255\061\001\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\073\001\
\074\001\075\001\076\001\077\001\078\001\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\086\001\087\001\255\255\255\255\
\255\255\255\255\092\001\093\001\094\001\095\001\096\001\097\001\
\098\001\255\255\255\255\101\001\102\001\103\001\104\001\255\255\
\255\255\107\001\255\255\255\255\255\255\111\001\255\255\255\255\
\114\001\255\255\116\001\117\001\255\255\119\001\120\001\121\001\
\255\255\123\001\124\001\125\001\126\001\127\001\128\001\255\255\
\130\001\131\001\132\001\255\255\002\001\003\001\004\001\005\001\
\006\001\000\000\255\255\009\001\255\255\255\255\255\255\255\255\
\014\001\255\255\016\001\017\001\018\001\255\255\020\001\255\255\
\022\001\023\001\024\001\025\001\026\001\027\001\255\255\255\255\
\255\255\031\001\032\001\255\255\255\255\035\001\036\001\255\255\
\038\001\039\001\040\001\255\255\042\001\255\255\255\255\045\001\
\255\255\255\255\255\255\049\001\050\001\051\001\052\001\255\255\
\054\001\255\255\255\255\255\255\255\255\255\255\255\255\061\001\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\073\001\074\001\075\001\076\001\077\001\
\078\001\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\086\001\087\001\255\255\255\255\255\255\255\255\092\001\093\001\
\094\001\095\001\096\001\097\001\098\001\255\255\255\255\101\001\
\102\001\103\001\104\001\255\255\255\255\107\001\255\255\255\255\
\255\255\111\001\255\255\255\255\114\001\255\255\116\001\117\001\
\255\255\119\001\120\001\121\001\255\255\123\001\124\001\125\001\
\126\001\127\001\128\001\255\255\130\001\131\001\132\001\002\001\
\003\001\004\001\005\001\006\001\000\000\255\255\009\001\255\255\
\255\255\255\255\255\255\014\001\255\255\016\001\017\001\018\001\
\255\255\020\001\255\255\022\001\023\001\024\001\025\001\026\001\
\027\001\255\255\255\255\255\255\031\001\032\001\255\255\255\255\
\035\001\036\001\255\255\038\001\039\001\040\001\255\255\042\001\
\255\255\255\255\045\001\255\255\255\255\255\255\049\001\050\001\
\051\001\052\001\255\255\054\001\255\255\255\255\255\255\255\255\
\255\255\255\255\061\001\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\073\001\074\001\
\075\001\076\001\077\001\078\001\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\086\001\087\001\255\255\255\255\255\255\
\255\255\092\001\093\001\094\001\095\001\096\001\097\001\098\001\
\255\255\255\255\101\001\102\001\103\001\104\001\255\255\255\255\
\107\001\255\255\255\255\255\255\111\001\255\255\255\255\114\001\
\255\255\116\001\117\001\255\255\119\001\120\001\121\001\255\255\
\123\001\124\001\125\001\126\001\127\001\128\001\255\255\130\001\
\131\001\132\001\255\255\002\001\003\001\004\001\005\001\006\001\
\000\000\255\255\009\001\255\255\255\255\255\255\255\255\014\001\
\255\255\016\001\017\001\018\001\255\255\020\001\255\255\022\001\
\023\001\024\001\025\001\026\001\027\001\255\255\255\255\255\255\
\031\001\032\001\255\255\255\255\035\001\036\001\255\255\038\001\
\039\001\040\001\255\255\042\001\255\255\255\255\045\001\255\255\
\255\255\255\255\049\001\050\001\051\001\052\001\255\255\054\001\
\255\255\255\255\255\255\255\255\255\255\255\255\061\001\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\073\001\074\001\075\001\076\001\077\001\078\001\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\086\001\
\087\001\255\255\255\255\255\255\255\255\092\001\093\001\094\001\
\095\001\096\001\097\001\098\001\255\255\255\255\101\001\102\001\
\103\001\104\001\255\255\255\255\107\001\255\255\255\255\255\255\
\111\001\255\255\255\255\114\001\255\255\116\001\117\001\255\255\
\119\001\120\001\121\001\255\255\123\001\124\001\125\001\126\001\
\127\001\128\001\255\255\130\001\131\001\132\001\002\001\003\001\
\004\001\005\001\006\001\000\000\255\255\009\001\255\255\255\255\
\255\255\255\255\014\001\255\255\016\001\017\001\018\001\255\255\
\020\001\255\255\022\001\023\001\024\001\025\001\026\001\027\001\
\255\255\255\255\255\255\031\001\032\001\255\255\255\255\035\001\
\036\001\255\255\038\001\039\001\040\001\255\255\042\001\255\255\
\255\255\045\001\255\255\255\255\255\255\049\001\050\001\051\001\
\052\001\255\255\054\001\255\255\255\255\255\255\255\255\255\255\
\255\255\061\001\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\073\001\074\001\075\001\
\076\001\077\001\078\001\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\086\001\087\001\255\255\255\255\255\255\255\255\
\092\001\093\001\094\001\095\001\096\001\097\001\098\001\255\255\
\255\255\101\001\102\001\103\001\104\001\255\255\255\255\107\001\
\255\255\255\255\255\255\111\001\255\255\255\255\114\001\255\255\
\116\001\117\001\255\255\119\001\120\001\121\001\255\255\123\001\
\124\001\125\001\126\001\127\001\128\001\255\255\130\001\131\001\
\132\001\255\255\002\001\003\001\004\001\005\001\006\001\000\000\
\255\255\009\001\255\255\255\255\255\255\255\255\014\001\255\255\
\016\001\017\001\018\001\255\255\020\001\255\255\022\001\023\001\
\024\001\025\001\026\001\027\001\255\255\255\255\255\255\031\001\
\032\001\255\255\255\255\035\001\036\001\255\255\038\001\039\001\
\040\001\255\255\042\001\255\255\255\255\045\001\255\255\255\255\
\255\255\049\001\050\001\051\001\052\001\255\255\054\001\255\255\
\255\255\255\255\255\255\255\255\255\255\061\001\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\073\001\074\001\075\001\076\001\077\001\078\001\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\086\001\087\001\
\255\255\255\255\255\255\255\255\092\001\093\001\094\001\095\001\
\096\001\097\001\098\001\255\255\255\255\101\001\102\001\103\001\
\104\001\255\255\255\255\107\001\255\255\255\255\255\255\111\001\
\255\255\255\255\114\001\255\255\116\001\117\001\255\255\119\001\
\120\001\121\001\255\255\123\001\124\001\125\001\126\001\127\001\
\128\001\255\255\130\001\131\001\132\001\002\001\003\001\004\001\
\005\001\006\001\000\000\255\255\009\001\255\255\255\255\255\255\
\255\255\014\001\255\255\016\001\017\001\018\001\255\255\020\001\
\255\255\022\001\023\001\024\001\025\001\026\001\027\001\255\255\
\255\255\255\255\031\001\032\001\255\255\255\255\035\001\036\001\
\255\255\038\001\039\001\040\001\255\255\042\001\255\255\255\255\
\045\001\255\255\255\255\255\255\049\001\050\001\051\001\052\001\
\255\255\054\001\255\255\255\255\255\255\255\255\255\255\255\255\
\061\001\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\073\001\074\001\075\001\076\001\
\077\001\078\001\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\086\001\087\001\255\255\255\255\255\255\255\255\092\001\
\093\001\094\001\095\001\096\001\097\001\098\001\255\255\255\255\
\101\001\102\001\103\001\104\001\255\255\255\255\107\001\255\255\
\255\255\255\255\111\001\255\255\255\255\114\001\255\255\116\001\
\117\001\255\255\119\001\120\001\121\001\255\255\123\001\124\001\
\125\001\126\001\127\001\128\001\255\255\130\001\131\001\132\001\
\255\255\255\255\003\001\004\001\005\001\006\001\007\001\008\001\
\009\001\000\000\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\018\001\255\255\020\001\255\255\022\001\023\001\024\001\
\025\001\026\001\027\001\255\255\255\255\255\255\031\001\032\001\
\255\255\034\001\035\001\036\001\255\255\038\001\039\001\040\001\
\041\001\042\001\043\001\044\001\045\001\046\001\047\001\048\001\
\049\001\050\001\051\001\052\001\053\001\054\001\255\255\255\255\
\255\255\255\255\255\255\060\001\061\001\062\001\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\074\001\075\001\076\001\077\001\078\001\079\001\080\001\
\081\001\082\001\083\001\255\255\255\255\086\001\087\001\088\001\
\255\255\255\255\255\255\092\001\093\001\094\001\095\001\096\001\
\097\001\098\001\099\001\100\001\101\001\102\001\103\001\104\001\
\105\001\106\001\107\001\108\001\109\001\110\001\111\001\112\001\
\113\001\114\001\115\001\116\001\117\001\255\255\119\001\120\001\
\121\001\255\255\123\001\124\001\125\001\126\001\127\001\128\001\
\255\255\255\255\131\001\255\255\255\255\003\001\004\001\005\001\
\006\001\007\001\008\001\009\001\000\000\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\018\001\255\255\020\001\255\255\
\022\001\023\001\024\001\025\001\026\001\027\001\255\255\255\255\
\255\255\031\001\032\001\255\255\034\001\035\001\036\001\255\255\
\038\001\039\001\040\001\041\001\042\001\043\001\044\001\045\001\
\046\001\047\001\048\001\049\001\050\001\051\001\052\001\053\001\
\054\001\255\255\255\255\255\255\255\255\255\255\060\001\061\001\
\062\001\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\074\001\075\001\076\001\077\001\
\078\001\079\001\080\001\081\001\082\001\083\001\255\255\255\255\
\086\001\087\001\088\001\255\255\255\255\255\255\092\001\093\001\
\094\001\095\001\096\001\097\001\098\001\099\001\100\001\101\001\
\102\001\103\001\104\001\105\001\106\001\107\001\108\001\109\001\
\110\001\111\001\112\001\113\001\114\001\115\001\255\255\117\001\
\255\255\119\001\120\001\121\001\255\255\123\001\124\001\125\001\
\126\001\127\001\128\001\255\255\255\255\131\001\255\255\255\255\
\255\255\255\255\255\255\255\255\003\001\004\001\005\001\006\001\
\007\001\008\001\009\001\000\000\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\018\001\255\255\020\001\255\255\022\001\
\023\001\024\001\025\001\026\001\027\001\255\255\255\255\255\255\
\031\001\032\001\255\255\034\001\035\001\036\001\255\255\038\001\
\039\001\040\001\041\001\042\001\043\001\044\001\045\001\046\001\
\047\001\048\001\049\001\050\001\051\001\052\001\053\001\054\001\
\255\255\255\255\255\255\255\255\255\255\060\001\061\001\062\001\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\074\001\075\001\076\001\077\001\078\001\
\079\001\080\001\081\001\082\001\083\001\255\255\255\255\086\001\
\087\001\088\001\255\255\255\255\255\255\092\001\093\001\094\001\
\095\001\096\001\097\001\098\001\099\001\100\001\101\001\102\001\
\103\001\104\001\105\001\106\001\107\001\108\001\109\001\110\001\
\111\001\112\001\113\001\114\001\115\001\255\255\117\001\255\255\
\119\001\120\001\121\001\255\255\123\001\124\001\125\001\126\001\
\127\001\128\001\255\255\255\255\131\001\255\255\255\255\003\001\
\004\001\005\001\006\001\007\001\008\001\009\001\000\000\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\018\001\255\255\
\020\001\255\255\022\001\023\001\024\001\025\001\026\001\027\001\
\255\255\255\255\255\255\031\001\255\255\255\255\034\001\035\001\
\036\001\255\255\038\001\039\001\040\001\041\001\042\001\255\255\
\044\001\045\001\255\255\255\255\255\255\049\001\050\001\051\001\
\052\001\255\255\054\001\255\255\255\255\255\255\255\255\255\255\
\255\255\061\001\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\074\001\075\001\
\255\255\255\255\078\001\079\001\080\001\255\255\255\255\255\255\
\084\001\255\255\086\001\087\001\088\001\255\255\255\255\255\255\
\092\001\093\001\094\001\095\001\096\001\097\001\098\001\099\001\
\100\001\101\001\102\001\103\001\104\001\105\001\106\001\107\001\
\108\001\109\001\255\255\111\001\255\255\255\255\114\001\115\001\
\255\255\117\001\255\255\119\001\255\255\121\001\255\255\123\001\
\124\001\125\001\126\001\127\001\128\001\255\255\130\001\255\255\
\255\255\255\255\255\255\255\255\000\000\255\255\003\001\004\001\
\005\001\006\001\255\255\255\255\009\001\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\018\001\255\255\020\001\
\255\255\022\001\023\001\024\001\025\001\026\001\027\001\255\255\
\255\255\255\255\031\001\032\001\255\255\255\255\035\001\036\001\
\037\001\038\001\039\001\040\001\255\255\042\001\255\255\255\255\
\045\001\255\255\255\255\255\255\049\001\050\001\051\001\052\001\
\255\255\054\001\255\255\255\255\255\255\255\255\255\255\255\255\
\061\001\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\074\001\075\001\076\001\
\077\001\078\001\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\086\001\087\001\255\255\255\255\255\255\255\255\092\001\
\093\001\094\001\095\001\096\001\097\001\098\001\255\255\255\255\
\101\001\102\001\103\001\104\001\255\255\255\255\107\001\255\255\
\255\255\255\255\111\001\255\255\255\255\114\001\255\255\116\001\
\117\001\255\255\119\001\120\001\255\255\255\255\123\001\124\001\
\125\001\126\001\127\001\128\001\000\000\255\255\255\255\255\255\
\255\255\003\001\004\001\005\001\006\001\255\255\255\255\009\001\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\018\001\255\255\020\001\255\255\022\001\023\001\024\001\025\001\
\026\001\027\001\255\255\255\255\255\255\031\001\032\001\255\255\
\255\255\035\001\036\001\255\255\038\001\039\001\040\001\255\255\
\042\001\255\255\255\255\045\001\255\255\255\255\255\255\049\001\
\050\001\051\001\052\001\255\255\054\001\255\255\255\255\255\255\
\255\255\255\255\255\255\061\001\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\074\001\075\001\076\001\077\001\078\001\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\086\001\087\001\255\255\255\255\
\255\255\255\255\092\001\093\001\094\001\095\001\096\001\097\001\
\098\001\255\255\255\255\101\001\102\001\103\001\104\001\255\255\
\255\255\107\001\255\255\255\255\255\255\111\001\255\255\255\255\
\114\001\255\255\116\001\117\001\255\255\119\001\120\001\255\255\
\255\255\123\001\124\001\125\001\126\001\127\001\128\001\003\001\
\004\001\005\001\006\001\000\000\255\255\009\001\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\018\001\255\255\
\020\001\255\255\022\001\023\001\024\001\025\001\026\001\027\001\
\255\255\255\255\255\255\031\001\032\001\255\255\255\255\035\001\
\036\001\255\255\038\001\039\001\040\001\255\255\042\001\255\255\
\255\255\045\001\255\255\255\255\255\255\049\001\050\001\051\001\
\052\001\255\255\054\001\255\255\255\255\255\255\255\255\255\255\
\255\255\061\001\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\074\001\075\001\
\076\001\077\001\078\001\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\086\001\087\001\255\255\255\255\255\255\255\255\
\092\001\093\001\094\001\095\001\096\001\097\001\098\001\255\255\
\255\255\101\001\102\001\103\001\104\001\255\255\255\255\107\001\
\255\255\255\255\255\255\111\001\255\255\255\255\114\001\255\255\
\116\001\117\001\255\255\119\001\120\001\255\255\255\255\123\001\
\124\001\125\001\126\001\127\001\128\001\255\255\255\255\003\001\
\004\001\005\001\006\001\000\000\255\255\009\001\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\018\001\255\255\
\020\001\255\255\022\001\023\001\024\001\025\001\026\001\027\001\
\255\255\255\255\255\255\031\001\032\001\255\255\255\255\035\001\
\036\001\255\255\038\001\039\001\040\001\255\255\042\001\255\255\
\255\255\045\001\255\255\255\255\255\255\049\001\050\001\051\001\
\052\001\255\255\054\001\255\255\255\255\255\255\255\255\255\255\
\255\255\061\001\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\074\001\075\001\
\076\001\077\001\078\001\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\086\001\087\001\255\255\255\255\255\255\255\255\
\092\001\093\001\094\001\095\001\096\001\097\001\098\001\255\255\
\255\255\101\001\102\001\103\001\104\001\255\255\255\255\107\001\
\255\255\255\255\255\255\111\001\255\255\255\255\114\001\255\255\
\255\255\117\001\255\255\119\001\120\001\121\001\255\255\123\001\
\124\001\125\001\126\001\127\001\128\001\255\255\255\255\255\255\
\255\255\000\000\255\255\255\255\255\255\255\255\003\001\004\001\
\005\001\006\001\255\255\255\255\009\001\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\018\001\255\255\020\001\
\255\255\022\001\023\001\024\001\025\001\026\001\027\001\255\255\
\255\255\255\255\031\001\032\001\255\255\255\255\035\001\036\001\
\255\255\038\001\039\001\040\001\255\255\042\001\255\255\255\255\
\045\001\255\255\255\255\255\255\049\001\050\001\051\001\052\001\
\255\255\054\001\255\255\255\255\255\255\255\255\255\255\255\255\
\061\001\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\074\001\075\001\076\001\
\077\001\078\001\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\086\001\087\001\255\255\255\255\255\255\255\255\092\001\
\093\001\094\001\095\001\096\001\097\001\098\001\255\255\255\255\
\101\001\102\001\103\001\104\001\255\255\255\255\107\001\255\255\
\255\255\255\255\111\001\255\255\255\255\114\001\255\255\255\255\
\117\001\255\255\119\001\120\001\121\001\255\255\123\001\124\001\
\125\001\126\001\127\001\128\001\000\000\255\255\003\001\004\001\
\005\001\006\001\255\255\255\255\009\001\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\018\001\255\255\020\001\
\255\255\022\001\023\001\024\001\025\001\026\001\027\001\255\255\
\255\255\255\255\031\001\032\001\255\255\255\255\035\001\036\001\
\255\255\038\001\039\001\040\001\255\255\042\001\255\255\255\255\
\045\001\255\255\255\255\255\255\049\001\050\001\051\001\052\001\
\255\255\054\001\255\255\255\255\255\255\255\255\255\255\255\255\
\061\001\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\074\001\075\001\076\001\
\077\001\078\001\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\086\001\087\001\255\255\255\255\255\255\255\255\092\001\
\093\001\094\001\095\001\096\001\097\001\098\001\255\255\255\255\
\101\001\102\001\103\001\104\001\255\255\255\255\107\001\255\255\
\255\255\255\255\111\001\255\255\255\255\114\001\255\255\255\255\
\117\001\255\255\119\001\120\001\121\001\255\255\123\001\124\001\
\125\001\126\001\127\001\128\001\003\001\004\001\005\001\006\001\
\000\000\255\255\009\001\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\018\001\255\255\020\001\255\255\022\001\
\023\001\024\001\025\001\026\001\027\001\255\255\255\255\255\255\
\031\001\032\001\255\255\255\255\035\001\036\001\255\255\038\001\
\039\001\040\001\255\255\042\001\255\255\255\255\045\001\255\255\
\255\255\255\255\049\001\050\001\051\001\052\001\255\255\054\001\
\255\255\255\255\255\255\255\255\255\255\255\255\061\001\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\074\001\075\001\076\001\077\001\078\001\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\086\001\
\087\001\255\255\255\255\255\255\255\255\092\001\093\001\094\001\
\095\001\096\001\097\001\098\001\255\255\255\255\101\001\102\001\
\103\001\104\001\255\255\255\255\107\001\255\255\255\255\255\255\
\111\001\255\255\255\255\114\001\255\255\255\255\117\001\255\255\
\119\001\120\001\121\001\255\255\123\001\124\001\125\001\126\001\
\127\001\128\001\255\255\255\255\255\255\255\255\000\000\003\001\
\004\001\005\001\006\001\255\255\255\255\009\001\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\018\001\255\255\
\020\001\255\255\022\001\023\001\024\001\025\001\026\001\027\001\
\255\255\255\255\255\255\031\001\032\001\255\255\255\255\035\001\
\036\001\255\255\038\001\039\001\040\001\255\255\042\001\255\255\
\255\255\045\001\255\255\255\255\255\255\049\001\050\001\051\001\
\052\001\255\255\054\001\255\255\255\255\255\255\255\255\255\255\
\255\255\061\001\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\074\001\075\001\
\076\001\077\001\078\001\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\086\001\087\001\255\255\255\255\255\255\255\255\
\092\001\093\001\094\001\095\001\096\001\097\001\098\001\255\255\
\255\255\101\001\102\001\103\001\104\001\255\255\255\255\107\001\
\255\255\255\255\255\255\111\001\255\255\255\255\114\001\255\255\
\255\255\117\001\255\255\119\001\120\001\121\001\255\255\123\001\
\124\001\125\001\126\001\127\001\128\001\000\000\255\255\255\255\
\255\255\255\255\255\255\003\001\004\001\005\001\006\001\255\255\
\255\255\009\001\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\018\001\255\255\020\001\255\255\022\001\023\001\
\024\001\025\001\026\001\027\001\255\255\255\255\255\255\031\001\
\032\001\255\255\255\255\035\001\036\001\255\255\038\001\039\001\
\040\001\255\255\042\001\255\255\255\255\045\001\255\255\255\255\
\255\255\049\001\050\001\051\001\052\001\255\255\054\001\255\255\
\255\255\255\255\255\255\255\255\255\255\061\001\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\074\001\075\001\076\001\077\001\078\001\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\086\001\087\001\
\255\255\255\255\255\255\255\255\092\001\093\001\094\001\095\001\
\096\001\097\001\098\001\255\255\255\255\101\001\102\001\103\001\
\104\001\255\255\255\255\107\001\255\255\255\255\255\255\111\001\
\255\255\255\255\114\001\255\255\255\255\117\001\255\255\119\001\
\120\001\121\001\255\255\123\001\124\001\125\001\126\001\127\001\
\128\001\003\001\004\001\005\001\006\001\000\000\255\255\009\001\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\018\001\255\255\020\001\255\255\022\001\023\001\024\001\025\001\
\026\001\027\001\255\255\255\255\255\255\031\001\032\001\255\255\
\255\255\035\001\036\001\255\255\038\001\039\001\040\001\255\255\
\042\001\255\255\255\255\045\001\255\255\255\255\255\255\049\001\
\050\001\051\001\052\001\255\255\054\001\255\255\255\255\255\255\
\255\255\255\255\255\255\061\001\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\074\001\075\001\076\001\077\001\078\001\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\086\001\087\001\255\255\255\255\
\255\255\255\255\092\001\093\001\094\001\095\001\096\001\097\001\
\098\001\255\255\255\255\101\001\102\001\103\001\104\001\255\255\
\255\255\107\001\255\255\255\255\255\255\111\001\255\255\255\255\
\114\001\255\255\255\255\117\001\255\255\119\001\120\001\121\001\
\255\255\123\001\124\001\125\001\126\001\127\001\128\001\255\255\
\003\001\004\001\005\001\006\001\000\000\255\255\009\001\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\018\001\
\255\255\020\001\255\255\022\001\023\001\024\001\025\001\026\001\
\027\001\255\255\255\255\255\255\031\001\032\001\255\255\255\255\
\035\001\036\001\255\255\038\001\039\001\040\001\255\255\042\001\
\255\255\255\255\045\001\255\255\255\255\255\255\049\001\050\001\
\051\001\052\001\255\255\054\001\255\255\255\255\255\255\255\255\
\255\255\255\255\061\001\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\074\001\
\075\001\076\001\077\001\078\001\255\255\000\000\255\255\255\255\
\255\255\255\255\255\255\086\001\087\001\255\255\255\255\255\255\
\255\255\092\001\093\001\094\001\095\001\096\001\097\001\098\001\
\255\255\255\255\101\001\102\001\103\001\104\001\255\255\255\255\
\107\001\255\255\255\255\255\255\111\001\255\255\255\255\114\001\
\255\255\000\000\117\001\255\255\119\001\120\001\255\255\255\255\
\123\001\124\001\125\001\126\001\127\001\128\001\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\003\001\004\001\005\001\006\001\255\255\255\255\009\001\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\018\001\
\255\255\020\001\255\255\022\001\023\001\024\001\025\001\026\001\
\027\001\255\255\255\255\255\255\031\001\255\255\255\255\255\255\
\035\001\036\001\255\255\038\001\039\001\040\001\255\255\042\001\
\255\255\255\255\045\001\255\255\255\255\255\255\049\001\050\001\
\051\001\052\001\255\255\054\001\255\255\255\255\255\255\255\255\
\255\255\255\255\061\001\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\075\001\255\255\255\255\078\001\255\255\000\000\255\255\255\255\
\255\255\255\255\255\255\086\001\087\001\255\255\255\255\255\255\
\255\255\092\001\093\001\094\001\095\001\096\001\097\001\098\001\
\255\255\255\255\101\001\102\001\103\001\104\001\255\255\255\255\
\107\001\255\255\255\255\255\255\111\001\255\255\255\255\114\001\
\255\255\255\255\117\001\255\255\119\001\255\255\255\255\255\255\
\123\001\124\001\125\001\126\001\127\001\128\001\255\255\003\001\
\004\001\005\001\006\001\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\000\000\018\001\255\255\
\020\001\255\255\022\001\023\001\024\001\255\255\255\255\027\001\
\255\255\255\255\255\255\031\001\032\001\255\255\255\255\035\001\
\036\001\255\255\038\001\039\001\040\001\255\255\255\255\255\255\
\255\255\045\001\255\255\255\255\255\255\049\001\050\001\051\001\
\052\001\000\000\054\001\255\255\255\255\255\255\255\255\255\255\
\255\255\061\001\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\074\001\255\255\
\076\001\077\001\255\255\255\255\007\001\008\001\255\255\255\255\
\255\255\255\255\086\001\255\255\255\255\255\255\255\255\018\001\
\092\001\093\001\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\031\001\255\255\255\255\034\001\
\255\255\255\255\255\255\111\001\003\001\004\001\005\001\006\001\
\255\255\117\001\045\001\119\001\120\001\121\001\049\001\255\255\
\051\001\255\255\255\255\018\001\255\255\020\001\255\255\022\001\
\023\001\024\001\255\255\255\255\027\001\255\255\255\255\255\255\
\031\001\255\255\255\255\255\255\035\001\036\001\255\255\038\001\
\039\001\040\001\255\255\255\255\079\001\080\001\045\001\255\255\
\000\000\255\255\049\001\050\001\051\001\052\001\255\255\054\001\
\255\255\255\255\255\255\255\255\255\255\255\255\061\001\098\001\
\099\001\100\001\255\255\255\255\255\255\255\255\105\001\106\001\
\044\001\108\001\109\001\255\255\048\001\255\255\255\255\255\255\
\115\001\053\001\255\255\255\255\255\255\255\255\255\255\086\001\
\060\001\255\255\062\001\255\255\255\255\092\001\093\001\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\003\001\004\001\005\001\006\001\255\255\081\001\082\001\083\001\
\111\001\255\255\255\255\255\255\088\001\255\255\117\001\018\001\
\119\001\020\001\121\001\022\001\023\001\024\001\255\255\255\255\
\027\001\255\255\255\255\255\255\031\001\000\000\255\255\255\255\
\035\001\036\001\110\001\038\001\039\001\040\001\255\255\255\255\
\255\255\255\255\045\001\255\255\255\255\255\255\049\001\050\001\
\051\001\052\001\255\255\054\001\255\255\255\255\255\255\255\255\
\255\255\255\255\061\001\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\007\001\008\001\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\018\001\
\255\255\255\255\255\255\086\001\255\255\255\255\255\255\255\255\
\255\255\092\001\093\001\255\255\031\001\255\255\255\255\034\001\
\255\255\255\255\255\255\255\255\003\001\004\001\005\001\006\001\
\255\255\255\255\045\001\255\255\111\001\255\255\049\001\255\255\
\051\001\255\255\117\001\018\001\119\001\020\001\121\001\022\001\
\023\001\024\001\255\255\255\255\027\001\255\255\255\255\000\000\
\031\001\032\001\255\255\255\255\035\001\036\001\255\255\038\001\
\039\001\040\001\255\255\255\255\079\001\080\001\045\001\255\255\
\255\255\255\255\049\001\050\001\051\001\052\001\255\255\054\001\
\255\255\255\255\255\255\255\255\255\255\255\255\061\001\098\001\
\099\001\100\001\255\255\255\255\255\255\255\255\105\001\106\001\
\255\255\108\001\109\001\074\001\255\255\076\001\077\001\255\255\
\115\001\255\255\255\255\255\255\255\255\255\255\255\255\086\001\
\255\255\255\255\255\255\255\255\255\255\092\001\093\001\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\003\001\004\001\005\001\006\001\255\255\
\111\001\255\255\255\255\255\255\000\000\255\255\117\001\255\255\
\119\001\120\001\018\001\255\255\020\001\255\255\022\001\023\001\
\024\001\255\255\255\255\027\001\255\255\255\255\255\255\031\001\
\255\255\255\255\255\255\035\001\036\001\255\255\038\001\039\001\
\040\001\255\255\255\255\255\255\255\255\045\001\255\255\255\255\
\255\255\049\001\050\001\051\001\052\001\255\255\054\001\255\255\
\255\255\255\255\255\255\255\255\255\255\061\001\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\007\001\
\008\001\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\018\001\255\255\255\255\255\255\086\001\255\255\
\003\001\004\001\005\001\006\001\092\001\093\001\255\255\031\001\
\255\255\000\000\034\001\255\255\255\255\255\255\255\255\018\001\
\255\255\020\001\255\255\022\001\023\001\024\001\255\255\111\001\
\027\001\049\001\255\255\051\001\031\001\117\001\255\255\119\001\
\035\001\036\001\255\255\038\001\039\001\040\001\255\255\255\255\
\255\255\255\255\045\001\255\255\255\255\255\255\049\001\050\001\
\051\001\052\001\255\255\054\001\255\255\255\255\255\255\079\001\
\080\001\255\255\061\001\000\000\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\098\001\099\001\100\001\255\255\255\255\255\255\
\255\255\105\001\106\001\086\001\108\001\109\001\255\255\255\255\
\255\255\092\001\093\001\115\001\255\255\255\255\000\000\255\255\
\255\255\255\255\003\001\004\001\005\001\006\001\255\255\001\001\
\255\255\255\255\255\255\255\255\111\001\255\255\255\255\255\255\
\255\255\018\001\117\001\020\001\119\001\022\001\023\001\024\001\
\255\255\255\255\027\001\255\255\255\255\255\255\031\001\255\255\
\255\255\255\255\035\001\036\001\255\255\038\001\039\001\040\001\
\255\255\255\255\255\255\255\255\045\001\255\255\000\000\255\255\
\049\001\050\001\051\001\052\001\046\001\054\001\255\255\255\255\
\255\255\255\255\255\255\255\255\061\001\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\063\001\064\001\065\001\
\066\001\067\001\068\001\069\001\070\001\071\001\072\001\255\255\
\255\255\255\255\255\255\255\255\255\255\086\001\255\255\003\001\
\004\001\005\001\006\001\092\001\093\001\255\255\088\001\089\001\
\090\001\091\001\255\255\255\255\255\255\255\255\018\001\255\255\
\020\001\255\255\022\001\023\001\024\001\255\255\111\001\027\001\
\255\255\255\255\255\255\031\001\117\001\255\255\119\001\035\001\
\036\001\255\255\038\001\039\001\040\001\255\255\255\255\255\255\
\255\255\045\001\255\255\000\000\255\255\049\001\050\001\051\001\
\052\001\255\255\054\001\255\255\255\255\255\255\255\255\255\255\
\255\255\061\001\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\000\000\255\255\255\255\255\255\255\255\
\255\255\255\255\086\001\255\255\003\001\004\001\005\001\006\001\
\092\001\093\001\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\018\001\255\255\020\001\255\255\022\001\
\023\001\024\001\255\255\111\001\027\001\255\255\255\255\255\255\
\031\001\117\001\255\255\119\001\035\001\036\001\255\255\038\001\
\039\001\040\001\255\255\255\255\255\255\255\255\045\001\255\255\
\000\000\255\255\049\001\050\001\051\001\052\001\255\255\054\001\
\255\255\255\255\007\001\008\001\255\255\255\255\061\001\255\255\
\255\255\255\255\255\255\255\255\255\255\018\001\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\000\000\255\255\031\001\255\255\255\255\034\001\255\255\086\001\
\255\255\003\001\004\001\005\001\006\001\092\001\093\001\044\001\
\255\255\255\255\255\255\255\255\049\001\255\255\051\001\255\255\
\018\001\255\255\020\001\255\255\022\001\023\001\024\001\255\255\
\111\001\027\001\255\255\255\255\255\255\031\001\117\001\255\255\
\119\001\035\001\036\001\255\255\038\001\039\001\040\001\255\255\
\255\255\255\255\079\001\080\001\255\255\000\000\255\255\049\001\
\050\001\051\001\052\001\255\255\054\001\007\001\008\001\255\255\
\010\001\011\001\255\255\061\001\255\255\098\001\099\001\100\001\
\018\001\255\255\255\255\021\001\105\001\106\001\255\255\108\001\
\109\001\255\255\255\255\029\001\255\255\031\001\115\001\255\255\
\034\001\255\255\255\255\255\255\086\001\255\255\255\255\255\255\
\255\255\255\255\092\001\093\001\255\255\255\255\255\255\049\001\
\255\255\051\001\000\000\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\111\001\255\255\255\255\
\255\255\255\255\255\255\117\001\255\255\119\001\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\079\001\080\001\255\255\
\255\255\255\255\084\001\085\001\255\255\255\255\255\255\255\255\
\255\255\255\255\007\001\008\001\255\255\255\255\255\255\255\255\
\098\001\099\001\100\001\255\255\255\255\018\001\019\001\105\001\
\106\001\255\255\108\001\109\001\255\255\255\255\255\255\255\255\
\255\255\115\001\031\001\255\255\033\001\034\001\255\255\255\255\
\255\255\255\255\007\001\008\001\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\049\001\018\001\051\001\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\031\001\255\255\255\255\034\001\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\074\001\255\255\255\255\
\255\255\255\255\079\001\080\001\049\001\255\255\051\001\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\007\001\
\008\001\255\255\255\255\255\255\255\255\098\001\099\001\100\001\
\255\255\255\255\018\001\255\255\105\001\106\001\255\255\108\001\
\109\001\255\255\079\001\080\001\255\255\255\255\115\001\031\001\
\255\255\255\255\034\001\255\255\255\255\255\255\255\255\007\001\
\008\001\255\255\255\255\255\255\255\255\098\001\099\001\100\001\
\255\255\049\001\018\001\051\001\105\001\106\001\255\255\108\001\
\109\001\255\255\255\255\255\255\255\255\255\255\115\001\031\001\
\255\255\255\255\034\001\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\079\001\
\080\001\049\001\255\255\051\001\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\007\001\008\001\255\255\255\255\
\255\255\255\255\098\001\099\001\100\001\255\255\255\255\018\001\
\255\255\105\001\106\001\255\255\108\001\109\001\255\255\079\001\
\080\001\255\255\255\255\115\001\031\001\255\255\255\255\034\001\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\098\001\099\001\100\001\255\255\049\001\255\255\
\051\001\105\001\106\001\255\255\108\001\109\001\255\255\255\255\
\255\255\007\001\008\001\115\001\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\018\001\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\079\001\080\001\255\255\255\255\
\255\255\031\001\255\255\255\255\034\001\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\098\001\
\099\001\100\001\255\255\049\001\255\255\051\001\105\001\106\001\
\255\255\108\001\109\001\255\255\255\255\255\255\255\255\255\255\
\115\001\255\255\255\255\255\255\088\001\089\001\255\255\091\001\
\255\255\093\001\094\001\095\001\096\001\255\255\255\255\255\255\
\255\255\079\001\080\001\103\001\104\001\105\001\106\001\107\001\
\108\001\109\001\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\098\001\099\001\100\001\255\255\
\255\255\255\255\255\255\105\001\106\001\255\255\108\001\109\001\
\255\255\255\255\255\255\135\001\255\255\115\001\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\146\001\147\001\
\148\001\255\255\150\001\151\001\152\001\255\255\154\001\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\169\001\170\001\171\001\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\001\001\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\012\001\013\001\255\255\255\255\
\255\255\017\001\255\255\255\255\200\001\201\001\202\001\203\001\
\204\001\205\001\206\001\207\001\208\001\209\001\210\001\211\001\
\212\001\213\001\214\001\215\001\216\001\217\001\218\001\219\001\
\255\255\221\001\255\255\255\255\255\255\255\255\046\001\255\255\
\255\255\255\255\001\001\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\012\001\013\001\063\001\
\064\001\065\001\066\001\067\001\068\001\069\001\070\001\071\001\
\072\001\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\032\001\255\255\255\255\255\255\255\255\255\255\255\255\
\088\001\089\001\090\001\091\001\255\255\255\255\255\255\046\001\
\255\255\255\255\255\255\023\002\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\035\002\
\063\001\064\001\065\001\066\001\067\001\068\001\069\001\070\001\
\071\001\072\001\255\255\074\001\255\255\076\001\077\001\003\001\
\004\001\005\001\006\001\255\255\255\255\255\255\255\255\255\255\
\255\255\088\001\089\001\090\001\091\001\255\255\018\001\255\255\
\020\001\255\255\022\001\023\001\024\001\255\255\255\255\027\001\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\035\001\
\036\001\255\255\038\001\039\001\040\001\255\255\255\255\255\255\
\255\255\120\001\255\255\255\255\255\255\049\001\050\001\051\001\
\052\001\255\255\054\001\255\255\255\255\255\255\001\001\255\255\
\255\255\061\001\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\012\001\013\001\014\001\255\255\016\001\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\086\001\001\001\255\255\255\255\255\255\255\255\
\092\001\093\001\255\255\255\255\255\255\001\001\012\001\013\001\
\255\255\255\255\255\255\046\001\255\255\255\255\255\255\255\255\
\012\001\013\001\255\255\111\001\255\255\255\255\255\255\255\255\
\255\255\117\001\255\255\119\001\063\001\064\001\065\001\066\001\
\067\001\068\001\069\001\070\001\071\001\072\001\073\001\255\255\
\046\001\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\046\001\255\255\255\255\088\001\089\001\090\001\
\091\001\063\001\064\001\065\001\066\001\067\001\068\001\069\001\
\070\001\071\001\072\001\063\001\064\001\065\001\066\001\067\001\
\068\001\069\001\070\001\071\001\072\001\001\001\255\255\255\255\
\255\255\116\001\088\001\089\001\090\001\091\001\255\255\001\001\
\012\001\013\001\255\255\255\255\088\001\089\001\090\001\091\001\
\255\255\255\255\012\001\013\001\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\116\001\255\255\
\255\255\255\255\255\255\255\255\001\001\255\255\255\255\255\255\
\116\001\255\255\046\001\255\255\255\255\255\255\255\255\012\001\
\013\001\255\255\255\255\255\255\046\001\255\255\255\255\255\255\
\255\255\255\255\255\255\063\001\064\001\065\001\066\001\067\001\
\068\001\069\001\070\001\071\001\072\001\063\001\064\001\065\001\
\066\001\067\001\068\001\069\001\070\001\071\001\072\001\255\255\
\255\255\046\001\255\255\255\255\088\001\089\001\090\001\091\001\
\255\255\255\255\255\255\255\255\255\255\255\255\088\001\089\001\
\090\001\091\001\063\001\064\001\065\001\066\001\067\001\068\001\
\069\001\070\001\071\001\072\001\001\001\255\255\255\255\255\255\
\116\001\255\255\255\255\255\255\255\255\255\255\001\001\012\001\
\013\001\255\255\116\001\088\001\089\001\090\001\091\001\255\255\
\255\255\012\001\013\001\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\116\001\
\255\255\046\001\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\046\001\255\255\255\255\255\255\255\255\
\255\255\255\255\063\001\064\001\065\001\066\001\067\001\068\001\
\069\001\070\001\071\001\072\001\063\001\064\001\065\001\066\001\
\067\001\068\001\069\001\070\001\071\001\072\001\001\001\255\255\
\255\255\255\255\255\255\088\001\089\001\090\001\091\001\255\255\
\255\255\012\001\013\001\001\001\002\001\088\001\089\001\090\001\
\091\001\255\255\255\255\255\255\255\255\255\255\012\001\013\001\
\255\255\255\255\255\255\255\255\031\001\255\255\255\255\116\001\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\116\001\255\255\046\001\255\255\255\255\001\001\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\046\001\012\001\013\001\001\001\063\001\064\001\065\001\066\001\
\067\001\068\001\069\001\070\001\071\001\072\001\255\255\013\001\
\255\255\063\001\064\001\065\001\066\001\067\001\068\001\069\001\
\070\001\071\001\072\001\255\255\255\255\088\001\089\001\090\001\
\091\001\255\255\255\255\046\001\255\255\255\255\255\255\255\255\
\255\255\255\255\088\001\089\001\090\001\091\001\255\255\255\255\
\046\001\255\255\255\255\255\255\063\001\064\001\065\001\066\001\
\067\001\068\001\069\001\070\001\071\001\072\001\255\255\255\255\
\255\255\063\001\064\001\065\001\066\001\067\001\068\001\069\001\
\070\001\071\001\072\001\255\255\255\255\088\001\089\001\090\001\
\091\001\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\088\001\089\001\090\001\091\001"

let yynames_const = "\
  QUESTION\000\
  COLON\000\
  ACTION_IF\000\
  ADD_KIT\000\
  ADD_MUSIC\000\
  ADD_PROJECTILE\000\
  ADD_STATE_TRIGGER\000\
  ADD_TRANS_TRIGGER\000\
  ADD_STORE_ITEM\000\
  ALLOW_MISSING\000\
  ALWAYS\000\
  AND\000\
  OR\000\
  NOT\000\
  ELSE\000\
  LPAREN\000\
  RPAREN\000\
  APPEND\000\
  APPENDI\000\
  APPEND_COL\000\
  ASK_EVERY_COMPONENT\000\
  AT_EXIT\000\
  AT_INTERACTIVE_EXIT\000\
  AT_INTERACTIVE_UNINSTALL\000\
  SET_2DA_ENTRY\000\
  READ_2DA_ENTRY\000\
  AT_UNINSTALL\000\
  AUTHOR\000\
  AUTO_TRA\000\
  BACKUP\000\
  BEGIN\000\
  BUT_ONLY_IF_IT_CHANGES\000\
  CHAIN2\000\
  CHAIN3\000\
  COMPILE\000\
  COPY\000\
  GLOB\000\
  COPY_EXISTING\000\
  COPY_EXISTING_REGEXP\000\
  COPY_RANDOM\000\
  COPY_TRANS\000\
  DELETE_BYTES\000\
  DEPRECATED\000\
  DO\000\
  END\000\
  EQUALS\000\
  EQUALSEQUALS\000\
  EXIT\000\
  EXTEND_BOTTOM\000\
  EXTEND_BOTTOM_REGEXP\000\
  EXTEND_TOP\000\
  EXTEND_TOP_REGEXP\000\
  EXTERN\000\
  FAIL\000\
  FILE_CONTAINS\000\
  FILE_MD5\000\
  FILE_EXISTS\000\
  FILE_EXISTS_IN_GAME\000\
  FILE_SIZE\000\
  FLAGS\000\
  FORBID_FILE\000\
  GOTO\000\
  GT\000\
  GTE\000\
  LT\000\
  LTE\000\
  BAND\000\
  BOR\000\
  BXOR\000\
  BLSL\000\
  BASR\000\
  BLSR\000\
  BNOT\000\
  IF\000\
  SET\000\
  IF_EVAL\000\
  IF_SIZE_IS\000\
  INSERT_BYTES\000\
  INTERJECT\000\
  INTERJECT_COPY_TRANS\000\
  JOURNAL\000\
  SOLVED_JOURNAL\000\
  UNSOLVED_JOURNAL\000\
  LANGUAGE\000\
  MENU_STYLE\000\
  MKDIR\000\
  PATCH_GAM\000\
  PLUS\000\
  MINUS\000\
  TIMES\000\
  DIVIDE\000\
  PRINT\000\
  RANDOM_SEED\000\
  READ_ASCII\000\
  READ_BYTE\000\
  READ_LONG\000\
  READ_SHORT\000\
  REPLACE\000\
  REPLACE_ACTION_TEXT\000\
  REPLACE_ACTION_TEXT_PROCESS\000\
  REPLACE_BCS_BLOCK\000\
  REPLACE_BCS_BLOCK_REGEXP\000\
  APPLY_BCS_PATCH\000\
  APPLY_BCS_PATCH_OR_COPY\000\
  REPLACE_SAY\000\
  REPLACE_STATE_TRIGGER\000\
  REPLACE_TEXTUALLY\000\
  REPLACE_TRIGGER_TEXT\000\
  REPLACE_TRIGGER_TEXT_REGEXP\000\
  REPLY\000\
  REQUIRE_FILE\000\
  REQUIRE_COMPONENT\000\
  FORBID_COMPONENT\000\
  SAY\000\
  SET_WEIGHT\000\
  STRING_SET\000\
  THEN\000\
  UNINSTALL\000\
  UNLESS\000\
  USING\000\
  WEIGHT\000\
  WRITE_ASCII\000\
  WRITE_EVALUATED_ASCII\000\
  WRITE_BYTE\000\
  WRITE_LONG\000\
  WRITE_SHORT\000\
  WHILE\000\
  EOF\000\
  "

let yynames_block = "\
  STRING\000\
  SOUND\000\
  STRING_REF\000\
  TRANS_REF\000\
  FORCED_STRING_REF\000\
  "

let yyact = [|
  (fun _ -> failwith "parser")
; (fun parser_env ->
    let _1 = (peek_val parser_env 0 : Dc.action list) in
    Obj.repr(
# 242 "src/dparser.mly"
                       ( let answer = _1 @ !extra_actions in 
                         extra_actions := [] ;
                         answer )
# 2559 "src/dparser.ml"
               : Dc.action list))
; (fun parser_env ->
    Obj.repr(
# 247 "src/dparser.mly"
                        ( [] )
# 2565 "src/dparser.ml"
               : Dc.action list))
; (fun parser_env ->
    let _1 = (peek_val parser_env 1 : Dc.action) in
    let _2 = (peek_val parser_env 0 : Dc.action list) in
    Obj.repr(
# 248 "src/dparser.mly"
                        ( _1 :: _2 )
# 2573 "src/dparser.ml"
               : Dc.action list))
; (fun parser_env ->
    let _2 = (peek_val parser_env 0 : string) in
    Obj.repr(
# 252 "src/dparser.mly"
                           ( current_unit := Some(String.uppercase _2); (String.uppercase _2,0) )
# 2580 "src/dparser.ml"
               : (string * int)))
; (fun parser_env ->
    let _2 = (peek_val parser_env 1 : string) in
    let _3 = (peek_val parser_env 0 : string) in
    Obj.repr(
# 253 "src/dparser.mly"
                            ( current_unit := Some(String.uppercase _2); (String.uppercase _2,my_int_of_string _3) )
# 2588 "src/dparser.ml"
               : (string * int)))
; (fun parser_env ->
    let _2 = (peek_val parser_env 0 : string) in
    Obj.repr(
# 257 "src/dparser.mly"
      ( current_unit := Some(String.uppercase _2) ; 
        (String.uppercase _2) )
# 2596 "src/dparser.ml"
               : (string)))
; (fun parser_env ->
    let _2 = (peek_val parser_env 2 : string) in
    let _3 = (peek_val parser_env 1 : string list) in
    let _4 = (peek_val parser_env 0 : int) in
    Obj.repr(
# 262 "src/dparser.mly"
    ( current_unit := Some(String.uppercase _2) ; 
    (true,String.uppercase _2,_3,_4) )
# 2606 "src/dparser.ml"
               : (bool * string * (string list) * int)))
; (fun parser_env ->
    let _2 = (peek_val parser_env 2 : string) in
    let _3 = (peek_val parser_env 1 : string list) in
    let _4 = (peek_val parser_env 0 : int) in
    Obj.repr(
# 265 "src/dparser.mly"
    ( current_unit := Some(String.uppercase _2) ;
    (false,String.uppercase _2,_3,_4) )
# 2616 "src/dparser.ml"
               : (bool * string * (string list) * int)))
; (fun parser_env ->
    Obj.repr(
# 269 "src/dparser.mly"
                              ( 0 )
# 2622 "src/dparser.ml"
               : int))
; (fun parser_env ->
    let _1 = (peek_val parser_env 0 : int) in
    Obj.repr(
# 270 "src/dparser.mly"
                              ( _1 )
# 2629 "src/dparser.ml"
               : int))
; (fun parser_env ->
    let _2 = (peek_val parser_env 0 : string) in
    Obj.repr(
# 274 "src/dparser.mly"
    ( current_unit := Some(String.uppercase _2); (String.uppercase _2) )
# 2636 "src/dparser.ml"
               : (string)))
; (fun parser_env ->
    let _2 = (peek_val parser_env 3 : string) in
    let _3 = (peek_val parser_env 2 : string) in
    let _4 = (peek_val parser_env 1 : string) in
    let _5 = (peek_val parser_env 0 : string list) in
    Obj.repr(
# 278 "src/dparser.mly"
  ( current_unit := Some(String.uppercase _2); 
    (String.uppercase _2,_3 :: _5,_4) )
# 2647 "src/dparser.ml"
               : 'replace_state_trigger_prologue))
; (fun parser_env ->
    Obj.repr(
# 282 "src/dparser.mly"
                        ( [] )
# 2653 "src/dparser.ml"
               : 'opt_do_string_list))
; (fun parser_env ->
    let _2 = (peek_val parser_env 0 : string list) in
    Obj.repr(
# 283 "src/dparser.mly"
                        ( _2 )
# 2660 "src/dparser.ml"
               : 'opt_do_string_list))
; (fun parser_env ->
    let _2 = (peek_val parser_env 4 : string) in
    let _3 = (peek_val parser_env 3 : string) in
    let _4 = (peek_val parser_env 2 : string) in
    let _5 = (peek_val parser_env 1 : string list) in
    let _6 = (peek_val parser_env 0 : 'opt_do_string_list) in
    Obj.repr(
# 288 "src/dparser.mly"
  ( current_unit := Some(String.uppercase _2); 
    (String.uppercase _2,_3 :: _5,_4,_6) )
# 2672 "src/dparser.ml"
               : 'add_trans_trigger_prologue))
; (fun parser_env ->
    let _2 = (peek_val parser_env 3 : string) in
    let _3 = (peek_val parser_env 2 : string) in
    let _4 = (peek_val parser_env 1 : string) in
    let _5 = (peek_val parser_env 0 : string list) in
    Obj.repr(
# 292 "src/dparser.mly"
  ( current_unit := Some(String.uppercase _2); 
    (String.uppercase _2,_3 :: _5,_4) 
  )
# 2684 "src/dparser.ml"
               : 'add_state_trigger_prologue))
; (fun parser_env ->
    let _2 = (peek_val parser_env 2 : 'optional_weighted_condition) in
    let _3 = (peek_val parser_env 1 : string) in
    let _4 = (peek_val parser_env 0 : string) in
    Obj.repr(
# 298 "src/dparser.mly"
  ( current_unit := Some(String.uppercase _3); (_2,String.uppercase _3,_4) )
# 2693 "src/dparser.ml"
               : 'chain3_prologue))
; (fun parser_env ->
    let _2 = (peek_val parser_env 2 : string) in
    let _3 = (peek_val parser_env 1 : string) in
    let _4 = (peek_val parser_env 0 : string) in
    Obj.repr(
# 302 "src/dparser.mly"
  ( current_unit := Some(String.uppercase _2); (String.uppercase _2,_3,_4) )
# 2702 "src/dparser.ml"
               : (string * string * string)))
; (fun parser_env ->
    let _2 = (peek_val parser_env 2 : string) in
    let _3 = (peek_val parser_env 1 : string) in
    let _4 = (peek_val parser_env 0 : string) in
    Obj.repr(
# 306 "src/dparser.mly"
  ( current_unit := Some(String.uppercase _2); (String.uppercase _2,_3,_4) )
# 2711 "src/dparser.ml"
               : (string * string * string)))
; (fun parser_env ->
    let _1 = (peek_val parser_env 1 : (string * int)) in
    let _2 = (peek_val parser_env 0 : Dlg.state list) in
    Obj.repr(
# 310 "src/dparser.mly"
                          ( let name,flags = _1 in Dc.Create(
  { Dlg.name = name ;
    Dlg.state = Array.of_list _2 ;
    Dlg.dlg_flags = flags ; }))
# 2722 "src/dparser.ml"
               : Dc.action))
; (fun parser_env ->
    let _1 = (peek_val parser_env 2 : (string)) in
    let _2 = (peek_val parser_env 1 : Dlg.state list) in
    Obj.repr(
# 315 "src/dparser.mly"
  ( current_unit := None ; Dc.Append( _1 , _2 ) )
# 2730 "src/dparser.ml"
               : Dc.action))
; (fun parser_env ->
    let _1 = (peek_val parser_env 2 : (bool * string * (string list) * int)) in
    let _2 = (peek_val parser_env 1 : Dlg.transition list) in
    Obj.repr(
# 317 "src/dparser.mly"
  ( let top,ext_unit,ext_label,number = _1 in
    current_unit := None ; 
    if top then 
      Dc.Extend_Top( String.uppercase ext_unit, ext_label, number, _2 ) 
    else
      Dc.Extend_Bottom( String.uppercase ext_unit, ext_label, number, _2 ) 
  )
# 2744 "src/dparser.ml"
               : Dc.action))
; (fun parser_env ->
    let _1 = (peek_val parser_env 2 : (string)) in
    let _2 = (peek_val parser_env 1 : Dlg.state list) in
    Obj.repr(
# 325 "src/dparser.mly"
  ( current_unit := None ; 
    Dc.Replace(_1, _2) )
# 2753 "src/dparser.ml"
               : Dc.action))
; (fun parser_env ->
    let _2 = (peek_val parser_env 2 : string) in
    let _3 = (peek_val parser_env 1 : string) in
    let _4 = (peek_val parser_env 0 : Dlg.tlk_string) in
    Obj.repr(
# 328 "src/dparser.mly"
  ( Dc.Replace_Say(_2,_3,_4) )
# 2762 "src/dparser.ml"
               : Dc.action))
; (fun parser_env ->
    let _1 = (peek_val parser_env 0 : 'replace_state_trigger_prologue) in
    Obj.repr(
# 330 "src/dparser.mly"
  ( let f,s,t = _1 in 
    let verified_t = verify_trigger_list t in 
    current_unit := None ; 
    Dc.Replace_State_Trigger(f,s,verified_t) )
# 2772 "src/dparser.ml"
               : Dc.action))
; (fun parser_env ->
    let _1 = (peek_val parser_env 0 : 'add_state_trigger_prologue) in
    Obj.repr(
# 335 "src/dparser.mly"
  ( let f,s,t = _1 in 
    let verified_t = verify_trigger_list t in 
    current_unit := None ; 
    Dc.Add_State_Trigger(f,s,verified_t) )
# 2782 "src/dparser.ml"
               : Dc.action))
; (fun parser_env ->
    let _1 = (peek_val parser_env 0 : 'add_trans_trigger_prologue) in
    Obj.repr(
# 340 "src/dparser.mly"
  ( let f,s,t,tl = _1 in 
    let verified_t = verify_trigger_list t in 
    current_unit := None ; 
    Dc.Add_Trans_Trigger(f,s,verified_t,tl) )
# 2792 "src/dparser.ml"
               : Dc.action))
; (fun parser_env ->
    let _2 = (peek_val parser_env 2 : string) in
    let _3 = (peek_val parser_env 1 : string) in
    let _4 = (peek_val parser_env 0 : int) in
    Obj.repr(
# 345 "src/dparser.mly"
  ( Dc.Set_Weight(_2,_3,_4) )
# 2801 "src/dparser.ml"
               : Dc.action))
; (fun parser_env ->
    let _1 = (peek_val parser_env 3 : 'chain3_prologue) in
    let _2 = (peek_val parser_env 2 : ((string option) * Dlg.tlk_string * (string option)) list) in
    let _3 = (peek_val parser_env 1 : 'compound_chain3_list) in
    let _4 = (peek_val parser_env 0 : 'chain3_epilogue) in
    Obj.repr(
# 347 "src/dparser.mly"
  ( let (entry_weight,entry_cond),file,state = _1 in 
    let first_part = List.map (fun (cond,says,action) -> 
      {
        Dc.c3du_speaker = file ;
        Dc.c3du_condition = cond ;
        Dc.c3du_action = action ;
        Dc.c3du_say = says ;
        Dc.c3du_id = Dc.get_c3du_counter () ; 
      } ) _2 in 
    Dc.Chain3
    {
      Dc.c3_entry_condition = entry_cond;
      Dc.c3_entry_weight = entry_weight;
      Dc.c3_entry_file = file ;
      Dc.c3_entry_label = state ;
      Dc.c3_dialogue = first_part @ _3 ;
      Dc.c3_variable = None ; 
      Dc.c3_exit_trans = _4 ; 
    } 
  )
# 2830 "src/dparser.ml"
               : Dc.action))
; (fun parser_env ->
    let _1 = (peek_val parser_env 2 : (string * string * string)) in
    let _2 = (peek_val parser_env 1 : 'compound_chain3_list) in
    let _3 = (peek_val parser_env 0 : 'chain3_epilogue) in
    Obj.repr(
# 368 "src/dparser.mly"
  ( let file,label,var = _1 in 
    Dc.Chain3
    {
      Dc.c3_entry_condition = None;
      Dc.c3_entry_weight = Dlg.Not_Specified;
      Dc.c3_entry_file = file ;
      Dc.c3_entry_label = label ;
      Dc.c3_dialogue = _2 ;
      Dc.c3_variable = Some(var) ; 
      Dc.c3_exit_trans = _3 ;
    } 
  )
# 2850 "src/dparser.ml"
               : Dc.action))
; (fun parser_env ->
    let _1 = (peek_val parser_env 2 : (string * string * string)) in
    let _2 = (peek_val parser_env 1 : 'compound_chain3_list) in
    Obj.repr(
# 381 "src/dparser.mly"
  ( let file,label,var = _1 in 
    Dc.Chain3
    {
      Dc.c3_entry_condition = None;
      Dc.c3_entry_weight = Dlg.Not_Specified;
      Dc.c3_entry_file = file ;
      Dc.c3_entry_label = label ;
      Dc.c3_dialogue = _2 ;
      Dc.c3_variable = Some(var) ; 
      Dc.c3_exit_trans = [| Dlg.make_trans_of_next (Dlg.Copy(file,label)) |] 
    } 
  )
# 2869 "src/dparser.ml"
               : Dc.action))
; (fun parser_env ->
    let _2 = (peek_val parser_env 2 : string) in
    let _3 = (peek_val parser_env 1 : string) in
    let _4 = (peek_val parser_env 0 : string) in
    Obj.repr(
# 394 "src/dparser.mly"
  ( Dc.Replace_Trigger_Text(String.uppercase _2,_3,_4,false) )
# 2878 "src/dparser.ml"
               : Dc.action))
; (fun parser_env ->
    let _2 = (peek_val parser_env 2 : string) in
    let _3 = (peek_val parser_env 1 : string) in
    let _4 = (peek_val parser_env 0 : string) in
    Obj.repr(
# 396 "src/dparser.mly"
  ( Dc.Replace_Trigger_Text(String.uppercase _2,_3,_4,true) )
# 2887 "src/dparser.ml"
               : Dc.action))
; (fun parser_env ->
    let _2 = (peek_val parser_env 3 : string) in
    let _3 = (peek_val parser_env 2 : string) in
    let _4 = (peek_val parser_env 1 : string) in
    let _5 = (peek_val parser_env 0 : string list) in
    Obj.repr(
# 398 "src/dparser.mly"
  ( Dc.Replace_Action_Text(String.uppercase _2 :: _5,_3,_4) )
# 2897 "src/dparser.ml"
               : Dc.action))
; (fun parser_env ->
    let _2 = (peek_val parser_env 3 : string) in
    let _3 = (peek_val parser_env 2 : string) in
    let _4 = (peek_val parser_env 1 : string) in
    let _5 = (peek_val parser_env 0 : string list) in
    Obj.repr(
# 400 "src/dparser.mly"
  ( Dc.Replace_Action_Text(String.uppercase _2 :: _5,_3,verify_action_list _4) )
# 2907 "src/dparser.ml"
               : Dc.action))
; (fun parser_env ->
    let _1 = (peek_val parser_env 2 : string option) in
    let _2 = (peek_val parser_env 1 : Dlg.tlk_string) in
    let _3 = (peek_val parser_env 0 : 'optional_action) in
    Obj.repr(
# 403 "src/dparser.mly"
                                                         ( [(_1,_2,_3)] )
# 2916 "src/dparser.ml"
               : ((string option) * Dlg.tlk_string * (string option)) list))
; (fun parser_env ->
    let _1 = (peek_val parser_env 4 : string option) in
    let _2 = (peek_val parser_env 3 : Dlg.tlk_string) in
    let _3 = (peek_val parser_env 2 : 'optional_action) in
    let _5 = (peek_val parser_env 0 : ((string option) * Dlg.tlk_string * (string option)) list) in
    Obj.repr(
# 405 "src/dparser.mly"
  ( (_1,_2,_3) :: (List.map (fun (a,b,c) -> 
    match _1,a with
    | _,None -> (_1,b,c)
    | None,_ -> (a,b,c)
    | Some(first),Some(second) -> (Some(first ^ "\n" ^ second),b,c)
    ) _5) )
# 2931 "src/dparser.ml"
               : ((string option) * Dlg.tlk_string * (string option)) list))
; (fun parser_env ->
    Obj.repr(
# 413 "src/dparser.mly"
                        ( None )
# 2937 "src/dparser.ml"
               : 'optional_action))
; (fun parser_env ->
    let _2 = (peek_val parser_env 0 : string) in
    Obj.repr(
# 414 "src/dparser.mly"
                        ( let verified_action = verify_action_list _2 in 
                          Some(verified_action) )
# 2945 "src/dparser.ml"
               : 'optional_action))
; (fun parser_env ->
    let _2 = (peek_val parser_env 1 : string) in
    let _3 = (peek_val parser_env 0 : string) in
    Obj.repr(
# 419 "src/dparser.mly"
    ( let next = Dlg.Symbolic(String.uppercase _2,_3) in
      [| Dlg.make_trans_of_next next |] )
# 2954 "src/dparser.ml"
               : 'chain3_epilogue))
; (fun parser_env ->
    let _2 = (peek_val parser_env 1 : string) in
    let _3 = (peek_val parser_env 0 : string) in
    Obj.repr(
# 422 "src/dparser.mly"
    ( let next = Dlg.Symbolic(String.uppercase _2,_3) in
      [| Dlg.make_trans_of_next next |] )
# 2963 "src/dparser.ml"
               : 'chain3_epilogue))
; (fun parser_env ->
    let _2 = (peek_val parser_env 1 : string) in
    let _3 = (peek_val parser_env 0 : string) in
    Obj.repr(
# 425 "src/dparser.mly"
    ( let next = Dlg.Copy(String.uppercase _2,_3) in 
      [| Dlg.make_trans_of_next next |] )
# 2972 "src/dparser.ml"
               : 'chain3_epilogue))
; (fun parser_env ->
    Obj.repr(
# 428 "src/dparser.mly"
    ( let next = Dlg.Exit in 
      [| Dlg.make_trans_of_next next |] )
# 2979 "src/dparser.ml"
               : 'chain3_epilogue))
; (fun parser_env ->
    let _2 = (peek_val parser_env 0 : Dlg.transition list) in
    Obj.repr(
# 430 "src/dparser.mly"
                                     ( Array.of_list _2 )
# 2986 "src/dparser.ml"
               : 'chain3_epilogue))
; (fun parser_env ->
    Obj.repr(
# 433 "src/dparser.mly"
                                 ( ((Dlg.Not_Specified),(None)) )
# 2992 "src/dparser.ml"
               : 'optional_weighted_condition))
; (fun parser_env ->
    let _2 = (peek_val parser_env 2 : Dlg.weight) in
    let _3 = (peek_val parser_env 1 : string) in
    Obj.repr(
# 434 "src/dparser.mly"
                        ( (_2,(Some(verify_trigger_list _3))) )
# 3000 "src/dparser.ml"
               : 'optional_weighted_condition))
; (fun parser_env ->
    Obj.repr(
# 437 "src/dparser.mly"
                        ( None )
# 3006 "src/dparser.ml"
               : string option))
; (fun parser_env ->
    let _2 = (peek_val parser_env 1 : string) in
    let _3 = (peek_val parser_env 0 : 'optional_then) in
    Obj.repr(
# 438 "src/dparser.mly"
                                 ( Some(verify_trigger_list _2) )
# 3014 "src/dparser.ml"
               : string option))
; (fun parser_env ->
    Obj.repr(
# 441 "src/dparser.mly"
                                        ( [] )
# 3020 "src/dparser.ml"
               : 'compound_chain3_list))
; (fun parser_env ->
    let _2 = (peek_val parser_env 2 : string) in
    let _3 = (peek_val parser_env 1 : ((string option) * Dlg.tlk_string * (string option)) list) in
    let _4 = (peek_val parser_env 0 : 'compound_chain3_list) in
    Obj.repr(
# 443 "src/dparser.mly"
  ( let this_speaker = String.uppercase _2 in 
    let first_part = List.map (fun (cond,says,action) -> 
      { Dc.c3du_speaker = this_speaker ;
        Dc.c3du_condition = cond ;
        Dc.c3du_action = action ;
        Dc.c3du_say = says ; 
        Dc.c3du_id = Dc.get_c3du_counter () ; 
        }) _3 in 
    first_part @ _4 
  )
# 3038 "src/dparser.ml"
               : 'compound_chain3_list))
; (fun parser_env ->
    Obj.repr(
# 457 "src/dparser.mly"
                        ( [] )
# 3044 "src/dparser.ml"
               : Dlg.state list))
; (fun parser_env ->
    let _1 = (peek_val parser_env 1 : Dlg.state list) in
    let _2 = (peek_val parser_env 0 : Dlg.state list) in
    Obj.repr(
# 458 "src/dparser.mly"
                        ( _1 @ _2 )
# 3052 "src/dparser.ml"
               : Dlg.state list))
; (fun parser_env ->
    Obj.repr(
# 461 "src/dparser.mly"
                        ( Dlg.Not_Specified )
# 3058 "src/dparser.ml"
               : Dlg.weight))
; (fun parser_env ->
    let _2 = (peek_val parser_env 0 : int) in
    Obj.repr(
# 462 "src/dparser.mly"
                        ( Dlg.Offset(_2) )
# 3065 "src/dparser.ml"
               : Dlg.weight))
; (fun parser_env ->
    Obj.repr(
# 465 "src/dparser.mly"
               ( () )
# 3071 "src/dparser.ml"
               : 'optional_then))
; (fun parser_env ->
    Obj.repr(
# 466 "src/dparser.mly"
       ( () )
# 3077 "src/dparser.ml"
               : 'optional_then))
; (fun parser_env ->
    Obj.repr(
# 468 "src/dparser.mly"
                ( () )
# 3083 "src/dparser.ml"
               : 'optional_begin))
; (fun parser_env ->
    Obj.repr(
# 469 "src/dparser.mly"
        ( () )
# 3089 "src/dparser.ml"
               : 'optional_begin))
; (fun parser_env ->
    let _1 = (peek_val parser_env 0 : string) in
    Obj.repr(
# 473 "src/dparser.mly"
       ( if _1 = "" then "" else verify_trigger_list _1 )
# 3096 "src/dparser.ml"
               : 'state_trigger))
; (fun parser_env ->
    let _2 = (peek_val parser_env 8 : Dlg.weight) in
    let _3 = (peek_val parser_env 7 : 'state_trigger) in
    let _4 = (peek_val parser_env 6 : 'optional_then) in
    let _5 = (peek_val parser_env 5 : 'optional_begin) in
    let _6 = (peek_val parser_env 4 : string) in
    let _8 = (peek_val parser_env 2 : Dlg.tlk_string list) in
    let _9 = (peek_val parser_env 1 : Dlg.transition list) in
    Obj.repr(
# 480 "src/dparser.mly"
    (
      let state_trigger = _3 in 
      if List.length _8 = 1 then 
         [{ Dlg.resp_str = List.hd _8 ;
           Dlg.trans = Array.of_list _9 ; 
           Dlg.state_trigger = state_trigger ;
           Dlg.state_trigger_weight = _2 ; 
           Dlg.symbolic_label = _6 ; }]
      else begin
        let rec process_say_list sl in_label in_trig in_weight = match sl with
          s1 :: s2 :: tl -> 
            let new_label = Dc.chain_label () in
            let dest_file = get_current_unit () in 
            let new_state = Dlg.make_state s1 in_label dest_file new_label in
            new_state.Dlg.state_trigger_weight <- in_weight ; 
            new_state.Dlg.state_trigger <- in_trig ; 
            new_state :: (process_say_list (s2::tl) new_label "" Dlg.Not_Specified)
        | s1 :: [] -> [
          let state = Dlg.make_state_trans s1 in_label (Array.of_list _9)
          in state.Dlg.state_trigger_weight <- in_weight ;
          state ] 
        | [] -> [] 
        in 
        process_say_list _8 _6 _3 _2
      end
    )
# 3134 "src/dparser.ml"
               : Dlg.state list))
; (fun parser_env ->
    let _1 = (peek_val parser_env 2 : string option * string) in
    let _2 = (peek_val parser_env 1 : Dlg.state list) in
    Obj.repr(
# 508 "src/dparser.mly"
  (
    let old_unit, append_name = _1 in 
    extra_actions := (Dc.Append( append_name, _2 )) :: !extra_actions ;
    current_unit := old_unit ;
    [] 
  )
# 3147 "src/dparser.ml"
               : Dlg.state list))
; (fun parser_env ->
    let _2 = (peek_val parser_env 5 : string) in
    let _3 = (peek_val parser_env 4 : string) in
    let _4 = (peek_val parser_env 3 : (string * Dlg.tlk_string) list) in
    let _6 = (peek_val parser_env 1 : string) in
    let _7 = (peek_val parser_env 0 : string) in
    Obj.repr(
# 516 "src/dparser.mly"
  ( let rec convert cl extern_guy = match cl with
      [] -> []
    | (code,s) :: tl -> 
        let file = if extern_guy then _2 else get_current_unit () in
        let extern_guy = if code = "==" then not extern_guy else extern_guy in
        (file,s) :: convert tl extern_guy
    in 
    extra_actions := (Dc.Chain(
      { Dc.entry_file = String.uppercase _2 ;
        Dc.entry_label = _3 ;
        Dc.dialogue = convert _4 true;
        Dc.exit_file = String.uppercase _6 ;
        Dc.exit_label = _7 ;
      } )) :: !extra_actions ;
    []  
  )
# 3173 "src/dparser.ml"
               : Dlg.state list))
; (fun parser_env ->
    let _2 = (peek_val parser_env 0 : string) in
    Obj.repr(
# 535 "src/dparser.mly"
 ( let what = String.uppercase _2 in  
  let old = !current_unit in current_unit := Some(what); (old, what) )
# 3181 "src/dparser.ml"
               : string option * string))
; (fun parser_env ->
    let _1 = (peek_val parser_env 0 : Dlg.tlk_string) in
    Obj.repr(
# 539 "src/dparser.mly"
                                ( [("",_1)] )
# 3188 "src/dparser.ml"
               : (string * Dlg.tlk_string) list))
; (fun parser_env ->
    let _1 = (peek_val parser_env 2 : Dlg.tlk_string) in
    let _3 = (peek_val parser_env 0 : (string * Dlg.tlk_string) list) in
    Obj.repr(
# 540 "src/dparser.mly"
                                ( ("",_1) :: _3 )
# 3196 "src/dparser.ml"
               : (string * Dlg.tlk_string) list))
; (fun parser_env ->
    let _1 = (peek_val parser_env 2 : Dlg.tlk_string) in
    let _3 = (peek_val parser_env 0 : (string * Dlg.tlk_string) list) in
    Obj.repr(
# 541 "src/dparser.mly"
                                ( ("==",_1) :: _3 )
# 3204 "src/dparser.ml"
               : (string * Dlg.tlk_string) list))
; (fun parser_env ->
    let _1 = (peek_val parser_env 0 : Dlg.tlk_string) in
    Obj.repr(
# 544 "src/dparser.mly"
                                ( [_1] )
# 3211 "src/dparser.ml"
               : Dlg.tlk_string list))
; (fun parser_env ->
    let _1 = (peek_val parser_env 2 : Dlg.tlk_string) in
    let _3 = (peek_val parser_env 0 : Dlg.tlk_string list) in
    Obj.repr(
# 545 "src/dparser.mly"
                                ( _1 :: _3 )
# 3219 "src/dparser.ml"
               : Dlg.tlk_string list))
; (fun parser_env ->
    Obj.repr(
# 548 "src/dparser.mly"
                             ( [] )
# 3225 "src/dparser.ml"
               : Dlg.transition list))
; (fun parser_env ->
    let _1 = (peek_val parser_env 1 : Dlg.transition) in
    let _2 = (peek_val parser_env 0 : Dlg.transition list) in
    Obj.repr(
# 549 "src/dparser.mly"
                             ( _1 :: _2 )
# 3233 "src/dparser.ml"
               : Dlg.transition list))
; (fun parser_env ->
    let _2 = (peek_val parser_env 0 : Dlg.tlk_string) in
    Obj.repr(
# 553 "src/dparser.mly"
                 ( Trans_Reply(Some(_2)) )
# 3240 "src/dparser.ml"
               : trans_opt_type))
; (fun parser_env ->
    let _2 = (peek_val parser_env 0 : string) in
    Obj.repr(
# 554 "src/dparser.mly"
                 ( let verified_action = verify_action_list _2 in 
                    Trans_Do(Some(verified_action)) )
# 3248 "src/dparser.ml"
               : trans_opt_type))
; (fun parser_env ->
    let _2 = (peek_val parser_env 0 : Dlg.tlk_string) in
    Obj.repr(
# 556 "src/dparser.mly"
                 ( Trans_Journal(Some(Dlg.Normal_Journal,_2)) )
# 3255 "src/dparser.ml"
               : trans_opt_type))
; (fun parser_env ->
    let _2 = (peek_val parser_env 0 : Dlg.tlk_string) in
    Obj.repr(
# 557 "src/dparser.mly"
                        ( Trans_Journal(Some(Dlg.Solved_Journal,_2)) )
# 3262 "src/dparser.ml"
               : trans_opt_type))
; (fun parser_env ->
    let _2 = (peek_val parser_env 0 : Dlg.tlk_string) in
    Obj.repr(
# 558 "src/dparser.mly"
                          ( Trans_Journal(Some(Dlg.Unsolved_Journal,_2)) )
# 3269 "src/dparser.ml"
               : trans_opt_type))
; (fun parser_env ->
    let _2 = (peek_val parser_env 0 : string) in
    Obj.repr(
# 559 "src/dparser.mly"
                 ( Trans_Flags(my_int_of_string _2))
# 3276 "src/dparser.ml"
               : trans_opt_type))
; (fun parser_env ->
    Obj.repr(
# 562 "src/dparser.mly"
                                ( [] )
# 3282 "src/dparser.ml"
               : trans_opt_type list))
; (fun parser_env ->
    let _1 = (peek_val parser_env 1 : trans_opt_type) in
    let _2 = (peek_val parser_env 0 : trans_opt_type list) in
    Obj.repr(
# 563 "src/dparser.mly"
                                ( _1 :: _2 )
# 3290 "src/dparser.ml"
               : trans_opt_type list))
; (fun parser_env ->
    let _1 = (peek_val parser_env 0 : string) in
    Obj.repr(
# 566 "src/dparser.mly"
                       ( if _1 = "" then None else
  Some(verify_trigger_list _1) )
# 3298 "src/dparser.ml"
               : 'trans_trigger))
; (fun parser_env ->
    let _1 = (peek_val parser_env 0 : string) in
    Obj.repr(
# 570 "src/dparser.mly"
                         ( _1 )
# 3305 "src/dparser.ml"
               : 'optional_string))
; (fun parser_env ->
    Obj.repr(
# 571 "src/dparser.mly"
  ( "" )
# 3311 "src/dparser.ml"
               : 'optional_string))
; (fun parser_env ->
    let _2 = (peek_val parser_env 3 : 'trans_trigger) in
    let _3 = (peek_val parser_env 2 : 'optional_then) in
    let _4 = (peek_val parser_env 1 : trans_opt_type list) in
    let _5 = (peek_val parser_env 0 : Dlg.trans_next) in
    Obj.repr(
# 576 "src/dparser.mly"
  ( let result = { 
      Dlg.trans_trigger = _2 ; 
      Dlg.trans_str = None ;
      Dlg.action = None ;
      Dlg.journal_str = None;
      Dlg.unknown_flags = 0 ;
      Dlg.next = _5 ; 
    } in
    List.iter (fun elt -> match elt with
    | Trans_Reply(r) -> result.Dlg.trans_str <- r ;
    | Trans_Do(r) -> result.Dlg.action <- r ;
    | Trans_Journal(r) -> 
        (if (result.Dlg.journal_str <> None) then 
         try parse_error "You may only have one JOURNAL per transition.  Recovering." with _ -> ()) ;
        result.Dlg.journal_str <- r;
    | Trans_Flags(r) -> result.Dlg.unknown_flags <- r;
    ) _4 ;
    result 
  )
# 3339 "src/dparser.ml"
               : Dlg.transition))
; (fun parser_env ->
    let _2 = (peek_val parser_env 4 : 'optional_string) in
    let _4 = (peek_val parser_env 2 : Dlg.tlk_string) in
    let _5 = (peek_val parser_env 1 : trans_opt_type list) in
    let _6 = (peek_val parser_env 0 : Dlg.trans_next) in
    Obj.repr(
# 596 "src/dparser.mly"
  ( let result = { 
      Dlg.trans_trigger = 
        if _2 = "" then None
        else Some(verify_trigger_list _2) ; 
      Dlg.trans_str = Some(_4) ;
      Dlg.action = None ;
      Dlg.journal_str = None;
      Dlg.unknown_flags = 0 ;
      Dlg.next = _6 ; 
    } in
    List.iter (fun elt -> match elt with
    | Trans_Reply(r) -> result.Dlg.trans_str <- r ;
    | Trans_Do(r) -> result.Dlg.action <- r ;
    | Trans_Journal(r) -> result.Dlg.journal_str <- r;
    | Trans_Flags(r) -> result.Dlg.unknown_flags <- r;
    ) _5 ;
    result 
  )
# 3366 "src/dparser.ml"
               : Dlg.transition))
; (fun parser_env ->
    let _2 = (peek_val parser_env 1 : string) in
    let _3 = (peek_val parser_env 0 : string) in
    Obj.repr(
# 615 "src/dparser.mly"
  ( { 
      Dlg.trans_trigger = None ; 
      Dlg.trans_str = None ;
      Dlg.action = None ;
      Dlg.journal_str = None;
      Dlg.unknown_flags = 0 ;
      Dlg.next = Dlg.Copy(_2,_3) ;
    } 
  )
# 3382 "src/dparser.ml"
               : Dlg.transition))
; (fun parser_env ->
    let _2 = (peek_val parser_env 0 : string) in
    Obj.repr(
# 626 "src/dparser.mly"
                       ( Dlg.Symbolic(get_current_unit () ,_2) )
# 3389 "src/dparser.ml"
               : Dlg.trans_next))
; (fun parser_env ->
    let _2 = (peek_val parser_env 0 : string) in
    Obj.repr(
# 627 "src/dparser.mly"
                  ( Dlg.Symbolic(get_current_unit () ,_2) )
# 3396 "src/dparser.ml"
               : Dlg.trans_next))
; (fun parser_env ->
    let _2 = (peek_val parser_env 1 : string) in
    let _3 = (peek_val parser_env 0 : string) in
    Obj.repr(
# 628 "src/dparser.mly"
                       ( Dlg.Symbolic(String.uppercase _2,_3) )
# 3404 "src/dparser.ml"
               : Dlg.trans_next))
; (fun parser_env ->
    Obj.repr(
# 629 "src/dparser.mly"
                       ( Dlg.Exit )
# 3410 "src/dparser.ml"
               : Dlg.trans_next))
; (fun parser_env ->
    let _1 = (peek_val parser_env 1 : string) in
    let _2 = (peek_val parser_env 0 : string) in
    Obj.repr(
# 633 "src/dparser.mly"
  ( let result = Dlg.Local_String({ lse_male = _1 ; lse_male_sound = _2; 
                    lse_female = _1; lse_female_sound = _2;}) in 
    (match !Dlg.local_string_ht with
      Some(l) -> if not (List.mem result l ) then begin
          Dlg.local_string_ht := Some(result :: l )
        end 
    | _ -> () ) ;
    result
  )
# 3426 "src/dparser.ml"
               : Dlg.tlk_string))
; (fun parser_env ->
    let _1 = (peek_val parser_env 3 : string) in
    let _2 = (peek_val parser_env 2 : string) in
    let _3 = (peek_val parser_env 1 : string) in
    let _4 = (peek_val parser_env 0 : string) in
    Obj.repr(
# 643 "src/dparser.mly"
  ( let result = Dlg.Local_String({ lse_male = _1 ; lse_male_sound = _2; 
          lse_female = _3; lse_female_sound = _4; }) in 
    (match !Dlg.local_string_ht with
      Some(l) -> if not (List.mem result l) then 
        Dlg.local_string_ht := Some(result :: l)
    | _ -> () ) ;
    result
  )
# 3443 "src/dparser.ml"
               : Dlg.tlk_string))
; (fun parser_env ->
    let _1 = (peek_val parser_env 0 : int) in
    Obj.repr(
# 651 "src/dparser.mly"
             ( Dlg.TLK_Index(_1) )
# 3450 "src/dparser.ml"
               : Dlg.tlk_string))
; (fun parser_env ->
    let _1 = (peek_val parser_env 0 : int) in
    Obj.repr(
# 652 "src/dparser.mly"
             ( Dc.resolve_string_while_loading (Dlg.Trans_String(_1)) )
# 3457 "src/dparser.ml"
               : Dlg.tlk_string))
; (fun parser_env ->
    let _1 = (peek_val parser_env 1 : int) in
    let _2 = (peek_val parser_env 0 : Dlg.tlk_string) in
    Obj.repr(
# 654 "src/dparser.mly"
  ( let _ = Dc.set_string_while_loading _1 _2 in Dlg.TLK_Index(_1) )
# 3465 "src/dparser.ml"
               : Dlg.tlk_string))
; (fun parser_env ->
    Obj.repr(
# 657 "src/dparser.mly"
                        ( "" )
# 3471 "src/dparser.ml"
               : string))
; (fun parser_env ->
    let _1 = (peek_val parser_env 0 : string) in
    Obj.repr(
# 658 "src/dparser.mly"
                        ( _1 )
# 3478 "src/dparser.ml"
               : string))
; (fun parser_env ->
    Obj.repr(
# 661 "src/dparser.mly"
                        ( [] )
# 3484 "src/dparser.ml"
               : (int * Dlg.tlk_string) list))
; (fun parser_env ->
    let _1 = (peek_val parser_env 3 : int) in
    let _3 = (peek_val parser_env 1 : Dlg.tlk_string) in
    let _4 = (peek_val parser_env 0 : (int * Dlg.tlk_string) list) in
    Obj.repr(
# 662 "src/dparser.mly"
                                ( (_1,_3) :: _4 )
# 3493 "src/dparser.ml"
               : (int * Dlg.tlk_string) list))
; (fun parser_env ->
    let _2 = (peek_val parser_env 5 : string) in
    let _4 = (peek_val parser_env 3 : string) in
    let _5 = (peek_val parser_env 2 : Tp.tp_flag list) in
    let _6 = (peek_val parser_env 1 : Tp.tp_lang list) in
    let _7 = (peek_val parser_env 0 : Tp.tp_mod list) in
    Obj.repr(
# 667 "src/dparser.mly"
  ( { Tp.backup = _2;
      Tp.author = _4; 
      Tp.flags = _5 ;
      Tp.languages = _6 ;
      Tp.modules = _7 ;
  } )
# 3509 "src/dparser.ml"
               : Tp.tp_file))
; (fun parser_env ->
    Obj.repr(
# 675 "src/dparser.mly"
                                ( [] )
# 3515 "src/dparser.ml"
               : Tp.tp_flag list))
; (fun parser_env ->
    let _2 = (peek_val parser_env 1 : string) in
    let _3 = (peek_val parser_env 0 : Tp.tp_flag list) in
    Obj.repr(
# 676 "src/dparser.mly"
                                       ( (Tp.Auto_Tra(_2)) :: _3 )
# 3523 "src/dparser.ml"
               : Tp.tp_flag list))
; (fun parser_env ->
    let _2 = (peek_val parser_env 1 : string) in
    let _3 = (peek_val parser_env 0 : Tp.tp_flag list) in
    Obj.repr(
# 677 "src/dparser.mly"
                                       ( (Tp.Menu_Style(_2)) :: _3 )
# 3531 "src/dparser.ml"
               : Tp.tp_flag list))
; (fun parser_env ->
    let _2 = (peek_val parser_env 0 : Tp.tp_flag list) in
    Obj.repr(
# 678 "src/dparser.mly"
                                       ( (Tp.Ask_Every_Component) :: _2 )
# 3538 "src/dparser.ml"
               : Tp.tp_flag list))
; (fun parser_env ->
    let _2 = (peek_val parser_env 2 : Tp.tp_action list) in
    let _4 = (peek_val parser_env 0 : Tp.tp_flag list) in
    Obj.repr(
# 679 "src/dparser.mly"
                                           ( (Tp.Always(_2)) :: _4 )
# 3546 "src/dparser.ml"
               : Tp.tp_flag list))
; (fun parser_env ->
    let _2 = (peek_val parser_env 1 : string list) in
    let _3 = (peek_val parser_env 0 : Tp.tp_flag list) in
    Obj.repr(
# 681 "src/dparser.mly"
    ( Tp.Allow_Missing(_2) :: _3 )
# 3554 "src/dparser.ml"
               : Tp.tp_flag list))
; (fun parser_env ->
    Obj.repr(
# 684 "src/dparser.mly"
                               ( [] )
# 3560 "src/dparser.ml"
               : string list))
; (fun parser_env ->
    let _1 = (peek_val parser_env 1 : string) in
    let _2 = (peek_val parser_env 0 : string list) in
    Obj.repr(
# 685 "src/dparser.mly"
                            ( (String.uppercase _1) :: _2 )
# 3568 "src/dparser.ml"
               : string list))
; (fun parser_env ->
    Obj.repr(
# 688 "src/dparser.mly"
                 ( [] )
# 3574 "src/dparser.ml"
               : Tp.tp_lang list))
; (fun parser_env ->
    let _2 = (peek_val parser_env 3 : string) in
    let _3 = (peek_val parser_env 2 : string) in
    let _4 = (peek_val parser_env 1 : string list) in
    let _5 = (peek_val parser_env 0 : Tp.tp_lang list) in
    Obj.repr(
# 690 "src/dparser.mly"
  ( { Tp.lang_name = _2 ;
      Tp.lang_dir_name = _3 ;
      Tp.lang_tra_files = _4 ;
  } :: _5 )
# 3587 "src/dparser.ml"
               : Tp.tp_lang list))
; (fun parser_env ->
    Obj.repr(
# 696 "src/dparser.mly"
                      ( [] )
# 3593 "src/dparser.ml"
               : Tp.tp_mod list))
; (fun parser_env ->
    let _2 = (peek_val parser_env 3 : Dlg.tlk_string) in
    let _3 = (peek_val parser_env 2 : 'tp_mod_flag_list) in
    let _4 = (peek_val parser_env 1 : Tp.tp_action list) in
    let _5 = (peek_val parser_env 0 : Tp.tp_mod list) in
    Obj.repr(
# 700 "src/dparser.mly"
  ( { Tp.mod_name = _2 ; Tp.mod_parts = _4 ; 
      Tp.mod_flags = _3 } :: _5 )
# 3604 "src/dparser.ml"
               : Tp.tp_mod list))
; (fun parser_env ->
    Obj.repr(
# 704 "src/dparser.mly"
                      ( [] )
# 3610 "src/dparser.ml"
               : 'tp_mod_flag_list))
; (fun parser_env ->
    let _2 = (peek_val parser_env 1 : Dlg.tlk_string) in
    let _3 = (peek_val parser_env 0 : 'tp_mod_flag_list) in
    Obj.repr(
# 705 "src/dparser.mly"
                                  ( Tp.TPM_Deprecated(_2) :: _3 )
# 3618 "src/dparser.ml"
               : 'tp_mod_flag_list))
; (fun parser_env ->
    let _2 = (peek_val parser_env 3 : string) in
    let _3 = (peek_val parser_env 2 : string) in
    let _4 = (peek_val parser_env 1 : Dlg.tlk_string) in
    let _5 = (peek_val parser_env 0 : 'tp_mod_flag_list) in
    Obj.repr(
# 707 "src/dparser.mly"
  ( Tp.TPM_RequireComponent(_2,(my_int_of_string _3),_4) :: _5 )
# 3628 "src/dparser.ml"
               : 'tp_mod_flag_list))
; (fun parser_env ->
    let _2 = (peek_val parser_env 3 : string) in
    let _3 = (peek_val parser_env 2 : string) in
    let _4 = (peek_val parser_env 1 : Dlg.tlk_string) in
    let _5 = (peek_val parser_env 0 : 'tp_mod_flag_list) in
    Obj.repr(
# 709 "src/dparser.mly"
  ( Tp.TPM_ForbidComponent(_2,(my_int_of_string _3),_4) :: _5 )
# 3638 "src/dparser.ml"
               : 'tp_mod_flag_list))
; (fun parser_env ->
    Obj.repr(
# 712 "src/dparser.mly"
                            ( [] )
# 3644 "src/dparser.ml"
               : Tp.tp_action list))
; (fun parser_env ->
    let _1 = (peek_val parser_env 1 : Tp.tp_action) in
    let _2 = (peek_val parser_env 0 : Tp.tp_action list) in
    Obj.repr(
# 713 "src/dparser.mly"
                            ( _1 :: _2 )
# 3652 "src/dparser.ml"
               : Tp.tp_action list))
; (fun parser_env ->
    Obj.repr(
# 716 "src/dparser.mly"
                                ( [] )
# 3658 "src/dparser.ml"
               : 'optional_using))
; (fun parser_env ->
    let _2 = (peek_val parser_env 0 : string list) in
    Obj.repr(
# 717 "src/dparser.mly"
                                ( _2 )
# 3665 "src/dparser.ml"
               : 'optional_using))
; (fun parser_env ->
    Obj.repr(
# 720 "src/dparser.mly"
                    ( true )
# 3671 "src/dparser.ml"
               : 'optional_plus))
; (fun parser_env ->
    Obj.repr(
# 721 "src/dparser.mly"
                    ( false )
# 3677 "src/dparser.ml"
               : 'optional_plus))
; (fun parser_env ->
    Obj.repr(
# 724 "src/dparser.mly"
                    ( false )
# 3683 "src/dparser.ml"
               : 'optional_glob))
; (fun parser_env ->
    Obj.repr(
# 725 "src/dparser.mly"
                    ( true )
# 3689 "src/dparser.ml"
               : 'optional_glob))
; (fun parser_env ->
    let _2 = (peek_val parser_env 4 : 'optional_plus) in
    let _3 = (peek_val parser_env 3 : 'optional_glob) in
    let _4 = (peek_val parser_env 2 : (string * string) list) in
    let _5 = (peek_val parser_env 1 : Tp.tp_patch list) in
    let _6 = (peek_val parser_env 0 : Tp.tp_constraint list) in
    Obj.repr(
# 730 "src/dparser.mly"
  ( Tp.TP_Copy(
      { Tp.copy_get_existing = false;
        Tp.copy_use_regexp = false; 
        Tp.copy_use_glob = _3; 
        Tp.copy_file_list = _4 ;
        Tp.copy_patch_list = _5 ;
        Tp.copy_constraint_list = _6;
        Tp.copy_backup = _2 ; } ) )
# 3707 "src/dparser.ml"
               : Tp.tp_action))
; (fun parser_env ->
    let _2 = (peek_val parser_env 3 : 'optional_plus) in
    let _3 = (peek_val parser_env 2 : (string * string) list) in
    let _4 = (peek_val parser_env 1 : Tp.tp_patch list) in
    let _5 = (peek_val parser_env 0 : Tp.tp_constraint list) in
    Obj.repr(
# 739 "src/dparser.mly"
  ( Tp.TP_Copy(
      { Tp.copy_get_existing = true;
        Tp.copy_use_regexp = false; 
        Tp.copy_use_glob = false;
        Tp.copy_file_list = _3 ;
        Tp.copy_patch_list = _4 ;
        Tp.copy_constraint_list = _5;
        Tp.copy_backup = _2 ; } ) )
# 3724 "src/dparser.ml"
               : Tp.tp_action))
; (fun parser_env ->
    let _2 = (peek_val parser_env 4 : 'optional_plus) in
    let _3 = (peek_val parser_env 3 : 'optional_glob) in
    let _4 = (peek_val parser_env 2 : (string * string) list) in
    let _5 = (peek_val parser_env 1 : Tp.tp_patch list) in
    let _6 = (peek_val parser_env 0 : Tp.tp_constraint list) in
    Obj.repr(
# 748 "src/dparser.mly"
  ( Tp.TP_Copy(
      { Tp.copy_get_existing = true;
        Tp.copy_use_regexp = true; 
        Tp.copy_use_glob = _3; 
        Tp.copy_file_list = _4 ;
        Tp.copy_patch_list = _5 ;
        Tp.copy_constraint_list = _6;
        Tp.copy_backup = _2 ; } ) )
# 3742 "src/dparser.ml"
               : Tp.tp_action))
; (fun parser_env ->
    let _2 = (peek_val parser_env 1 : string list) in
    let _3 = (peek_val parser_env 0 : Tp.tp_patch list) in
    Obj.repr(
# 756 "src/dparser.mly"
                                        ( Tp.TP_CopyRandom(_2,_3) )
# 3750 "src/dparser.ml"
               : Tp.tp_action))
; (fun parser_env ->
    let _2 = (peek_val parser_env 0 : string) in
    Obj.repr(
# 757 "src/dparser.mly"
                     ( Tp.TP_RandomSeed(my_int_of_string _2) )
# 3757 "src/dparser.ml"
               : Tp.tp_action))
; (fun parser_env ->
    let _2 = (peek_val parser_env 1 : string list) in
    let _3 = (peek_val parser_env 0 : 'optional_using) in
    Obj.repr(
# 758 "src/dparser.mly"
                                     ( Tp.TP_Compile(_2,_3) )
# 3765 "src/dparser.ml"
               : Tp.tp_action))
; (fun parser_env ->
    let _2 = (peek_val parser_env 0 : string list) in
    Obj.repr(
# 759 "src/dparser.mly"
                    ( Tp.TP_Mkdir(_2) )
# 3772 "src/dparser.ml"
               : Tp.tp_action))
; (fun parser_env ->
    let _2 = (peek_val parser_env 1 : string) in
    let _3 = (peek_val parser_env 0 : Dlg.tlk_string) in
    Obj.repr(
# 760 "src/dparser.mly"
                          ( Tp.TP_Require_File(_2,_3) )
# 3780 "src/dparser.ml"
               : Tp.tp_action))
; (fun parser_env ->
    let _2 = (peek_val parser_env 1 : string) in
    let _3 = (peek_val parser_env 0 : Dlg.tlk_string) in
    Obj.repr(
# 761 "src/dparser.mly"
                         ( Tp.TP_Forbid_File(_2,_3) )
# 3788 "src/dparser.ml"
               : Tp.tp_action))
; (fun parser_env ->
    let _2 = (peek_val parser_env 2 : string) in
    let _3 = (peek_val parser_env 1 : string) in
    let _4 = (peek_val parser_env 0 : Tp.tp_constraint list) in
    Obj.repr(
# 762 "src/dparser.mly"
                                    ( Tp.TP_Append(_2,_3,_4) )
# 3797 "src/dparser.ml"
               : Tp.tp_action))
; (fun parser_env ->
    let _2 = (peek_val parser_env 2 : string) in
    let _3 = (peek_val parser_env 1 : string) in
    let _4 = (peek_val parser_env 0 : Tp.tp_constraint list) in
    Obj.repr(
# 764 "src/dparser.mly"
    ( let lst = Str.split (Str.regexp "[ \t]+") _3 in
      let lst = List.map (fun elt -> if elt = "$" then "" else elt) lst in
      Tp.TP_Append_Col(_2,lst,_4) )
# 3808 "src/dparser.ml"
               : Tp.tp_action))
; (fun parser_env ->
    let _2 = (peek_val parser_env 3 : string) in
    let _3 = (peek_val parser_env 2 : string) in
    let _4 = (peek_val parser_env 1 : Tp.tp_patch list) in
    let _5 = (peek_val parser_env 0 : 'optional_using) in
    Obj.repr(
# 768 "src/dparser.mly"
    ( Tp.TP_Extend_Top(false,_2,_3,_4,_5) )
# 3818 "src/dparser.ml"
               : Tp.tp_action))
; (fun parser_env ->
    let _2 = (peek_val parser_env 3 : string) in
    let _3 = (peek_val parser_env 2 : string) in
    let _4 = (peek_val parser_env 1 : Tp.tp_patch list) in
    let _5 = (peek_val parser_env 0 : 'optional_using) in
    Obj.repr(
# 770 "src/dparser.mly"
    ( Tp.TP_Extend_Bottom(false,_2,_3,_4,_5) )
# 3828 "src/dparser.ml"
               : Tp.tp_action))
; (fun parser_env ->
    let _2 = (peek_val parser_env 3 : string) in
    let _3 = (peek_val parser_env 2 : string) in
    let _4 = (peek_val parser_env 1 : Tp.tp_patch list) in
    let _5 = (peek_val parser_env 0 : 'optional_using) in
    Obj.repr(
# 772 "src/dparser.mly"
    ( Tp.TP_Extend_Top(true,_2,_3,_4,_5) )
# 3838 "src/dparser.ml"
               : Tp.tp_action))
; (fun parser_env ->
    let _2 = (peek_val parser_env 3 : string) in
    let _3 = (peek_val parser_env 2 : string) in
    let _4 = (peek_val parser_env 1 : Tp.tp_patch list) in
    let _5 = (peek_val parser_env 0 : 'optional_using) in
    Obj.repr(
# 774 "src/dparser.mly"
    ( Tp.TP_Extend_Bottom(true,_2,_3,_4,_5) )
# 3848 "src/dparser.ml"
               : Tp.tp_action))
; (fun parser_env ->
    let _2 = (peek_val parser_env 0 : string) in
    Obj.repr(
# 775 "src/dparser.mly"
                 ( Tp.TP_At_Exit(_2) )
# 3855 "src/dparser.ml"
               : Tp.tp_action))
; (fun parser_env ->
    let _2 = (peek_val parser_env 0 : string) in
    Obj.repr(
# 776 "src/dparser.mly"
                             ( Tp.TP_At_Interactive_Exit(_2) )
# 3862 "src/dparser.ml"
               : Tp.tp_action))
; (fun parser_env ->
    let _2 = (peek_val parser_env 0 : string) in
    Obj.repr(
# 777 "src/dparser.mly"
                                  ( Tp.TP_At_Interactive_Uninstall(_2) )
# 3869 "src/dparser.ml"
               : Tp.tp_action))
; (fun parser_env ->
    let _2 = (peek_val parser_env 0 : string) in
    Obj.repr(
# 778 "src/dparser.mly"
                      ( Tp.TP_At_Uninstall(_2) )
# 3876 "src/dparser.ml"
               : Tp.tp_action))
; (fun parser_env ->
    let _2 = (peek_val parser_env 1 : string) in
    let _3 = (peek_val parser_env 0 : string) in
    Obj.repr(
# 779 "src/dparser.mly"
                          ( Tp.TP_Add_Music(
    { Tp.music_name = _2; 
      Tp.music_file = _3; } ) )
# 3886 "src/dparser.ml"
               : Tp.tp_action))
; (fun parser_env ->
    let _2 = (peek_val parser_env 0 : string) in
    Obj.repr(
# 782 "src/dparser.mly"
                        ( 
  Tp.TP_Add_Projectile( { Tp.pro_file = _2; } ) )
# 3894 "src/dparser.ml"
               : Tp.tp_action))
; (fun parser_env ->
    let _2 = (peek_val parser_env 1 : string) in
    let _3 = (peek_val parser_env 0 : Dlg.tlk_string) in
    Obj.repr(
# 784 "src/dparser.mly"
                        ( Tp.TP_String_Set(_2,_3) )
# 3902 "src/dparser.ml"
               : Tp.tp_action))
; (fun parser_env ->
    let _2 = (peek_val parser_env 1 : string) in
    let _3 = (peek_val parser_env 0 : string) in
    Obj.repr(
# 785 "src/dparser.mly"
                          ( Tp.TP_Uninstall_Now(_2,(my_int_of_string _3)) )
# 3910 "src/dparser.ml"
               : Tp.tp_action))
; (fun parser_env ->
    let _2 = (peek_val parser_env 19 : string) in
    let _3 = (peek_val parser_env 18 : string) in
    let _4 = (peek_val parser_env 17 : string) in
    let _5 = (peek_val parser_env 16 : string) in
    let _6 = (peek_val parser_env 15 : string) in
    let _7 = (peek_val parser_env 14 : string) in
    let _8 = (peek_val parser_env 13 : string) in
    let _9 = (peek_val parser_env 12 : string) in
    let _10 = (peek_val parser_env 11 : string) in
    let _11 = (peek_val parser_env 10 : string) in
    let _12 = (peek_val parser_env 9 : string) in
    let _13 = (peek_val parser_env 8 : string) in
    let _14 = (peek_val parser_env 7 : string) in
    let _15 = (peek_val parser_env 6 : string) in
    let _17 = (peek_val parser_env 4 : Dlg.tlk_string) in
    let _19 = (peek_val parser_env 2 : Dlg.tlk_string) in
    let _21 = (peek_val parser_env 0 : Dlg.tlk_string) in
    Obj.repr(
# 804 "src/dparser.mly"
  ( Tp.TP_Add_Kit(
   { Tp.kit_name = _2 ;
    Tp.clasweap = _3 ; 
    Tp.weapprof = _4 ;
    Tp.abclasrq = _5 ;
    Tp.abclsmod = _6 ;
    Tp.abdcdsrq = _7 ;
    Tp.abdcscrq = _8 ;
    Tp.alignmnt = _9 ;
    Tp.dualclas = _10 ;
    Tp.ability_file = _11 ;
    Tp.include_in = _12 ;
    Tp.unused_class = _13 ;
    Tp.tob_abbr = _14; 
    Tp.tob_start = 
      (let lst = Str.split (Str.regexp "[ \t]+") _15 in
      List.map (fun elt -> if elt = "$" then "" else elt) lst) ;
    Tp.lower = _17 ;
    Tp.mixed = _19 ;
    Tp.help = _21 ;
  }))
# 3953 "src/dparser.ml"
               : Tp.tp_action))
; (fun parser_env ->
    let _2 = (peek_val parser_env 0 : Dlg.tlk_string) in
    Obj.repr(
# 825 "src/dparser.mly"
                 ( Tp.TP_Fail(_2) )
# 3960 "src/dparser.ml"
               : Tp.tp_action))
; (fun parser_env ->
    let _2 = (peek_val parser_env 0 : Dlg.tlk_string) in
    Obj.repr(
# 826 "src/dparser.mly"
                  ( Tp.TP_Print(_2) )
# 3967 "src/dparser.ml"
               : Tp.tp_action))
; (fun parser_env ->
    let _2 = (peek_val parser_env 4 : 'tp_predicate) in
    let _5 = (peek_val parser_env 1 : Tp.tp_action list) in
    Obj.repr(
# 827 "src/dparser.mly"
                                                       ( Tp.TP_If(_2,_5,[]) )
# 3975 "src/dparser.ml"
               : Tp.tp_action))
; (fun parser_env ->
    let _2 = (peek_val parser_env 8 : 'tp_predicate) in
    let _5 = (peek_val parser_env 5 : Tp.tp_action list) in
    let _9 = (peek_val parser_env 1 : Tp.tp_action list) in
    Obj.repr(
# 829 "src/dparser.mly"
                             ( Tp.TP_If(_2,_5,_9) )
# 3984 "src/dparser.ml"
               : Tp.tp_action))
; (fun parser_env ->
    let _2 = (peek_val parser_env 1 : 'tp_predicate) in
    Obj.repr(
# 832 "src/dparser.mly"
                                          ( _2 )
# 3991 "src/dparser.ml"
               : 'tp_predicate))
; (fun parser_env ->
    let _1 = (peek_val parser_env 2 : 'tp_predicate) in
    let _3 = (peek_val parser_env 0 : 'tp_predicate) in
    Obj.repr(
# 833 "src/dparser.mly"
                                ( Tp.Pred_And(_1,_3) )
# 3999 "src/dparser.ml"
               : 'tp_predicate))
; (fun parser_env ->
    let _1 = (peek_val parser_env 2 : 'tp_predicate) in
    let _3 = (peek_val parser_env 0 : 'tp_predicate) in
    Obj.repr(
# 834 "src/dparser.mly"
                               ( Tp.Pred_Or(_1,_3) )
# 4007 "src/dparser.ml"
               : 'tp_predicate))
; (fun parser_env ->
    let _2 = (peek_val parser_env 0 : 'tp_predicate) in
    Obj.repr(
# 835 "src/dparser.mly"
                   ( Tp.Pred_Not(_2) )
# 4014 "src/dparser.ml"
               : 'tp_predicate))
; (fun parser_env ->
    let _2 = (peek_val parser_env 0 : string) in
    Obj.repr(
# 836 "src/dparser.mly"
                     ( Tp.Pred_File_Exists(_2) )
# 4021 "src/dparser.ml"
               : 'tp_predicate))
; (fun parser_env ->
    let _2 = (peek_val parser_env 1 : string) in
    let _3 = (peek_val parser_env 0 : string) in
    Obj.repr(
# 837 "src/dparser.mly"
                         ( Tp.Pred_File_MD5(_2,_3) )
# 4029 "src/dparser.ml"
               : 'tp_predicate))
; (fun parser_env ->
    let _2 = (peek_val parser_env 0 : string) in
    Obj.repr(
# 838 "src/dparser.mly"
                             ( Tp.Pred_File_Exists_In_Game(_2) )
# 4036 "src/dparser.ml"
               : 'tp_predicate))
; (fun parser_env ->
    let _2 = (peek_val parser_env 1 : string) in
    let _3 = (peek_val parser_env 0 : string) in
    Obj.repr(
# 839 "src/dparser.mly"
                          ( Tp.Pred_File_Size(_2,my_int_of_string _3) )
# 4044 "src/dparser.ml"
               : 'tp_predicate))
; (fun parser_env ->
    let _2 = (peek_val parser_env 1 : string) in
    let _3 = (peek_val parser_env 0 : string) in
    Obj.repr(
# 840 "src/dparser.mly"
                              ( Tp.Pred_File_Contains(_2,_3) )
# 4052 "src/dparser.ml"
               : 'tp_predicate))
; (fun parser_env ->
    Obj.repr(
# 844 "src/dparser.mly"
                         ( [] )
# 4058 "src/dparser.ml"
               : string list))
; (fun parser_env ->
    let _1 = (peek_val parser_env 1 : string) in
    let _2 = (peek_val parser_env 0 : string list) in
    Obj.repr(
# 845 "src/dparser.mly"
                      ( _1 :: _2 )
# 4066 "src/dparser.ml"
               : string list))
; (fun parser_env ->
    Obj.repr(
# 848 "src/dparser.mly"
                               ( [] )
# 4072 "src/dparser.ml"
               : Tp.tp_constraint list))
; (fun parser_env ->
    let _2 = (peek_val parser_env 1 : string) in
    let _3 = (peek_val parser_env 0 : Tp.tp_constraint list) in
    Obj.repr(
# 849 "src/dparser.mly"
                               ( Tp.TP_Contains(_2) :: _3 )
# 4080 "src/dparser.ml"
               : Tp.tp_constraint list))
; (fun parser_env ->
    let _2 = (peek_val parser_env 1 : string) in
    let _3 = (peek_val parser_env 0 : Tp.tp_constraint list) in
    Obj.repr(
# 850 "src/dparser.mly"
                               ( Tp.TP_NotContains(_2) :: _3 )
# 4088 "src/dparser.ml"
               : Tp.tp_constraint list))
; (fun parser_env ->
    let _2 = (peek_val parser_env 1 : string) in
    let _3 = (peek_val parser_env 0 : Tp.tp_constraint list) in
    Obj.repr(
# 851 "src/dparser.mly"
                                 ( Tp.TP_IfSizeIs(my_int_of_string _2) :: _3 )
# 4096 "src/dparser.ml"
               : Tp.tp_constraint list))
; (fun parser_env ->
    let _2 = (peek_val parser_env 1 : 'patch_exp) in
    let _3 = (peek_val parser_env 0 : Tp.tp_constraint list) in
    Obj.repr(
# 852 "src/dparser.mly"
                                 ( Tp.TP_Eval(_2) :: _3 )
# 4104 "src/dparser.ml"
               : Tp.tp_constraint list))
; (fun parser_env ->
    let _2 = (peek_val parser_env 0 : Tp.tp_constraint list) in
    Obj.repr(
# 853 "src/dparser.mly"
                                             ( Tp.TP_ButOnlyIfItChanges :: _2 )
# 4111 "src/dparser.ml"
               : Tp.tp_constraint list))
; (fun parser_env ->
    Obj.repr(
# 856 "src/dparser.mly"
                             ( [] )
# 4117 "src/dparser.ml"
               : (string * string) list))
; (fun parser_env ->
    let _1 = (peek_val parser_env 2 : string) in
    let _2 = (peek_val parser_env 1 : string) in
    let _3 = (peek_val parser_env 0 : (string * string) list) in
    Obj.repr(
# 857 "src/dparser.mly"
                             ( (_1,_2) :: _3 )
# 4126 "src/dparser.ml"
               : (string * string) list))
; (fun parser_env ->
    let _1 = (peek_val parser_env 0 : string) in
    Obj.repr(
# 860 "src/dparser.mly"
                                ( Tp.PE_String(_1) )
# 4133 "src/dparser.ml"
               : 'patch_exp))
; (fun parser_env ->
    let _2 = (peek_val parser_env 1 : 'patch_exp) in
    Obj.repr(
# 861 "src/dparser.mly"
                                ( _2 )
# 4140 "src/dparser.ml"
               : 'patch_exp))
; (fun parser_env ->
    let _1 = (peek_val parser_env 2 : 'patch_exp) in
    let _3 = (peek_val parser_env 0 : 'patch_exp) in
    Obj.repr(
# 862 "src/dparser.mly"
                                ( Tp.PE_Add(_1,_3) )
# 4148 "src/dparser.ml"
               : 'patch_exp))
; (fun parser_env ->
    let _1 = (peek_val parser_env 2 : 'patch_exp) in
    let _3 = (peek_val parser_env 0 : 'patch_exp) in
    Obj.repr(
# 863 "src/dparser.mly"
                                 ( Tp.PE_Sub(_1,_3) )
# 4156 "src/dparser.ml"
               : 'patch_exp))
; (fun parser_env ->
    let _1 = (peek_val parser_env 2 : 'patch_exp) in
    let _3 = (peek_val parser_env 0 : 'patch_exp) in
    Obj.repr(
# 864 "src/dparser.mly"
                                 ( Tp.PE_Mul(_1,_3) )
# 4164 "src/dparser.ml"
               : 'patch_exp))
; (fun parser_env ->
    let _1 = (peek_val parser_env 2 : 'patch_exp) in
    let _3 = (peek_val parser_env 0 : 'patch_exp) in
    Obj.repr(
# 865 "src/dparser.mly"
                                  ( Tp.PE_Div(_1,_3) )
# 4172 "src/dparser.ml"
               : 'patch_exp))
; (fun parser_env ->
    let _1 = (peek_val parser_env 2 : 'patch_exp) in
    let _3 = (peek_val parser_env 0 : 'patch_exp) in
    Obj.repr(
# 866 "src/dparser.mly"
                              ( Tp.PE_Equal(_1,_3) )
# 4180 "src/dparser.ml"
               : 'patch_exp))
; (fun parser_env ->
    let _2 = (peek_val parser_env 0 : 'patch_exp) in
    Obj.repr(
# 867 "src/dparser.mly"
                              ( Tp.PE_Not(_2) )
# 4187 "src/dparser.ml"
               : 'patch_exp))
; (fun parser_env ->
    let _1 = (peek_val parser_env 2 : 'patch_exp) in
    let _3 = (peek_val parser_env 0 : 'patch_exp) in
    Obj.repr(
# 868 "src/dparser.mly"
                           ( Tp.PE_And(_1,_3) )
# 4195 "src/dparser.ml"
               : 'patch_exp))
; (fun parser_env ->
    let _1 = (peek_val parser_env 2 : 'patch_exp) in
    let _3 = (peek_val parser_env 0 : 'patch_exp) in
    Obj.repr(
# 869 "src/dparser.mly"
                          ( Tp.PE_Or(_1,_3) )
# 4203 "src/dparser.ml"
               : 'patch_exp))
; (fun parser_env ->
    let _1 = (peek_val parser_env 2 : 'patch_exp) in
    let _3 = (peek_val parser_env 0 : 'patch_exp) in
    Obj.repr(
# 870 "src/dparser.mly"
                          ( Tp.PE_GT(_1,_3) )
# 4211 "src/dparser.ml"
               : 'patch_exp))
; (fun parser_env ->
    let _1 = (peek_val parser_env 2 : 'patch_exp) in
    let _3 = (peek_val parser_env 0 : 'patch_exp) in
    Obj.repr(
# 871 "src/dparser.mly"
                           ( Tp.PE_GTE(_1,_3) )
# 4219 "src/dparser.ml"
               : 'patch_exp))
; (fun parser_env ->
    let _1 = (peek_val parser_env 2 : 'patch_exp) in
    let _3 = (peek_val parser_env 0 : 'patch_exp) in
    Obj.repr(
# 872 "src/dparser.mly"
                          ( Tp.PE_LT(_1,_3) )
# 4227 "src/dparser.ml"
               : 'patch_exp))
; (fun parser_env ->
    let _1 = (peek_val parser_env 2 : 'patch_exp) in
    let _3 = (peek_val parser_env 0 : 'patch_exp) in
    Obj.repr(
# 873 "src/dparser.mly"
                           ( Tp.PE_LTE(_1,_3) )
# 4235 "src/dparser.ml"
               : 'patch_exp))
; (fun parser_env ->
    let _1 = (peek_val parser_env 2 : 'patch_exp) in
    let _3 = (peek_val parser_env 0 : 'patch_exp) in
    Obj.repr(
# 875 "src/dparser.mly"
                            ( Tp.PE_BAND(_1,_3) )
# 4243 "src/dparser.ml"
               : 'patch_exp))
; (fun parser_env ->
    let _1 = (peek_val parser_env 2 : 'patch_exp) in
    let _3 = (peek_val parser_env 0 : 'patch_exp) in
    Obj.repr(
# 876 "src/dparser.mly"
                           ( Tp.PE_BOR(_1,_3) )
# 4251 "src/dparser.ml"
               : 'patch_exp))
; (fun parser_env ->
    let _2 = (peek_val parser_env 0 : 'patch_exp) in
    Obj.repr(
# 877 "src/dparser.mly"
                  ( Tp.PE_BNOT(_2) )
# 4258 "src/dparser.ml"
               : 'patch_exp))
; (fun parser_env ->
    let _1 = (peek_val parser_env 2 : 'patch_exp) in
    let _3 = (peek_val parser_env 0 : 'patch_exp) in
    Obj.repr(
# 878 "src/dparser.mly"
                            ( Tp.PE_BXOR(_1,_3) )
# 4266 "src/dparser.ml"
               : 'patch_exp))
; (fun parser_env ->
    let _1 = (peek_val parser_env 2 : 'patch_exp) in
    let _3 = (peek_val parser_env 0 : 'patch_exp) in
    Obj.repr(
# 879 "src/dparser.mly"
                            ( Tp.PE_BLSL(_1,_3) )
# 4274 "src/dparser.ml"
               : 'patch_exp))
; (fun parser_env ->
    let _1 = (peek_val parser_env 2 : 'patch_exp) in
    let _3 = (peek_val parser_env 0 : 'patch_exp) in
    Obj.repr(
# 880 "src/dparser.mly"
                            ( Tp.PE_BLSR(_1,_3) )
# 4282 "src/dparser.ml"
               : 'patch_exp))
; (fun parser_env ->
    let _1 = (peek_val parser_env 2 : 'patch_exp) in
    let _3 = (peek_val parser_env 0 : 'patch_exp) in
    Obj.repr(
# 881 "src/dparser.mly"
                            ( Tp.PE_BASR(_1,_3) )
# 4290 "src/dparser.ml"
               : 'patch_exp))
; (fun parser_env ->
    let _1 = (peek_val parser_env 4 : 'patch_exp) in
    let _3 = (peek_val parser_env 2 : 'patch_exp) in
    let _5 = (peek_val parser_env 0 : 'patch_exp) in
    Obj.repr(
# 883 "src/dparser.mly"
                                               ( Tp.PE_If(_1,_3,_5); )
# 4299 "src/dparser.ml"
               : 'patch_exp))
; (fun parser_env ->
    Obj.repr(
# 886 "src/dparser.mly"
                  ( [] )
# 4305 "src/dparser.ml"
               : Tp.tp_patch list))
; (fun parser_env ->
    let _1 = (peek_val parser_env 1 : 'tp_patch) in
    let _2 = (peek_val parser_env 0 : Tp.tp_patch list) in
    Obj.repr(
# 887 "src/dparser.mly"
                         ( _1 :: _2 )
# 4313 "src/dparser.ml"
               : Tp.tp_patch list))
; (fun parser_env ->
    let _2 = (peek_val parser_env 1 : 'patch_exp) in
    let _3 = (peek_val parser_env 0 : Dlg.tlk_string) in
    Obj.repr(
# 891 "src/dparser.mly"
                    ( Tp.TP_PatchStrRef(_2,_3) )
# 4321 "src/dparser.ml"
               : 'tp_patch))
; (fun parser_env ->
    let _2 = (peek_val parser_env 1 : string) in
    let _3 = (peek_val parser_env 0 : Dlg.tlk_string) in
    Obj.repr(
# 892 "src/dparser.mly"
                     ( Tp.TP_PatchString(_2,_3) )
# 4329 "src/dparser.ml"
               : 'tp_patch))
; (fun parser_env ->
    let _2 = (peek_val parser_env 1 : string) in
    let _3 = (peek_val parser_env 0 : string) in
    Obj.repr(
# 893 "src/dparser.mly"
                                  ( Tp.TP_PatchStringTextually(_2,_3) )
# 4337 "src/dparser.ml"
               : 'tp_patch))
; (fun parser_env ->
    let _2 = (peek_val parser_env 1 : string) in
    let _3 = (peek_val parser_env 0 : string) in
    Obj.repr(
# 894 "src/dparser.mly"
                                  ( Tp.TP_PatchReplaceBCSBlock(_2,_3) )
# 4345 "src/dparser.ml"
               : 'tp_patch))
; (fun parser_env ->
    let _2 = (peek_val parser_env 1 : string) in
    let _3 = (peek_val parser_env 0 : string) in
    Obj.repr(
# 895 "src/dparser.mly"
                                         ( Tp.TP_PatchReplaceBCSBlockRE(_2,_3) )
# 4353 "src/dparser.ml"
               : 'tp_patch))
; (fun parser_env ->
    let _2 = (peek_val parser_env 0 : string) in
    Obj.repr(
# 896 "src/dparser.mly"
                         ( Tp.TP_PatchApplyBCSPatch(_2,None) )
# 4360 "src/dparser.ml"
               : 'tp_patch))
; (fun parser_env ->
    let _2 = (peek_val parser_env 1 : string) in
    let _3 = (peek_val parser_env 0 : string) in
    Obj.repr(
# 897 "src/dparser.mly"
                                        ( Tp.TP_PatchApplyBCSPatch(_2,Some(_3)) )
# 4368 "src/dparser.ml"
               : 'tp_patch))
; (fun parser_env ->
    let _2 = (peek_val parser_env 1 : 'patch_exp) in
    let _3 = (peek_val parser_env 0 : string) in
    Obj.repr(
# 898 "src/dparser.mly"
                              ( Tp.TP_PatchReadAscii(_2,_3) )
# 4376 "src/dparser.ml"
               : 'tp_patch))
; (fun parser_env ->
    let _2 = (peek_val parser_env 1 : 'patch_exp) in
    let _3 = (peek_val parser_env 0 : string) in
    Obj.repr(
# 899 "src/dparser.mly"
                             ( Tp.TP_PatchReadByte(_2,_3) )
# 4384 "src/dparser.ml"
               : 'tp_patch))
; (fun parser_env ->
    let _2 = (peek_val parser_env 1 : 'patch_exp) in
    let _3 = (peek_val parser_env 0 : string) in
    Obj.repr(
# 900 "src/dparser.mly"
                              ( Tp.TP_PatchReadShort(_2,_3) )
# 4392 "src/dparser.ml"
               : 'tp_patch))
; (fun parser_env ->
    let _2 = (peek_val parser_env 1 : 'patch_exp) in
    let _3 = (peek_val parser_env 0 : string) in
    Obj.repr(
# 901 "src/dparser.mly"
                             ( Tp.TP_PatchReadLong(_2,_3) )
# 4400 "src/dparser.ml"
               : 'tp_patch))
; (fun parser_env ->
    let _2 = (peek_val parser_env 1 : 'patch_exp) in
    let _3 = (peek_val parser_env 0 : 'patch_exp) in
    Obj.repr(
# 902 "src/dparser.mly"
                                 ( Tp.TP_PatchByte(_2,_3) )
# 4408 "src/dparser.ml"
               : 'tp_patch))
; (fun parser_env ->
    let _2 = (peek_val parser_env 1 : 'patch_exp) in
    let _3 = (peek_val parser_env 0 : 'patch_exp) in
    Obj.repr(
# 903 "src/dparser.mly"
                                  ( Tp.TP_PatchShort(_2,_3) )
# 4416 "src/dparser.ml"
               : 'tp_patch))
; (fun parser_env ->
    let _2 = (peek_val parser_env 1 : 'patch_exp) in
    let _3 = (peek_val parser_env 0 : 'patch_exp) in
    Obj.repr(
# 904 "src/dparser.mly"
                                 ( Tp.TP_PatchLong(_2,_3) )
# 4424 "src/dparser.ml"
               : 'tp_patch))
; (fun parser_env ->
    let _2 = (peek_val parser_env 1 : 'patch_exp) in
    let _3 = (peek_val parser_env 0 : string) in
    Obj.repr(
# 905 "src/dparser.mly"
                               ( Tp.TP_PatchASCII(_2,_3,false) )
# 4432 "src/dparser.ml"
               : 'tp_patch))
; (fun parser_env ->
    let _2 = (peek_val parser_env 1 : 'patch_exp) in
    let _3 = (peek_val parser_env 0 : string) in
    Obj.repr(
# 906 "src/dparser.mly"
                                         ( Tp.TP_PatchASCII(_2,_3,true) )
# 4440 "src/dparser.ml"
               : 'tp_patch))
; (fun parser_env ->
    let _2 = (peek_val parser_env 1 : 'patch_exp) in
    let _3 = (peek_val parser_env 0 : 'patch_exp) in
    Obj.repr(
# 907 "src/dparser.mly"
                                   ( Tp.TP_PatchInsertBytes(_2,_3) )
# 4448 "src/dparser.ml"
               : 'tp_patch))
; (fun parser_env ->
    let _2 = (peek_val parser_env 1 : 'patch_exp) in
    let _3 = (peek_val parser_env 0 : 'patch_exp) in
    Obj.repr(
# 908 "src/dparser.mly"
                                   ( Tp.TP_PatchDeleteBytes(_2,_3) )
# 4456 "src/dparser.ml"
               : 'tp_patch))
; (fun parser_env ->
    let _2 = (peek_val parser_env 2 : string) in
    let _4 = (peek_val parser_env 0 : 'patch_exp) in
    Obj.repr(
# 909 "src/dparser.mly"
                              ( Tp.TP_PatchSet(_2,_4) )
# 4464 "src/dparser.ml"
               : 'tp_patch))
; (fun parser_env ->
    let _2 = (peek_val parser_env 3 : 'patch_exp) in
    let _4 = (peek_val parser_env 1 : Tp.tp_patch list) in
    Obj.repr(
# 910 "src/dparser.mly"
                                          ( Tp.TP_PatchWhile(_2,_4) )
# 4472 "src/dparser.ml"
               : 'tp_patch))
; (fun parser_env ->
    let _2 = (peek_val parser_env 3 : 'patch_exp) in
    let _3 = (peek_val parser_env 2 : 'patch_exp) in
    let _4 = (peek_val parser_env 1 : 'patch_exp) in
    let _5 = (peek_val parser_env 0 : 'patch_exp) in
    Obj.repr(
# 911 "src/dparser.mly"
                                                        ( Tp.TP_Patch2DA(_2,_3,_4,_5) )
# 4482 "src/dparser.ml"
               : 'tp_patch))
; (fun parser_env ->
    let _2 = (peek_val parser_env 3 : 'patch_exp) in
    let _3 = (peek_val parser_env 2 : 'patch_exp) in
    let _4 = (peek_val parser_env 1 : 'patch_exp) in
    let _5 = (peek_val parser_env 0 : string) in
    Obj.repr(
# 912 "src/dparser.mly"
                                                      ( Tp.TP_Read2DA(_2,_3,_4,_5) )
# 4492 "src/dparser.ml"
               : 'tp_patch))
; (fun parser_env ->
    let _2 = (peek_val parser_env 3 : string) in
    let _3 = (peek_val parser_env 2 : string) in
    let _4 = (peek_val parser_env 1 : int) in
    let _5 = (peek_val parser_env 0 : int) in
    Obj.repr(
# 913 "src/dparser.mly"
                                                ( Tp.TP_Patch_Gam(_2,_3,_4,_5) )
# 4502 "src/dparser.ml"
               : 'tp_patch))
; (fun parser_env ->
    let _2 = (peek_val parser_env 6 : 'optional_plus) in
    let _3 = (peek_val parser_env 5 : string) in
    let _4 = (peek_val parser_env 4 : int) in
    let _5 = (peek_val parser_env 3 : int) in
    let _6 = (peek_val parser_env 2 : int) in
    let _7 = (peek_val parser_env 1 : string) in
    let _8 = (peek_val parser_env 0 : int) in
    Obj.repr(
# 915 "src/dparser.mly"
  ( Tp.TP_Add_S_Item({ Tp.overwrite_store_item = _2; },_3,_4,_5,_6,_7,_8) )
# 4515 "src/dparser.ml"
               : 'tp_patch))
; (fun parser_env ->
    let _1 = (peek_val parser_env 0 : (string * int * int * (string option)) list) in
    Obj.repr(
# 918 "src/dparser.mly"
                              ( _1 )
# 4522 "src/dparser.ml"
               : (string * int * int * (string option)) list))
; (fun parser_env ->
    Obj.repr(
# 921 "src/dparser.mly"
                              ( [] )
# 4528 "src/dparser.ml"
               : (string * int * int * (string option)) list))
; (fun parser_env ->
    let _1 = (peek_val parser_env 3 : string) in
    let _2 = (peek_val parser_env 2 : int) in
    let _3 = (peek_val parser_env 1 : int) in
    let _4 = (peek_val parser_env 0 : (string * int * int * (string option)) list) in
    Obj.repr(
# 923 "src/dparser.mly"
  ( (_1,_2,_3,None) :: _4 )
# 4538 "src/dparser.ml"
               : (string * int * int * (string option)) list))
; (fun parser_env ->
    let _1 = (peek_val parser_env 4 : string) in
    let _2 = (peek_val parser_env 3 : int) in
    let _3 = (peek_val parser_env 2 : int) in
    let _4 = (peek_val parser_env 1 : string) in
    let _5 = (peek_val parser_env 0 : (string * int * int * (string option)) list) in
    Obj.repr(
# 925 "src/dparser.mly"
  ( (_1,_2,_3,Some(_4)) :: _5 )
# 4549 "src/dparser.ml"
               : (string * int * int * (string option)) list))
(* Entry d_file *)
; (fun parser_env -> raise (YYexit (peek_val parser_env 0)))
(* Entry tra_file *)
; (fun parser_env -> raise (YYexit (peek_val parser_env 0)))
(* Entry tp_file *)
; (fun parser_env -> raise (YYexit (peek_val parser_env 0)))
(* Entry log_file *)
; (fun parser_env -> raise (YYexit (peek_val parser_env 0)))
|]
let yytables =
  { actions=yyact;
    transl_const=yytransl_const;
    transl_block=yytransl_block;
    lhs=yylhs;
    len=yylen;
    defred=yydefred;
    dgoto=yydgoto;
    sindex=yysindex;
    rindex=yyrindex;
    gindex=yygindex;
    tablesize=yytablesize;
    table=yytable;
    check=yycheck;
    error_function=parse_error;
    names_const=yynames_const;
    names_block=yynames_block }
let d_file (lexfun : Lexing.lexbuf -> token) (lexbuf : Lexing.lexbuf) =
   (yyparse yytables 1 lexfun lexbuf : Dc.action list)
let tra_file (lexfun : Lexing.lexbuf -> token) (lexbuf : Lexing.lexbuf) =
   (yyparse yytables 2 lexfun lexbuf : (int * Dlg.tlk_string) list)
let tp_file (lexfun : Lexing.lexbuf -> token) (lexbuf : Lexing.lexbuf) =
   (yyparse yytables 3 lexfun lexbuf : Tp.tp_file)
let log_file (lexfun : Lexing.lexbuf -> token) (lexbuf : Lexing.lexbuf) =
   (yyparse yytables 4 lexfun lexbuf : (string * int * int * (string option)) list)
;;
# 929 "src/dparser.mly"



# 4590 "src/dparser.ml"
